(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
    typeof define === 'function' && define.amd ? define(['exports'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.Feather = {}));
}(this, (function (exports) { 'use strict';

    function noop() { }
    function assign(tar, src) {
        // @ts-ignore
        for (const k in src)
            tar[k] = src[k];
        return tar;
    }
    function run(fn) {
        return fn();
    }
    function blank_object() {
        return Object.create(null);
    }
    function run_all(fns) {
        fns.forEach(run);
    }
    function is_function(thing) {
        return typeof thing === 'function';
    }
    function safe_not_equal(a, b) {
        return a != a ? b == b : a !== b || ((a && typeof a === 'object') || typeof a === 'function');
    }
    function is_empty(obj) {
        return Object.keys(obj).length === 0;
    }
    function exclude_internal_props(props) {
        const result = {};
        for (const k in props)
            if (k[0] !== '$')
                result[k] = props[k];
        return result;
    }
    function compute_rest_props(props, keys) {
        const rest = {};
        keys = new Set(keys);
        for (const k in props)
            if (!keys.has(k) && k[0] !== '$')
                rest[k] = props[k];
        return rest;
    }

    function append(target, node) {
        target.appendChild(node);
    }
    function insert(target, node, anchor) {
        target.insertBefore(node, anchor || null);
    }
    function detach(node) {
        node.parentNode.removeChild(node);
    }
    function svg_element(name) {
        return document.createElementNS('http://www.w3.org/2000/svg', name);
    }
    function attr(node, attribute, value) {
        if (value == null)
            node.removeAttribute(attribute);
        else if (node.getAttribute(attribute) !== value)
            node.setAttribute(attribute, value);
    }
    function set_svg_attributes(node, attributes) {
        for (const key in attributes) {
            attr(node, key, attributes[key]);
        }
    }
    function children(element) {
        return Array.from(element.childNodes);
    }

    let current_component;
    function set_current_component(component) {
        current_component = component;
    }

    const dirty_components = [];
    const binding_callbacks = [];
    const render_callbacks = [];
    const flush_callbacks = [];
    const resolved_promise = Promise.resolve();
    let update_scheduled = false;
    function schedule_update() {
        if (!update_scheduled) {
            update_scheduled = true;
            resolved_promise.then(flush);
        }
    }
    function add_render_callback(fn) {
        render_callbacks.push(fn);
    }
    let flushing = false;
    const seen_callbacks = new Set();
    function flush() {
        if (flushing)
            return;
        flushing = true;
        do {
            // first, call beforeUpdate functions
            // and update components
            for (let i = 0; i < dirty_components.length; i += 1) {
                const component = dirty_components[i];
                set_current_component(component);
                update(component.$$);
            }
            set_current_component(null);
            dirty_components.length = 0;
            while (binding_callbacks.length)
                binding_callbacks.pop()();
            // then, once components are updated, call
            // afterUpdate functions. This may cause
            // subsequent updates...
            for (let i = 0; i < render_callbacks.length; i += 1) {
                const callback = render_callbacks[i];
                if (!seen_callbacks.has(callback)) {
                    // ...so guard against infinite loops
                    seen_callbacks.add(callback);
                    callback();
                }
            }
            render_callbacks.length = 0;
        } while (dirty_components.length);
        while (flush_callbacks.length) {
            flush_callbacks.pop()();
        }
        update_scheduled = false;
        flushing = false;
        seen_callbacks.clear();
    }
    function update($$) {
        if ($$.fragment !== null) {
            $$.update();
            run_all($$.before_update);
            const dirty = $$.dirty;
            $$.dirty = [-1];
            $$.fragment && $$.fragment.p($$.ctx, dirty);
            $$.after_update.forEach(add_render_callback);
        }
    }
    const outroing = new Set();
    function transition_in(block, local) {
        if (block && block.i) {
            outroing.delete(block);
            block.i(local);
        }
    }

    function get_spread_update(levels, updates) {
        const update = {};
        const to_null_out = {};
        const accounted_for = { $$scope: 1 };
        let i = levels.length;
        while (i--) {
            const o = levels[i];
            const n = updates[i];
            if (n) {
                for (const key in o) {
                    if (!(key in n))
                        to_null_out[key] = 1;
                }
                for (const key in n) {
                    if (!accounted_for[key]) {
                        update[key] = n[key];
                        accounted_for[key] = 1;
                    }
                }
                levels[i] = n;
            }
            else {
                for (const key in o) {
                    accounted_for[key] = 1;
                }
            }
        }
        for (const key in to_null_out) {
            if (!(key in update))
                update[key] = undefined;
        }
        return update;
    }
    function mount_component(component, target, anchor) {
        const { fragment, on_mount, on_destroy, after_update } = component.$$;
        fragment && fragment.m(target, anchor);
        // onMount happens before the initial afterUpdate
        add_render_callback(() => {
            const new_on_destroy = on_mount.map(run).filter(is_function);
            if (on_destroy) {
                on_destroy.push(...new_on_destroy);
            }
            else {
                // Edge case - component was destroyed immediately,
                // most likely as a result of a binding initialising
                run_all(new_on_destroy);
            }
            component.$$.on_mount = [];
        });
        after_update.forEach(add_render_callback);
    }
    function destroy_component(component, detaching) {
        const $$ = component.$$;
        if ($$.fragment !== null) {
            run_all($$.on_destroy);
            $$.fragment && $$.fragment.d(detaching);
            // TODO null out other refs, including component.$$ (but need to
            // preserve final state?)
            $$.on_destroy = $$.fragment = null;
            $$.ctx = [];
        }
    }
    function make_dirty(component, i) {
        if (component.$$.dirty[0] === -1) {
            dirty_components.push(component);
            schedule_update();
            component.$$.dirty.fill(0);
        }
        component.$$.dirty[(i / 31) | 0] |= (1 << (i % 31));
    }
    function init(component, options, instance, create_fragment, not_equal, props, dirty = [-1]) {
        const parent_component = current_component;
        set_current_component(component);
        const prop_values = options.props || {};
        const $$ = component.$$ = {
            fragment: null,
            ctx: null,
            // state
            props,
            update: noop,
            not_equal,
            bound: blank_object(),
            // lifecycle
            on_mount: [],
            on_destroy: [],
            before_update: [],
            after_update: [],
            context: new Map(parent_component ? parent_component.$$.context : []),
            // everything else
            callbacks: blank_object(),
            dirty,
            skip_bound: false
        };
        let ready = false;
        $$.ctx = instance
            ? instance(component, prop_values, (i, ret, ...rest) => {
                const value = rest.length ? rest[0] : ret;
                if ($$.ctx && not_equal($$.ctx[i], $$.ctx[i] = value)) {
                    if (!$$.skip_bound && $$.bound[i])
                        $$.bound[i](value);
                    if (ready)
                        make_dirty(component, i);
                }
                return ret;
            })
            : [];
        $$.update();
        ready = true;
        run_all($$.before_update);
        // `false` as a special case of no DOM component
        $$.fragment = create_fragment ? create_fragment($$.ctx) : false;
        if (options.target) {
            if (options.hydrate) {
                const nodes = children(options.target);
                // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
                $$.fragment && $$.fragment.l(nodes);
                nodes.forEach(detach);
            }
            else {
                // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
                $$.fragment && $$.fragment.c();
            }
            if (options.intro)
                transition_in(component.$$.fragment);
            mount_component(component, options.target, options.anchor);
            flush();
        }
        set_current_component(parent_component);
    }
    /**
     * Base class for Svelte components. Used when dev=false.
     */
    class SvelteComponent {
        $destroy() {
            destroy_component(this, 1);
            this.$destroy = noop;
        }
        $on(type, callback) {
            const callbacks = (this.$$.callbacks[type] || (this.$$.callbacks[type] = []));
            callbacks.push(callback);
            return () => {
                const index = callbacks.indexOf(callback);
                if (index !== -1)
                    callbacks.splice(index, 1);
            };
        }
        $set($$props) {
            if (this.$$set && !is_empty($$props)) {
                this.$$.skip_bound = true;
                this.$$set($$props);
                this.$$.skip_bound = false;
            }
        }
    }

    /* src/icons/Activity.svelte generated by Svelte v3.31.0 */

    function create_fragment(ctx) {
    	let svg;
    	let polyline;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline = svg_element("polyline");
    			attr(polyline, "points", "22 12 18 12 15 21 9 3 6 12 2 12");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Activity extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance, create_fragment, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Airplay.svelte generated by Svelte v3.31.0 */

    function create_fragment$1(ctx) {
    	let svg;
    	let path;
    	let polygon;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			polygon = svg_element("polygon");
    			attr(path, "d", "M5 17H4a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h16a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2h-1");
    			attr(polygon, "points", "12 15 17 21 7 21 12 15");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, polygon);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Airplay extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1, create_fragment$1, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/AlertCircle.svelte generated by Svelte v3.31.0 */

    function create_fragment$2(ctx) {
    	let svg;
    	let circle;
    	let line0;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle = svg_element("circle");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "12");
    			attr(circle, "r", "10");
    			attr(line0, "x1", "12");
    			attr(line0, "y1", "8");
    			attr(line0, "x2", "12");
    			attr(line0, "y2", "12");
    			attr(line1, "x1", "12");
    			attr(line1, "y1", "16");
    			attr(line1, "x2", "12.01");
    			attr(line1, "y2", "16");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle);
    			append(svg, line0);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class AlertCircle extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2, create_fragment$2, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/AlertOctagon.svelte generated by Svelte v3.31.0 */

    function create_fragment$3(ctx) {
    	let svg;
    	let polygon;
    	let line0;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polygon = svg_element("polygon");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			attr(polygon, "points", "7.86 2 16.14 2 22 7.86 22 16.14 16.14 22 7.86 22 2 16.14 2 7.86 7.86 2");
    			attr(line0, "x1", "12");
    			attr(line0, "y1", "8");
    			attr(line0, "x2", "12");
    			attr(line0, "y2", "12");
    			attr(line1, "x1", "12");
    			attr(line1, "y1", "16");
    			attr(line1, "x2", "12.01");
    			attr(line1, "y2", "16");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polygon);
    			append(svg, line0);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class AlertOctagon extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3, create_fragment$3, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/AlertTriangle.svelte generated by Svelte v3.31.0 */

    function create_fragment$4(ctx) {
    	let svg;
    	let path;
    	let line0;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			attr(path, "d", "M10.29 3.86L1.82 18a2 2 0 0 0 1.71 3h16.94a2 2 0 0 0 1.71-3L13.71 3.86a2 2 0 0 0-3.42 0z");
    			attr(line0, "x1", "12");
    			attr(line0, "y1", "9");
    			attr(line0, "x2", "12");
    			attr(line0, "y2", "13");
    			attr(line1, "x1", "12");
    			attr(line1, "y1", "17");
    			attr(line1, "x2", "12.01");
    			attr(line1, "y2", "17");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, line0);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$4($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class AlertTriangle extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$4, create_fragment$4, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/AlignCenter.svelte generated by Svelte v3.31.0 */

    function create_fragment$5(ctx) {
    	let svg;
    	let line0;
    	let line1;
    	let line2;
    	let line3;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			line2 = svg_element("line");
    			line3 = svg_element("line");
    			attr(line0, "x1", "18");
    			attr(line0, "y1", "10");
    			attr(line0, "x2", "6");
    			attr(line0, "y2", "10");
    			attr(line1, "x1", "21");
    			attr(line1, "y1", "6");
    			attr(line1, "x2", "3");
    			attr(line1, "y2", "6");
    			attr(line2, "x1", "21");
    			attr(line2, "y1", "14");
    			attr(line2, "x2", "3");
    			attr(line2, "y2", "14");
    			attr(line3, "x1", "18");
    			attr(line3, "y1", "18");
    			attr(line3, "x2", "6");
    			attr(line3, "y2", "18");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, line0);
    			append(svg, line1);
    			append(svg, line2);
    			append(svg, line3);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$5($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class AlignCenter extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$5, create_fragment$5, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/AlignJustify.svelte generated by Svelte v3.31.0 */

    function create_fragment$6(ctx) {
    	let svg;
    	let line0;
    	let line1;
    	let line2;
    	let line3;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			line2 = svg_element("line");
    			line3 = svg_element("line");
    			attr(line0, "x1", "21");
    			attr(line0, "y1", "10");
    			attr(line0, "x2", "3");
    			attr(line0, "y2", "10");
    			attr(line1, "x1", "21");
    			attr(line1, "y1", "6");
    			attr(line1, "x2", "3");
    			attr(line1, "y2", "6");
    			attr(line2, "x1", "21");
    			attr(line2, "y1", "14");
    			attr(line2, "x2", "3");
    			attr(line2, "y2", "14");
    			attr(line3, "x1", "21");
    			attr(line3, "y1", "18");
    			attr(line3, "x2", "3");
    			attr(line3, "y2", "18");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, line0);
    			append(svg, line1);
    			append(svg, line2);
    			append(svg, line3);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$6($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class AlignJustify extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$6, create_fragment$6, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/AlignLeft.svelte generated by Svelte v3.31.0 */

    function create_fragment$7(ctx) {
    	let svg;
    	let line0;
    	let line1;
    	let line2;
    	let line3;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			line2 = svg_element("line");
    			line3 = svg_element("line");
    			attr(line0, "x1", "17");
    			attr(line0, "y1", "10");
    			attr(line0, "x2", "3");
    			attr(line0, "y2", "10");
    			attr(line1, "x1", "21");
    			attr(line1, "y1", "6");
    			attr(line1, "x2", "3");
    			attr(line1, "y2", "6");
    			attr(line2, "x1", "21");
    			attr(line2, "y1", "14");
    			attr(line2, "x2", "3");
    			attr(line2, "y2", "14");
    			attr(line3, "x1", "17");
    			attr(line3, "y1", "18");
    			attr(line3, "x2", "3");
    			attr(line3, "y2", "18");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, line0);
    			append(svg, line1);
    			append(svg, line2);
    			append(svg, line3);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$7($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class AlignLeft extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$7, create_fragment$7, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/AlignRight.svelte generated by Svelte v3.31.0 */

    function create_fragment$8(ctx) {
    	let svg;
    	let line0;
    	let line1;
    	let line2;
    	let line3;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			line2 = svg_element("line");
    			line3 = svg_element("line");
    			attr(line0, "x1", "21");
    			attr(line0, "y1", "10");
    			attr(line0, "x2", "7");
    			attr(line0, "y2", "10");
    			attr(line1, "x1", "21");
    			attr(line1, "y1", "6");
    			attr(line1, "x2", "3");
    			attr(line1, "y2", "6");
    			attr(line2, "x1", "21");
    			attr(line2, "y1", "14");
    			attr(line2, "x2", "3");
    			attr(line2, "y2", "14");
    			attr(line3, "x1", "21");
    			attr(line3, "y1", "18");
    			attr(line3, "x2", "7");
    			attr(line3, "y2", "18");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, line0);
    			append(svg, line1);
    			append(svg, line2);
    			append(svg, line3);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$8($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class AlignRight extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$8, create_fragment$8, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Anchor.svelte generated by Svelte v3.31.0 */

    function create_fragment$9(ctx) {
    	let svg;
    	let circle;
    	let line;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle = svg_element("circle");
    			line = svg_element("line");
    			path = svg_element("path");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "5");
    			attr(circle, "r", "3");
    			attr(line, "x1", "12");
    			attr(line, "y1", "22");
    			attr(line, "x2", "12");
    			attr(line, "y2", "8");
    			attr(path, "d", "M5 12H2a10 10 0 0 0 20 0h-3");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle);
    			append(svg, line);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$9($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Anchor extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$9, create_fragment$9, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Aperture.svelte generated by Svelte v3.31.0 */

    function create_fragment$a(ctx) {
    	let svg;
    	let circle;
    	let line0;
    	let line1;
    	let line2;
    	let line3;
    	let line4;
    	let line5;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle = svg_element("circle");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			line2 = svg_element("line");
    			line3 = svg_element("line");
    			line4 = svg_element("line");
    			line5 = svg_element("line");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "12");
    			attr(circle, "r", "10");
    			attr(line0, "x1", "14.31");
    			attr(line0, "y1", "8");
    			attr(line0, "x2", "20.05");
    			attr(line0, "y2", "17.94");
    			attr(line1, "x1", "9.69");
    			attr(line1, "y1", "8");
    			attr(line1, "x2", "21.17");
    			attr(line1, "y2", "8");
    			attr(line2, "x1", "7.38");
    			attr(line2, "y1", "12");
    			attr(line2, "x2", "13.12");
    			attr(line2, "y2", "2.06");
    			attr(line3, "x1", "9.69");
    			attr(line3, "y1", "16");
    			attr(line3, "x2", "3.95");
    			attr(line3, "y2", "6.06");
    			attr(line4, "x1", "14.31");
    			attr(line4, "y1", "16");
    			attr(line4, "x2", "2.83");
    			attr(line4, "y2", "16");
    			attr(line5, "x1", "16.62");
    			attr(line5, "y1", "12");
    			attr(line5, "x2", "10.88");
    			attr(line5, "y2", "21.94");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle);
    			append(svg, line0);
    			append(svg, line1);
    			append(svg, line2);
    			append(svg, line3);
    			append(svg, line4);
    			append(svg, line5);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$a($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Aperture extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$a, create_fragment$a, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Archive.svelte generated by Svelte v3.31.0 */

    function create_fragment$b(ctx) {
    	let svg;
    	let polyline;
    	let rect;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline = svg_element("polyline");
    			rect = svg_element("rect");
    			line = svg_element("line");
    			attr(polyline, "points", "21 8 21 21 3 21 3 8");
    			attr(rect, "x", "1");
    			attr(rect, "y", "3");
    			attr(rect, "width", "22");
    			attr(rect, "height", "5");
    			attr(line, "x1", "10");
    			attr(line, "y1", "12");
    			attr(line, "x2", "14");
    			attr(line, "y2", "12");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline);
    			append(svg, rect);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$b($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Archive extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$b, create_fragment$b, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/ArrowDownCircle.svelte generated by Svelte v3.31.0 */

    function create_fragment$c(ctx) {
    	let svg;
    	let circle;
    	let polyline;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle = svg_element("circle");
    			polyline = svg_element("polyline");
    			line = svg_element("line");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "12");
    			attr(circle, "r", "10");
    			attr(polyline, "points", "8 12 12 16 16 12");
    			attr(line, "x1", "12");
    			attr(line, "y1", "8");
    			attr(line, "x2", "12");
    			attr(line, "y2", "16");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle);
    			append(svg, polyline);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$c($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class ArrowDownCircle extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$c, create_fragment$c, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/ArrowDownLeft.svelte generated by Svelte v3.31.0 */

    function create_fragment$d(ctx) {
    	let svg;
    	let line;
    	let polyline;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			line = svg_element("line");
    			polyline = svg_element("polyline");
    			attr(line, "x1", "17");
    			attr(line, "y1", "7");
    			attr(line, "x2", "7");
    			attr(line, "y2", "17");
    			attr(polyline, "points", "17 17 7 17 7 7");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, line);
    			append(svg, polyline);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$d($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class ArrowDownLeft extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$d, create_fragment$d, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/ArrowDownRight.svelte generated by Svelte v3.31.0 */

    function create_fragment$e(ctx) {
    	let svg;
    	let line;
    	let polyline;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			line = svg_element("line");
    			polyline = svg_element("polyline");
    			attr(line, "x1", "7");
    			attr(line, "y1", "7");
    			attr(line, "x2", "17");
    			attr(line, "y2", "17");
    			attr(polyline, "points", "17 7 17 17 7 17");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, line);
    			append(svg, polyline);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$e($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class ArrowDownRight extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$e, create_fragment$e, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/ArrowDown.svelte generated by Svelte v3.31.0 */

    function create_fragment$f(ctx) {
    	let svg;
    	let line;
    	let polyline;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			line = svg_element("line");
    			polyline = svg_element("polyline");
    			attr(line, "x1", "12");
    			attr(line, "y1", "5");
    			attr(line, "x2", "12");
    			attr(line, "y2", "19");
    			attr(polyline, "points", "19 12 12 19 5 12");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, line);
    			append(svg, polyline);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$f($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class ArrowDown extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$f, create_fragment$f, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/ArrowLeftCircle.svelte generated by Svelte v3.31.0 */

    function create_fragment$g(ctx) {
    	let svg;
    	let circle;
    	let polyline;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle = svg_element("circle");
    			polyline = svg_element("polyline");
    			line = svg_element("line");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "12");
    			attr(circle, "r", "10");
    			attr(polyline, "points", "12 8 8 12 12 16");
    			attr(line, "x1", "16");
    			attr(line, "y1", "12");
    			attr(line, "x2", "8");
    			attr(line, "y2", "12");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle);
    			append(svg, polyline);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$g($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class ArrowLeftCircle extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$g, create_fragment$g, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/ArrowLeft.svelte generated by Svelte v3.31.0 */

    function create_fragment$h(ctx) {
    	let svg;
    	let line;
    	let polyline;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			line = svg_element("line");
    			polyline = svg_element("polyline");
    			attr(line, "x1", "19");
    			attr(line, "y1", "12");
    			attr(line, "x2", "5");
    			attr(line, "y2", "12");
    			attr(polyline, "points", "12 19 5 12 12 5");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, line);
    			append(svg, polyline);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$h($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class ArrowLeft extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$h, create_fragment$h, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/ArrowRightCircle.svelte generated by Svelte v3.31.0 */

    function create_fragment$i(ctx) {
    	let svg;
    	let circle;
    	let polyline;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle = svg_element("circle");
    			polyline = svg_element("polyline");
    			line = svg_element("line");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "12");
    			attr(circle, "r", "10");
    			attr(polyline, "points", "12 16 16 12 12 8");
    			attr(line, "x1", "8");
    			attr(line, "y1", "12");
    			attr(line, "x2", "16");
    			attr(line, "y2", "12");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle);
    			append(svg, polyline);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$i($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class ArrowRightCircle extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$i, create_fragment$i, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/ArrowRight.svelte generated by Svelte v3.31.0 */

    function create_fragment$j(ctx) {
    	let svg;
    	let line;
    	let polyline;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			line = svg_element("line");
    			polyline = svg_element("polyline");
    			attr(line, "x1", "5");
    			attr(line, "y1", "12");
    			attr(line, "x2", "19");
    			attr(line, "y2", "12");
    			attr(polyline, "points", "12 5 19 12 12 19");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, line);
    			append(svg, polyline);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$j($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class ArrowRight extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$j, create_fragment$j, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/ArrowUpCircle.svelte generated by Svelte v3.31.0 */

    function create_fragment$k(ctx) {
    	let svg;
    	let circle;
    	let polyline;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle = svg_element("circle");
    			polyline = svg_element("polyline");
    			line = svg_element("line");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "12");
    			attr(circle, "r", "10");
    			attr(polyline, "points", "16 12 12 8 8 12");
    			attr(line, "x1", "12");
    			attr(line, "y1", "16");
    			attr(line, "x2", "12");
    			attr(line, "y2", "8");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle);
    			append(svg, polyline);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$k($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class ArrowUpCircle extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$k, create_fragment$k, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/ArrowUpLeft.svelte generated by Svelte v3.31.0 */

    function create_fragment$l(ctx) {
    	let svg;
    	let line;
    	let polyline;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			line = svg_element("line");
    			polyline = svg_element("polyline");
    			attr(line, "x1", "17");
    			attr(line, "y1", "17");
    			attr(line, "x2", "7");
    			attr(line, "y2", "7");
    			attr(polyline, "points", "7 17 7 7 17 7");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, line);
    			append(svg, polyline);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$l($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class ArrowUpLeft extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$l, create_fragment$l, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/ArrowUpRight.svelte generated by Svelte v3.31.0 */

    function create_fragment$m(ctx) {
    	let svg;
    	let line;
    	let polyline;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			line = svg_element("line");
    			polyline = svg_element("polyline");
    			attr(line, "x1", "7");
    			attr(line, "y1", "17");
    			attr(line, "x2", "17");
    			attr(line, "y2", "7");
    			attr(polyline, "points", "7 7 17 7 17 17");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, line);
    			append(svg, polyline);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$m($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class ArrowUpRight extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$m, create_fragment$m, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/ArrowUp.svelte generated by Svelte v3.31.0 */

    function create_fragment$n(ctx) {
    	let svg;
    	let line;
    	let polyline;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			line = svg_element("line");
    			polyline = svg_element("polyline");
    			attr(line, "x1", "12");
    			attr(line, "y1", "19");
    			attr(line, "x2", "12");
    			attr(line, "y2", "5");
    			attr(polyline, "points", "5 12 12 5 19 12");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, line);
    			append(svg, polyline);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$n($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class ArrowUp extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$n, create_fragment$n, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/AtSign.svelte generated by Svelte v3.31.0 */

    function create_fragment$o(ctx) {
    	let svg;
    	let circle;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle = svg_element("circle");
    			path = svg_element("path");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "12");
    			attr(circle, "r", "4");
    			attr(path, "d", "M16 8v5a3 3 0 0 0 6 0v-1a10 10 0 1 0-3.92 7.94");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$o($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class AtSign extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$o, create_fragment$o, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Award.svelte generated by Svelte v3.31.0 */

    function create_fragment$p(ctx) {
    	let svg;
    	let circle;
    	let polyline;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle = svg_element("circle");
    			polyline = svg_element("polyline");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "8");
    			attr(circle, "r", "7");
    			attr(polyline, "points", "8.21 13.89 7 23 12 20 17 23 15.79 13.88");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle);
    			append(svg, polyline);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$p($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Award extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$p, create_fragment$p, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/BarChart2.svelte generated by Svelte v3.31.0 */

    function create_fragment$q(ctx) {
    	let svg;
    	let line0;
    	let line1;
    	let line2;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			line2 = svg_element("line");
    			attr(line0, "x1", "18");
    			attr(line0, "y1", "20");
    			attr(line0, "x2", "18");
    			attr(line0, "y2", "10");
    			attr(line1, "x1", "12");
    			attr(line1, "y1", "20");
    			attr(line1, "x2", "12");
    			attr(line1, "y2", "4");
    			attr(line2, "x1", "6");
    			attr(line2, "y1", "20");
    			attr(line2, "x2", "6");
    			attr(line2, "y2", "14");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, line0);
    			append(svg, line1);
    			append(svg, line2);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$q($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class BarChart2 extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$q, create_fragment$q, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/BarChart.svelte generated by Svelte v3.31.0 */

    function create_fragment$r(ctx) {
    	let svg;
    	let line0;
    	let line1;
    	let line2;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			line2 = svg_element("line");
    			attr(line0, "x1", "12");
    			attr(line0, "y1", "20");
    			attr(line0, "x2", "12");
    			attr(line0, "y2", "10");
    			attr(line1, "x1", "18");
    			attr(line1, "y1", "20");
    			attr(line1, "x2", "18");
    			attr(line1, "y2", "4");
    			attr(line2, "x1", "6");
    			attr(line2, "y1", "20");
    			attr(line2, "x2", "6");
    			attr(line2, "y2", "16");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, line0);
    			append(svg, line1);
    			append(svg, line2);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$r($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class BarChart extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$r, create_fragment$r, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/BatteryCharging.svelte generated by Svelte v3.31.0 */

    function create_fragment$s(ctx) {
    	let svg;
    	let path;
    	let line;
    	let polyline;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			line = svg_element("line");
    			polyline = svg_element("polyline");
    			attr(path, "d", "M5 18H3a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h3.19M15 6h2a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2h-3.19");
    			attr(line, "x1", "23");
    			attr(line, "y1", "13");
    			attr(line, "x2", "23");
    			attr(line, "y2", "11");
    			attr(polyline, "points", "11 6 7 12 13 12 9 18");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, line);
    			append(svg, polyline);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$s($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class BatteryCharging extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$s, create_fragment$s, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Battery.svelte generated by Svelte v3.31.0 */

    function create_fragment$t(ctx) {
    	let svg;
    	let rect;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			rect = svg_element("rect");
    			line = svg_element("line");
    			attr(rect, "x", "1");
    			attr(rect, "y", "6");
    			attr(rect, "width", "18");
    			attr(rect, "height", "12");
    			attr(rect, "rx", "2");
    			attr(rect, "ry", "2");
    			attr(line, "x1", "23");
    			attr(line, "y1", "13");
    			attr(line, "x2", "23");
    			attr(line, "y2", "11");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, rect);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$t($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Battery extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$t, create_fragment$t, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/BellOff.svelte generated by Svelte v3.31.0 */

    function create_fragment$u(ctx) {
    	let svg;
    	let path0;
    	let path1;
    	let path2;
    	let path3;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path0 = svg_element("path");
    			path1 = svg_element("path");
    			path2 = svg_element("path");
    			path3 = svg_element("path");
    			line = svg_element("line");
    			attr(path0, "d", "M13.73 21a2 2 0 0 1-3.46 0");
    			attr(path1, "d", "M18.63 13A17.89 17.89 0 0 1 18 8");
    			attr(path2, "d", "M6.26 6.26A5.86 5.86 0 0 0 6 8c0 7-3 9-3 9h14");
    			attr(path3, "d", "M18 8a6 6 0 0 0-9.33-5");
    			attr(line, "x1", "1");
    			attr(line, "y1", "1");
    			attr(line, "x2", "23");
    			attr(line, "y2", "23");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path0);
    			append(svg, path1);
    			append(svg, path2);
    			append(svg, path3);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$u($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class BellOff extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$u, create_fragment$u, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Bell.svelte generated by Svelte v3.31.0 */

    function create_fragment$v(ctx) {
    	let svg;
    	let path0;
    	let path1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path0 = svg_element("path");
    			path1 = svg_element("path");
    			attr(path0, "d", "M18 8A6 6 0 0 0 6 8c0 7-3 9-3 9h18s-3-2-3-9");
    			attr(path1, "d", "M13.73 21a2 2 0 0 1-3.46 0");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path0);
    			append(svg, path1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$v($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Bell extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$v, create_fragment$v, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Bluetooth.svelte generated by Svelte v3.31.0 */

    function create_fragment$w(ctx) {
    	let svg;
    	let polyline;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline = svg_element("polyline");
    			attr(polyline, "points", "6.5 6.5 17.5 17.5 12 23 12 1 17.5 6.5 6.5 17.5");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$w($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Bluetooth extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$w, create_fragment$w, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Bold.svelte generated by Svelte v3.31.0 */

    function create_fragment$x(ctx) {
    	let svg;
    	let path0;
    	let path1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path0 = svg_element("path");
    			path1 = svg_element("path");
    			attr(path0, "d", "M6 4h8a4 4 0 0 1 4 4 4 4 0 0 1-4 4H6z");
    			attr(path1, "d", "M6 12h9a4 4 0 0 1 4 4 4 4 0 0 1-4 4H6z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path0);
    			append(svg, path1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$x($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Bold extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$x, create_fragment$x, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/BookOpen.svelte generated by Svelte v3.31.0 */

    function create_fragment$y(ctx) {
    	let svg;
    	let path0;
    	let path1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path0 = svg_element("path");
    			path1 = svg_element("path");
    			attr(path0, "d", "M2 3h6a4 4 0 0 1 4 4v14a3 3 0 0 0-3-3H2z");
    			attr(path1, "d", "M22 3h-6a4 4 0 0 0-4 4v14a3 3 0 0 1 3-3h7z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path0);
    			append(svg, path1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$y($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class BookOpen extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$y, create_fragment$y, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Book.svelte generated by Svelte v3.31.0 */

    function create_fragment$z(ctx) {
    	let svg;
    	let path0;
    	let path1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path0 = svg_element("path");
    			path1 = svg_element("path");
    			attr(path0, "d", "M4 19.5A2.5 2.5 0 0 1 6.5 17H20");
    			attr(path1, "d", "M6.5 2H20v20H6.5A2.5 2.5 0 0 1 4 19.5v-15A2.5 2.5 0 0 1 6.5 2z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path0);
    			append(svg, path1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$z($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Book extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$z, create_fragment$z, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Bookmark.svelte generated by Svelte v3.31.0 */

    function create_fragment$A(ctx) {
    	let svg;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			attr(path, "d", "M19 21l-7-5-7 5V5a2 2 0 0 1 2-2h10a2 2 0 0 1 2 2z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$A($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Bookmark extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$A, create_fragment$A, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Box.svelte generated by Svelte v3.31.0 */

    function create_fragment$B(ctx) {
    	let svg;
    	let path;
    	let polyline;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			polyline = svg_element("polyline");
    			line = svg_element("line");
    			attr(path, "d", "M21 16V8a2 2 0 0 0-1-1.73l-7-4a2 2 0 0 0-2 0l-7 4A2 2 0 0 0 3 8v8a2 2 0 0 0 1 1.73l7 4a2 2 0 0 0 2 0l7-4A2 2 0 0 0 21 16z");
    			attr(polyline, "points", "3.27 6.96 12 12.01 20.73 6.96");
    			attr(line, "x1", "12");
    			attr(line, "y1", "22.08");
    			attr(line, "x2", "12");
    			attr(line, "y2", "12");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, polyline);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$B($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Box extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$B, create_fragment$B, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Briefcase.svelte generated by Svelte v3.31.0 */

    function create_fragment$C(ctx) {
    	let svg;
    	let rect;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			rect = svg_element("rect");
    			path = svg_element("path");
    			attr(rect, "x", "2");
    			attr(rect, "y", "7");
    			attr(rect, "width", "20");
    			attr(rect, "height", "14");
    			attr(rect, "rx", "2");
    			attr(rect, "ry", "2");
    			attr(path, "d", "M16 21V5a2 2 0 0 0-2-2h-4a2 2 0 0 0-2 2v16");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, rect);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$C($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Briefcase extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$C, create_fragment$C, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Calendar.svelte generated by Svelte v3.31.0 */

    function create_fragment$D(ctx) {
    	let svg;
    	let rect;
    	let line0;
    	let line1;
    	let line2;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			rect = svg_element("rect");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			line2 = svg_element("line");
    			attr(rect, "x", "3");
    			attr(rect, "y", "4");
    			attr(rect, "width", "18");
    			attr(rect, "height", "18");
    			attr(rect, "rx", "2");
    			attr(rect, "ry", "2");
    			attr(line0, "x1", "16");
    			attr(line0, "y1", "2");
    			attr(line0, "x2", "16");
    			attr(line0, "y2", "6");
    			attr(line1, "x1", "8");
    			attr(line1, "y1", "2");
    			attr(line1, "x2", "8");
    			attr(line1, "y2", "6");
    			attr(line2, "x1", "3");
    			attr(line2, "y1", "10");
    			attr(line2, "x2", "21");
    			attr(line2, "y2", "10");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, rect);
    			append(svg, line0);
    			append(svg, line1);
    			append(svg, line2);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$D($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Calendar extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$D, create_fragment$D, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/CameraOff.svelte generated by Svelte v3.31.0 */

    function create_fragment$E(ctx) {
    	let svg;
    	let line;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			line = svg_element("line");
    			path = svg_element("path");
    			attr(line, "x1", "1");
    			attr(line, "y1", "1");
    			attr(line, "x2", "23");
    			attr(line, "y2", "23");
    			attr(path, "d", "M21 21H3a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h3m3-3h6l2 3h4a2 2 0 0 1 2 2v9.34m-7.72-2.06a4 4 0 1 1-5.56-5.56");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, line);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$E($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class CameraOff extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$E, create_fragment$E, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Camera.svelte generated by Svelte v3.31.0 */

    function create_fragment$F(ctx) {
    	let svg;
    	let path;
    	let circle;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			circle = svg_element("circle");
    			attr(path, "d", "M23 19a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h4l2-3h6l2 3h4a2 2 0 0 1 2 2z");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "13");
    			attr(circle, "r", "4");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, circle);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$F($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Camera extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$F, create_fragment$F, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Cast.svelte generated by Svelte v3.31.0 */

    function create_fragment$G(ctx) {
    	let svg;
    	let path;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			line = svg_element("line");
    			attr(path, "d", "M2 16.1A5 5 0 0 1 5.9 20M2 12.05A9 9 0 0 1 9.95 20M2 8V6a2 2 0 0 1 2-2h16a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2h-6");
    			attr(line, "x1", "2");
    			attr(line, "y1", "20");
    			attr(line, "x2", "2.01");
    			attr(line, "y2", "20");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$G($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Cast extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$G, create_fragment$G, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/CheckCircle.svelte generated by Svelte v3.31.0 */

    function create_fragment$H(ctx) {
    	let svg;
    	let path;
    	let polyline;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			polyline = svg_element("polyline");
    			attr(path, "d", "M22 11.08V12a10 10 0 1 1-5.93-9.14");
    			attr(polyline, "points", "22 4 12 14.01 9 11.01");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, polyline);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$H($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class CheckCircle extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$H, create_fragment$H, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/CheckSquare.svelte generated by Svelte v3.31.0 */

    function create_fragment$I(ctx) {
    	let svg;
    	let polyline;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline = svg_element("polyline");
    			path = svg_element("path");
    			attr(polyline, "points", "9 11 12 14 22 4");
    			attr(path, "d", "M21 12v7a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h11");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$I($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class CheckSquare extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$I, create_fragment$I, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Check.svelte generated by Svelte v3.31.0 */

    function create_fragment$J(ctx) {
    	let svg;
    	let polyline;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline = svg_element("polyline");
    			attr(polyline, "points", "20 6 9 17 4 12");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$J($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Check extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$J, create_fragment$J, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/ChevronDown.svelte generated by Svelte v3.31.0 */

    function create_fragment$K(ctx) {
    	let svg;
    	let polyline;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline = svg_element("polyline");
    			attr(polyline, "points", "6 9 12 15 18 9");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$K($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class ChevronDown extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$K, create_fragment$K, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/ChevronLeft.svelte generated by Svelte v3.31.0 */

    function create_fragment$L(ctx) {
    	let svg;
    	let polyline;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline = svg_element("polyline");
    			attr(polyline, "points", "15 18 9 12 15 6");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$L($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class ChevronLeft extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$L, create_fragment$L, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/ChevronRight.svelte generated by Svelte v3.31.0 */

    function create_fragment$M(ctx) {
    	let svg;
    	let polyline;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline = svg_element("polyline");
    			attr(polyline, "points", "9 18 15 12 9 6");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$M($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class ChevronRight extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$M, create_fragment$M, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/ChevronUp.svelte generated by Svelte v3.31.0 */

    function create_fragment$N(ctx) {
    	let svg;
    	let polyline;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline = svg_element("polyline");
    			attr(polyline, "points", "18 15 12 9 6 15");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$N($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class ChevronUp extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$N, create_fragment$N, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/ChevronsDown.svelte generated by Svelte v3.31.0 */

    function create_fragment$O(ctx) {
    	let svg;
    	let polyline0;
    	let polyline1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline0 = svg_element("polyline");
    			polyline1 = svg_element("polyline");
    			attr(polyline0, "points", "7 13 12 18 17 13");
    			attr(polyline1, "points", "7 6 12 11 17 6");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline0);
    			append(svg, polyline1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$O($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class ChevronsDown extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$O, create_fragment$O, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/ChevronsLeft.svelte generated by Svelte v3.31.0 */

    function create_fragment$P(ctx) {
    	let svg;
    	let polyline0;
    	let polyline1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline0 = svg_element("polyline");
    			polyline1 = svg_element("polyline");
    			attr(polyline0, "points", "11 17 6 12 11 7");
    			attr(polyline1, "points", "18 17 13 12 18 7");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline0);
    			append(svg, polyline1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$P($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class ChevronsLeft extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$P, create_fragment$P, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/ChevronsRight.svelte generated by Svelte v3.31.0 */

    function create_fragment$Q(ctx) {
    	let svg;
    	let polyline0;
    	let polyline1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline0 = svg_element("polyline");
    			polyline1 = svg_element("polyline");
    			attr(polyline0, "points", "13 17 18 12 13 7");
    			attr(polyline1, "points", "6 17 11 12 6 7");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline0);
    			append(svg, polyline1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$Q($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class ChevronsRight extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$Q, create_fragment$Q, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/ChevronsUp.svelte generated by Svelte v3.31.0 */

    function create_fragment$R(ctx) {
    	let svg;
    	let polyline0;
    	let polyline1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline0 = svg_element("polyline");
    			polyline1 = svg_element("polyline");
    			attr(polyline0, "points", "17 11 12 6 7 11");
    			attr(polyline1, "points", "17 18 12 13 7 18");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline0);
    			append(svg, polyline1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$R($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class ChevronsUp extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$R, create_fragment$R, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Chrome.svelte generated by Svelte v3.31.0 */

    function create_fragment$S(ctx) {
    	let svg;
    	let circle0;
    	let circle1;
    	let line0;
    	let line1;
    	let line2;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle0 = svg_element("circle");
    			circle1 = svg_element("circle");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			line2 = svg_element("line");
    			attr(circle0, "cx", "12");
    			attr(circle0, "cy", "12");
    			attr(circle0, "r", "10");
    			attr(circle1, "cx", "12");
    			attr(circle1, "cy", "12");
    			attr(circle1, "r", "4");
    			attr(line0, "x1", "21.17");
    			attr(line0, "y1", "8");
    			attr(line0, "x2", "12");
    			attr(line0, "y2", "8");
    			attr(line1, "x1", "3.95");
    			attr(line1, "y1", "6.06");
    			attr(line1, "x2", "8.54");
    			attr(line1, "y2", "14");
    			attr(line2, "x1", "10.88");
    			attr(line2, "y1", "21.94");
    			attr(line2, "x2", "15.46");
    			attr(line2, "y2", "14");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle0);
    			append(svg, circle1);
    			append(svg, line0);
    			append(svg, line1);
    			append(svg, line2);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$S($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Chrome extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$S, create_fragment$S, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Circle.svelte generated by Svelte v3.31.0 */

    function create_fragment$T(ctx) {
    	let svg;
    	let circle;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle = svg_element("circle");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "12");
    			attr(circle, "r", "10");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$T($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Circle extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$T, create_fragment$T, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Clipboard.svelte generated by Svelte v3.31.0 */

    function create_fragment$U(ctx) {
    	let svg;
    	let path;
    	let rect;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			rect = svg_element("rect");
    			attr(path, "d", "M16 4h2a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2V6a2 2 0 0 1 2-2h2");
    			attr(rect, "x", "8");
    			attr(rect, "y", "2");
    			attr(rect, "width", "8");
    			attr(rect, "height", "4");
    			attr(rect, "rx", "1");
    			attr(rect, "ry", "1");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, rect);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$U($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Clipboard extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$U, create_fragment$U, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Clock.svelte generated by Svelte v3.31.0 */

    function create_fragment$V(ctx) {
    	let svg;
    	let circle;
    	let polyline;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle = svg_element("circle");
    			polyline = svg_element("polyline");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "12");
    			attr(circle, "r", "10");
    			attr(polyline, "points", "12 6 12 12 16 14");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle);
    			append(svg, polyline);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$V($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Clock extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$V, create_fragment$V, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/CloudDrizzle.svelte generated by Svelte v3.31.0 */

    function create_fragment$W(ctx) {
    	let svg;
    	let line0;
    	let line1;
    	let line2;
    	let line3;
    	let line4;
    	let line5;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			line2 = svg_element("line");
    			line3 = svg_element("line");
    			line4 = svg_element("line");
    			line5 = svg_element("line");
    			path = svg_element("path");
    			attr(line0, "x1", "8");
    			attr(line0, "y1", "19");
    			attr(line0, "x2", "8");
    			attr(line0, "y2", "21");
    			attr(line1, "x1", "8");
    			attr(line1, "y1", "13");
    			attr(line1, "x2", "8");
    			attr(line1, "y2", "15");
    			attr(line2, "x1", "16");
    			attr(line2, "y1", "19");
    			attr(line2, "x2", "16");
    			attr(line2, "y2", "21");
    			attr(line3, "x1", "16");
    			attr(line3, "y1", "13");
    			attr(line3, "x2", "16");
    			attr(line3, "y2", "15");
    			attr(line4, "x1", "12");
    			attr(line4, "y1", "21");
    			attr(line4, "x2", "12");
    			attr(line4, "y2", "23");
    			attr(line5, "x1", "12");
    			attr(line5, "y1", "15");
    			attr(line5, "x2", "12");
    			attr(line5, "y2", "17");
    			attr(path, "d", "M20 16.58A5 5 0 0 0 18 7h-1.26A8 8 0 1 0 4 15.25");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, line0);
    			append(svg, line1);
    			append(svg, line2);
    			append(svg, line3);
    			append(svg, line4);
    			append(svg, line5);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$W($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class CloudDrizzle extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$W, create_fragment$W, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/CloudLightning.svelte generated by Svelte v3.31.0 */

    function create_fragment$X(ctx) {
    	let svg;
    	let path;
    	let polyline;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			polyline = svg_element("polyline");
    			attr(path, "d", "M19 16.9A5 5 0 0 0 18 7h-1.26a8 8 0 1 0-11.62 9");
    			attr(polyline, "points", "13 11 9 17 15 17 11 23");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, polyline);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$X($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class CloudLightning extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$X, create_fragment$X, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/CloudOff.svelte generated by Svelte v3.31.0 */

    function create_fragment$Y(ctx) {
    	let svg;
    	let path;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			line = svg_element("line");
    			attr(path, "d", "M22.61 16.95A5 5 0 0 0 18 10h-1.26a8 8 0 0 0-7.05-6M5 5a8 8 0 0 0 4 15h9a5 5 0 0 0 1.7-.3");
    			attr(line, "x1", "1");
    			attr(line, "y1", "1");
    			attr(line, "x2", "23");
    			attr(line, "y2", "23");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$Y($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class CloudOff extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$Y, create_fragment$Y, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/CloudRain.svelte generated by Svelte v3.31.0 */

    function create_fragment$Z(ctx) {
    	let svg;
    	let line0;
    	let line1;
    	let line2;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			line2 = svg_element("line");
    			path = svg_element("path");
    			attr(line0, "x1", "16");
    			attr(line0, "y1", "13");
    			attr(line0, "x2", "16");
    			attr(line0, "y2", "21");
    			attr(line1, "x1", "8");
    			attr(line1, "y1", "13");
    			attr(line1, "x2", "8");
    			attr(line1, "y2", "21");
    			attr(line2, "x1", "12");
    			attr(line2, "y1", "15");
    			attr(line2, "x2", "12");
    			attr(line2, "y2", "23");
    			attr(path, "d", "M20 16.58A5 5 0 0 0 18 7h-1.26A8 8 0 1 0 4 15.25");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, line0);
    			append(svg, line1);
    			append(svg, line2);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$Z($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class CloudRain extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$Z, create_fragment$Z, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/CloudSnow.svelte generated by Svelte v3.31.0 */

    function create_fragment$_(ctx) {
    	let svg;
    	let path;
    	let line0;
    	let line1;
    	let line2;
    	let line3;
    	let line4;
    	let line5;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			line2 = svg_element("line");
    			line3 = svg_element("line");
    			line4 = svg_element("line");
    			line5 = svg_element("line");
    			attr(path, "d", "M20 17.58A5 5 0 0 0 18 8h-1.26A8 8 0 1 0 4 16.25");
    			attr(line0, "x1", "8");
    			attr(line0, "y1", "16");
    			attr(line0, "x2", "8.01");
    			attr(line0, "y2", "16");
    			attr(line1, "x1", "8");
    			attr(line1, "y1", "20");
    			attr(line1, "x2", "8.01");
    			attr(line1, "y2", "20");
    			attr(line2, "x1", "12");
    			attr(line2, "y1", "18");
    			attr(line2, "x2", "12.01");
    			attr(line2, "y2", "18");
    			attr(line3, "x1", "12");
    			attr(line3, "y1", "22");
    			attr(line3, "x2", "12.01");
    			attr(line3, "y2", "22");
    			attr(line4, "x1", "16");
    			attr(line4, "y1", "16");
    			attr(line4, "x2", "16.01");
    			attr(line4, "y2", "16");
    			attr(line5, "x1", "16");
    			attr(line5, "y1", "20");
    			attr(line5, "x2", "16.01");
    			attr(line5, "y2", "20");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, line0);
    			append(svg, line1);
    			append(svg, line2);
    			append(svg, line3);
    			append(svg, line4);
    			append(svg, line5);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$_($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class CloudSnow extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$_, create_fragment$_, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Cloud.svelte generated by Svelte v3.31.0 */

    function create_fragment$$(ctx) {
    	let svg;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			attr(path, "d", "M18 10h-1.26A8 8 0 1 0 9 20h9a5 5 0 0 0 0-10z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$$($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Cloud extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$$, create_fragment$$, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Code.svelte generated by Svelte v3.31.0 */

    function create_fragment$10(ctx) {
    	let svg;
    	let polyline0;
    	let polyline1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline0 = svg_element("polyline");
    			polyline1 = svg_element("polyline");
    			attr(polyline0, "points", "16 18 22 12 16 6");
    			attr(polyline1, "points", "8 6 2 12 8 18");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline0);
    			append(svg, polyline1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$10($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Code extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$10, create_fragment$10, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Codepen.svelte generated by Svelte v3.31.0 */

    function create_fragment$11(ctx) {
    	let svg;
    	let polygon;
    	let line0;
    	let polyline0;
    	let polyline1;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polygon = svg_element("polygon");
    			line0 = svg_element("line");
    			polyline0 = svg_element("polyline");
    			polyline1 = svg_element("polyline");
    			line1 = svg_element("line");
    			attr(polygon, "points", "12 2 22 8.5 22 15.5 12 22 2 15.5 2 8.5 12 2");
    			attr(line0, "x1", "12");
    			attr(line0, "y1", "22");
    			attr(line0, "x2", "12");
    			attr(line0, "y2", "15.5");
    			attr(polyline0, "points", "22 8.5 12 15.5 2 8.5");
    			attr(polyline1, "points", "2 15.5 12 8.5 22 15.5");
    			attr(line1, "x1", "12");
    			attr(line1, "y1", "2");
    			attr(line1, "x2", "12");
    			attr(line1, "y2", "8.5");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polygon);
    			append(svg, line0);
    			append(svg, polyline0);
    			append(svg, polyline1);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$11($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Codepen extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$11, create_fragment$11, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Codesandbox.svelte generated by Svelte v3.31.0 */

    function create_fragment$12(ctx) {
    	let svg;
    	let path;
    	let polyline0;
    	let polyline1;
    	let polyline2;
    	let polyline3;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			polyline0 = svg_element("polyline");
    			polyline1 = svg_element("polyline");
    			polyline2 = svg_element("polyline");
    			polyline3 = svg_element("polyline");
    			line = svg_element("line");
    			attr(path, "d", "M21 16V8a2 2 0 0 0-1-1.73l-7-4a2 2 0 0 0-2 0l-7 4A2 2 0 0 0 3 8v8a2 2 0 0 0 1 1.73l7 4a2 2 0 0 0 2 0l7-4A2 2 0 0 0 21 16z");
    			attr(polyline0, "points", "7.5 4.21 12 6.81 16.5 4.21");
    			attr(polyline1, "points", "7.5 19.79 7.5 14.6 3 12");
    			attr(polyline2, "points", "21 12 16.5 14.6 16.5 19.79");
    			attr(polyline3, "points", "3.27 6.96 12 12.01 20.73 6.96");
    			attr(line, "x1", "12");
    			attr(line, "y1", "22.08");
    			attr(line, "x2", "12");
    			attr(line, "y2", "12");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, polyline0);
    			append(svg, polyline1);
    			append(svg, polyline2);
    			append(svg, polyline3);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$12($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Codesandbox extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$12, create_fragment$12, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Coffee.svelte generated by Svelte v3.31.0 */

    function create_fragment$13(ctx) {
    	let svg;
    	let path0;
    	let path1;
    	let line0;
    	let line1;
    	let line2;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path0 = svg_element("path");
    			path1 = svg_element("path");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			line2 = svg_element("line");
    			attr(path0, "d", "M18 8h1a4 4 0 0 1 0 8h-1");
    			attr(path1, "d", "M2 8h16v9a4 4 0 0 1-4 4H6a4 4 0 0 1-4-4V8z");
    			attr(line0, "x1", "6");
    			attr(line0, "y1", "1");
    			attr(line0, "x2", "6");
    			attr(line0, "y2", "4");
    			attr(line1, "x1", "10");
    			attr(line1, "y1", "1");
    			attr(line1, "x2", "10");
    			attr(line1, "y2", "4");
    			attr(line2, "x1", "14");
    			attr(line2, "y1", "1");
    			attr(line2, "x2", "14");
    			attr(line2, "y2", "4");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path0);
    			append(svg, path1);
    			append(svg, line0);
    			append(svg, line1);
    			append(svg, line2);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$13($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Coffee extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$13, create_fragment$13, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Columns.svelte generated by Svelte v3.31.0 */

    function create_fragment$14(ctx) {
    	let svg;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			attr(path, "d", "M12 3h7a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2h-7m0-18H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h7m0-18v18");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$14($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Columns extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$14, create_fragment$14, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Command.svelte generated by Svelte v3.31.0 */

    function create_fragment$15(ctx) {
    	let svg;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			attr(path, "d", "M18 3a3 3 0 0 0-3 3v12a3 3 0 0 0 3 3 3 3 0 0 0 3-3 3 3 0 0 0-3-3H6a3 3 0 0 0-3 3 3 3 0 0 0 3 3 3 3 0 0 0 3-3V6a3 3 0 0 0-3-3 3 3 0 0 0-3 3 3 3 0 0 0 3 3h12a3 3 0 0 0 3-3 3 3 0 0 0-3-3z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$15($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Command extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$15, create_fragment$15, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Compass.svelte generated by Svelte v3.31.0 */

    function create_fragment$16(ctx) {
    	let svg;
    	let circle;
    	let polygon;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle = svg_element("circle");
    			polygon = svg_element("polygon");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "12");
    			attr(circle, "r", "10");
    			attr(polygon, "points", "16.24 7.76 14.12 14.12 7.76 16.24 9.88 9.88 16.24 7.76");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle);
    			append(svg, polygon);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$16($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Compass extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$16, create_fragment$16, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Copy.svelte generated by Svelte v3.31.0 */

    function create_fragment$17(ctx) {
    	let svg;
    	let rect;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			rect = svg_element("rect");
    			path = svg_element("path");
    			attr(rect, "x", "9");
    			attr(rect, "y", "9");
    			attr(rect, "width", "13");
    			attr(rect, "height", "13");
    			attr(rect, "rx", "2");
    			attr(rect, "ry", "2");
    			attr(path, "d", "M5 15H4a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h9a2 2 0 0 1 2 2v1");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, rect);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$17($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Copy extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$17, create_fragment$17, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/CornerDownLeft.svelte generated by Svelte v3.31.0 */

    function create_fragment$18(ctx) {
    	let svg;
    	let polyline;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline = svg_element("polyline");
    			path = svg_element("path");
    			attr(polyline, "points", "9 10 4 15 9 20");
    			attr(path, "d", "M20 4v7a4 4 0 0 1-4 4H4");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$18($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class CornerDownLeft extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$18, create_fragment$18, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/CornerDownRight.svelte generated by Svelte v3.31.0 */

    function create_fragment$19(ctx) {
    	let svg;
    	let polyline;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline = svg_element("polyline");
    			path = svg_element("path");
    			attr(polyline, "points", "15 10 20 15 15 20");
    			attr(path, "d", "M4 4v7a4 4 0 0 0 4 4h12");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$19($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class CornerDownRight extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$19, create_fragment$19, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/CornerLeftDown.svelte generated by Svelte v3.31.0 */

    function create_fragment$1a(ctx) {
    	let svg;
    	let polyline;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline = svg_element("polyline");
    			path = svg_element("path");
    			attr(polyline, "points", "14 15 9 20 4 15");
    			attr(path, "d", "M20 4h-7a4 4 0 0 0-4 4v12");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1a($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class CornerLeftDown extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1a, create_fragment$1a, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/CornerLeftUp.svelte generated by Svelte v3.31.0 */

    function create_fragment$1b(ctx) {
    	let svg;
    	let polyline;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline = svg_element("polyline");
    			path = svg_element("path");
    			attr(polyline, "points", "14 9 9 4 4 9");
    			attr(path, "d", "M20 20h-7a4 4 0 0 1-4-4V4");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1b($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class CornerLeftUp extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1b, create_fragment$1b, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/CornerRightDown.svelte generated by Svelte v3.31.0 */

    function create_fragment$1c(ctx) {
    	let svg;
    	let polyline;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline = svg_element("polyline");
    			path = svg_element("path");
    			attr(polyline, "points", "10 15 15 20 20 15");
    			attr(path, "d", "M4 4h7a4 4 0 0 1 4 4v12");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1c($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class CornerRightDown extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1c, create_fragment$1c, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/CornerRightUp.svelte generated by Svelte v3.31.0 */

    function create_fragment$1d(ctx) {
    	let svg;
    	let polyline;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline = svg_element("polyline");
    			path = svg_element("path");
    			attr(polyline, "points", "10 9 15 4 20 9");
    			attr(path, "d", "M4 20h7a4 4 0 0 0 4-4V4");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1d($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class CornerRightUp extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1d, create_fragment$1d, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/CornerUpLeft.svelte generated by Svelte v3.31.0 */

    function create_fragment$1e(ctx) {
    	let svg;
    	let polyline;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline = svg_element("polyline");
    			path = svg_element("path");
    			attr(polyline, "points", "9 14 4 9 9 4");
    			attr(path, "d", "M20 20v-7a4 4 0 0 0-4-4H4");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1e($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class CornerUpLeft extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1e, create_fragment$1e, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/CornerUpRight.svelte generated by Svelte v3.31.0 */

    function create_fragment$1f(ctx) {
    	let svg;
    	let polyline;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline = svg_element("polyline");
    			path = svg_element("path");
    			attr(polyline, "points", "15 14 20 9 15 4");
    			attr(path, "d", "M4 20v-7a4 4 0 0 1 4-4h12");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1f($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class CornerUpRight extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1f, create_fragment$1f, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Cpu.svelte generated by Svelte v3.31.0 */

    function create_fragment$1g(ctx) {
    	let svg;
    	let rect0;
    	let rect1;
    	let line0;
    	let line1;
    	let line2;
    	let line3;
    	let line4;
    	let line5;
    	let line6;
    	let line7;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			rect0 = svg_element("rect");
    			rect1 = svg_element("rect");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			line2 = svg_element("line");
    			line3 = svg_element("line");
    			line4 = svg_element("line");
    			line5 = svg_element("line");
    			line6 = svg_element("line");
    			line7 = svg_element("line");
    			attr(rect0, "x", "4");
    			attr(rect0, "y", "4");
    			attr(rect0, "width", "16");
    			attr(rect0, "height", "16");
    			attr(rect0, "rx", "2");
    			attr(rect0, "ry", "2");
    			attr(rect1, "x", "9");
    			attr(rect1, "y", "9");
    			attr(rect1, "width", "6");
    			attr(rect1, "height", "6");
    			attr(line0, "x1", "9");
    			attr(line0, "y1", "1");
    			attr(line0, "x2", "9");
    			attr(line0, "y2", "4");
    			attr(line1, "x1", "15");
    			attr(line1, "y1", "1");
    			attr(line1, "x2", "15");
    			attr(line1, "y2", "4");
    			attr(line2, "x1", "9");
    			attr(line2, "y1", "20");
    			attr(line2, "x2", "9");
    			attr(line2, "y2", "23");
    			attr(line3, "x1", "15");
    			attr(line3, "y1", "20");
    			attr(line3, "x2", "15");
    			attr(line3, "y2", "23");
    			attr(line4, "x1", "20");
    			attr(line4, "y1", "9");
    			attr(line4, "x2", "23");
    			attr(line4, "y2", "9");
    			attr(line5, "x1", "20");
    			attr(line5, "y1", "14");
    			attr(line5, "x2", "23");
    			attr(line5, "y2", "14");
    			attr(line6, "x1", "1");
    			attr(line6, "y1", "9");
    			attr(line6, "x2", "4");
    			attr(line6, "y2", "9");
    			attr(line7, "x1", "1");
    			attr(line7, "y1", "14");
    			attr(line7, "x2", "4");
    			attr(line7, "y2", "14");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, rect0);
    			append(svg, rect1);
    			append(svg, line0);
    			append(svg, line1);
    			append(svg, line2);
    			append(svg, line3);
    			append(svg, line4);
    			append(svg, line5);
    			append(svg, line6);
    			append(svg, line7);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1g($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Cpu extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1g, create_fragment$1g, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/CreditCard.svelte generated by Svelte v3.31.0 */

    function create_fragment$1h(ctx) {
    	let svg;
    	let rect;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			rect = svg_element("rect");
    			line = svg_element("line");
    			attr(rect, "x", "1");
    			attr(rect, "y", "4");
    			attr(rect, "width", "22");
    			attr(rect, "height", "16");
    			attr(rect, "rx", "2");
    			attr(rect, "ry", "2");
    			attr(line, "x1", "1");
    			attr(line, "y1", "10");
    			attr(line, "x2", "23");
    			attr(line, "y2", "10");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, rect);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1h($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class CreditCard extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1h, create_fragment$1h, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Crop.svelte generated by Svelte v3.31.0 */

    function create_fragment$1i(ctx) {
    	let svg;
    	let path0;
    	let path1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path0 = svg_element("path");
    			path1 = svg_element("path");
    			attr(path0, "d", "M6.13 1L6 16a2 2 0 0 0 2 2h15");
    			attr(path1, "d", "M1 6.13L16 6a2 2 0 0 1 2 2v15");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path0);
    			append(svg, path1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1i($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Crop extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1i, create_fragment$1i, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Crosshair.svelte generated by Svelte v3.31.0 */

    function create_fragment$1j(ctx) {
    	let svg;
    	let circle;
    	let line0;
    	let line1;
    	let line2;
    	let line3;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle = svg_element("circle");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			line2 = svg_element("line");
    			line3 = svg_element("line");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "12");
    			attr(circle, "r", "10");
    			attr(line0, "x1", "22");
    			attr(line0, "y1", "12");
    			attr(line0, "x2", "18");
    			attr(line0, "y2", "12");
    			attr(line1, "x1", "6");
    			attr(line1, "y1", "12");
    			attr(line1, "x2", "2");
    			attr(line1, "y2", "12");
    			attr(line2, "x1", "12");
    			attr(line2, "y1", "6");
    			attr(line2, "x2", "12");
    			attr(line2, "y2", "2");
    			attr(line3, "x1", "12");
    			attr(line3, "y1", "22");
    			attr(line3, "x2", "12");
    			attr(line3, "y2", "18");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle);
    			append(svg, line0);
    			append(svg, line1);
    			append(svg, line2);
    			append(svg, line3);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1j($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Crosshair extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1j, create_fragment$1j, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Database.svelte generated by Svelte v3.31.0 */

    function create_fragment$1k(ctx) {
    	let svg;
    	let ellipse;
    	let path0;
    	let path1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			ellipse = svg_element("ellipse");
    			path0 = svg_element("path");
    			path1 = svg_element("path");
    			attr(ellipse, "cx", "12");
    			attr(ellipse, "cy", "5");
    			attr(ellipse, "rx", "9");
    			attr(ellipse, "ry", "3");
    			attr(path0, "d", "M21 12c0 1.66-4 3-9 3s-9-1.34-9-3");
    			attr(path1, "d", "M3 5v14c0 1.66 4 3 9 3s9-1.34 9-3V5");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, ellipse);
    			append(svg, path0);
    			append(svg, path1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1k($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Database extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1k, create_fragment$1k, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Delete.svelte generated by Svelte v3.31.0 */

    function create_fragment$1l(ctx) {
    	let svg;
    	let path;
    	let line0;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			attr(path, "d", "M21 4H8l-7 8 7 8h13a2 2 0 0 0 2-2V6a2 2 0 0 0-2-2z");
    			attr(line0, "x1", "18");
    			attr(line0, "y1", "9");
    			attr(line0, "x2", "12");
    			attr(line0, "y2", "15");
    			attr(line1, "x1", "12");
    			attr(line1, "y1", "9");
    			attr(line1, "x2", "18");
    			attr(line1, "y2", "15");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, line0);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1l($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Delete extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1l, create_fragment$1l, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Disc.svelte generated by Svelte v3.31.0 */

    function create_fragment$1m(ctx) {
    	let svg;
    	let circle0;
    	let circle1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle0 = svg_element("circle");
    			circle1 = svg_element("circle");
    			attr(circle0, "cx", "12");
    			attr(circle0, "cy", "12");
    			attr(circle0, "r", "10");
    			attr(circle1, "cx", "12");
    			attr(circle1, "cy", "12");
    			attr(circle1, "r", "3");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle0);
    			append(svg, circle1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1m($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Disc extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1m, create_fragment$1m, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/DivideCircle.svelte generated by Svelte v3.31.0 */

    function create_fragment$1n(ctx) {
    	let svg;
    	let line0;
    	let line1;
    	let line2;
    	let circle;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			line2 = svg_element("line");
    			circle = svg_element("circle");
    			attr(line0, "x1", "8");
    			attr(line0, "y1", "12");
    			attr(line0, "x2", "16");
    			attr(line0, "y2", "12");
    			attr(line1, "x1", "12");
    			attr(line1, "y1", "16");
    			attr(line1, "x2", "12");
    			attr(line1, "y2", "16");
    			attr(line2, "x1", "12");
    			attr(line2, "y1", "8");
    			attr(line2, "x2", "12");
    			attr(line2, "y2", "8");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "12");
    			attr(circle, "r", "10");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, line0);
    			append(svg, line1);
    			append(svg, line2);
    			append(svg, circle);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1n($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class DivideCircle extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1n, create_fragment$1n, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/DivideSquare.svelte generated by Svelte v3.31.0 */

    function create_fragment$1o(ctx) {
    	let svg;
    	let rect;
    	let line0;
    	let line1;
    	let line2;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			rect = svg_element("rect");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			line2 = svg_element("line");
    			attr(rect, "x", "3");
    			attr(rect, "y", "3");
    			attr(rect, "width", "18");
    			attr(rect, "height", "18");
    			attr(rect, "rx", "2");
    			attr(rect, "ry", "2");
    			attr(line0, "x1", "8");
    			attr(line0, "y1", "12");
    			attr(line0, "x2", "16");
    			attr(line0, "y2", "12");
    			attr(line1, "x1", "12");
    			attr(line1, "y1", "16");
    			attr(line1, "x2", "12");
    			attr(line1, "y2", "16");
    			attr(line2, "x1", "12");
    			attr(line2, "y1", "8");
    			attr(line2, "x2", "12");
    			attr(line2, "y2", "8");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, rect);
    			append(svg, line0);
    			append(svg, line1);
    			append(svg, line2);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1o($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class DivideSquare extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1o, create_fragment$1o, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Divide.svelte generated by Svelte v3.31.0 */

    function create_fragment$1p(ctx) {
    	let svg;
    	let circle0;
    	let line;
    	let circle1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle0 = svg_element("circle");
    			line = svg_element("line");
    			circle1 = svg_element("circle");
    			attr(circle0, "cx", "12");
    			attr(circle0, "cy", "6");
    			attr(circle0, "r", "2");
    			attr(line, "x1", "5");
    			attr(line, "y1", "12");
    			attr(line, "x2", "19");
    			attr(line, "y2", "12");
    			attr(circle1, "cx", "12");
    			attr(circle1, "cy", "18");
    			attr(circle1, "r", "2");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle0);
    			append(svg, line);
    			append(svg, circle1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1p($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Divide extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1p, create_fragment$1p, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/DollarSign.svelte generated by Svelte v3.31.0 */

    function create_fragment$1q(ctx) {
    	let svg;
    	let line;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			line = svg_element("line");
    			path = svg_element("path");
    			attr(line, "x1", "12");
    			attr(line, "y1", "1");
    			attr(line, "x2", "12");
    			attr(line, "y2", "23");
    			attr(path, "d", "M17 5H9.5a3.5 3.5 0 0 0 0 7h5a3.5 3.5 0 0 1 0 7H6");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, line);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1q($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class DollarSign extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1q, create_fragment$1q, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/DownloadCloud.svelte generated by Svelte v3.31.0 */

    function create_fragment$1r(ctx) {
    	let svg;
    	let polyline;
    	let line;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline = svg_element("polyline");
    			line = svg_element("line");
    			path = svg_element("path");
    			attr(polyline, "points", "8 17 12 21 16 17");
    			attr(line, "x1", "12");
    			attr(line, "y1", "12");
    			attr(line, "x2", "12");
    			attr(line, "y2", "21");
    			attr(path, "d", "M20.88 18.09A5 5 0 0 0 18 9h-1.26A8 8 0 1 0 3 16.29");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline);
    			append(svg, line);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1r($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class DownloadCloud extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1r, create_fragment$1r, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Download.svelte generated by Svelte v3.31.0 */

    function create_fragment$1s(ctx) {
    	let svg;
    	let path;
    	let polyline;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			polyline = svg_element("polyline");
    			line = svg_element("line");
    			attr(path, "d", "M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-4");
    			attr(polyline, "points", "7 10 12 15 17 10");
    			attr(line, "x1", "12");
    			attr(line, "y1", "15");
    			attr(line, "x2", "12");
    			attr(line, "y2", "3");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, polyline);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1s($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Download extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1s, create_fragment$1s, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Dribbble.svelte generated by Svelte v3.31.0 */

    function create_fragment$1t(ctx) {
    	let svg;
    	let circle;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle = svg_element("circle");
    			path = svg_element("path");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "12");
    			attr(circle, "r", "10");
    			attr(path, "d", "M8.56 2.75c4.37 6.03 6.02 9.42 8.03 17.72m2.54-15.38c-3.72 4.35-8.94 5.66-16.88 5.85m19.5 1.9c-3.5-.93-6.63-.82-8.94 0-2.58.92-5.01 2.86-7.44 6.32");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1t($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Dribbble extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1t, create_fragment$1t, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Droplet.svelte generated by Svelte v3.31.0 */

    function create_fragment$1u(ctx) {
    	let svg;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			attr(path, "d", "M12 2.69l5.66 5.66a8 8 0 1 1-11.31 0z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1u($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Droplet extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1u, create_fragment$1u, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Edit2.svelte generated by Svelte v3.31.0 */

    function create_fragment$1v(ctx) {
    	let svg;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			attr(path, "d", "M17 3a2.828 2.828 0 1 1 4 4L7.5 20.5 2 22l1.5-5.5L17 3z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1v($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Edit2 extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1v, create_fragment$1v, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Edit3.svelte generated by Svelte v3.31.0 */

    function create_fragment$1w(ctx) {
    	let svg;
    	let path0;
    	let path1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path0 = svg_element("path");
    			path1 = svg_element("path");
    			attr(path0, "d", "M12 20h9");
    			attr(path1, "d", "M16.5 3.5a2.121 2.121 0 0 1 3 3L7 19l-4 1 1-4L16.5 3.5z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path0);
    			append(svg, path1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1w($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Edit3 extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1w, create_fragment$1w, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Edit.svelte generated by Svelte v3.31.0 */

    function create_fragment$1x(ctx) {
    	let svg;
    	let path0;
    	let path1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path0 = svg_element("path");
    			path1 = svg_element("path");
    			attr(path0, "d", "M11 4H4a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h14a2 2 0 0 0 2-2v-7");
    			attr(path1, "d", "M18.5 2.5a2.121 2.121 0 0 1 3 3L12 15l-4 1 1-4 9.5-9.5z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path0);
    			append(svg, path1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1x($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Edit extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1x, create_fragment$1x, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/ExternalLink.svelte generated by Svelte v3.31.0 */

    function create_fragment$1y(ctx) {
    	let svg;
    	let path;
    	let polyline;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			polyline = svg_element("polyline");
    			line = svg_element("line");
    			attr(path, "d", "M18 13v6a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h6");
    			attr(polyline, "points", "15 3 21 3 21 9");
    			attr(line, "x1", "10");
    			attr(line, "y1", "14");
    			attr(line, "x2", "21");
    			attr(line, "y2", "3");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, polyline);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1y($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class ExternalLink extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1y, create_fragment$1y, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/EyeOff.svelte generated by Svelte v3.31.0 */

    function create_fragment$1z(ctx) {
    	let svg;
    	let path;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			line = svg_element("line");
    			attr(path, "d", "M17.94 17.94A10.07 10.07 0 0 1 12 20c-7 0-11-8-11-8a18.45 18.45 0 0 1 5.06-5.94M9.9 4.24A9.12 9.12 0 0 1 12 4c7 0 11 8 11 8a18.5 18.5 0 0 1-2.16 3.19m-6.72-1.07a3 3 0 1 1-4.24-4.24");
    			attr(line, "x1", "1");
    			attr(line, "y1", "1");
    			attr(line, "x2", "23");
    			attr(line, "y2", "23");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1z($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class EyeOff extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1z, create_fragment$1z, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Eye.svelte generated by Svelte v3.31.0 */

    function create_fragment$1A(ctx) {
    	let svg;
    	let path;
    	let circle;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			circle = svg_element("circle");
    			attr(path, "d", "M1 12s4-8 11-8 11 8 11 8-4 8-11 8-11-8-11-8z");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "12");
    			attr(circle, "r", "3");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, circle);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1A($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Eye extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1A, create_fragment$1A, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Facebook.svelte generated by Svelte v3.31.0 */

    function create_fragment$1B(ctx) {
    	let svg;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			attr(path, "d", "M18 2h-3a5 5 0 0 0-5 5v3H7v4h3v8h4v-8h3l1-4h-4V7a1 1 0 0 1 1-1h3z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1B($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Facebook extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1B, create_fragment$1B, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/FastForward.svelte generated by Svelte v3.31.0 */

    function create_fragment$1C(ctx) {
    	let svg;
    	let polygon0;
    	let polygon1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polygon0 = svg_element("polygon");
    			polygon1 = svg_element("polygon");
    			attr(polygon0, "points", "13 19 22 12 13 5 13 19");
    			attr(polygon1, "points", "2 19 11 12 2 5 2 19");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polygon0);
    			append(svg, polygon1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1C($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class FastForward extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1C, create_fragment$1C, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Feather.svelte generated by Svelte v3.31.0 */

    function create_fragment$1D(ctx) {
    	let svg;
    	let path;
    	let line0;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			attr(path, "d", "M20.24 12.24a6 6 0 0 0-8.49-8.49L5 10.5V19h8.5z");
    			attr(line0, "x1", "16");
    			attr(line0, "y1", "8");
    			attr(line0, "x2", "2");
    			attr(line0, "y2", "22");
    			attr(line1, "x1", "17.5");
    			attr(line1, "y1", "15");
    			attr(line1, "x2", "9");
    			attr(line1, "y2", "15");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, line0);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1D($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Feather extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1D, create_fragment$1D, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Figma.svelte generated by Svelte v3.31.0 */

    function create_fragment$1E(ctx) {
    	let svg;
    	let path0;
    	let path1;
    	let path2;
    	let path3;
    	let path4;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path0 = svg_element("path");
    			path1 = svg_element("path");
    			path2 = svg_element("path");
    			path3 = svg_element("path");
    			path4 = svg_element("path");
    			attr(path0, "d", "M5 5.5A3.5 3.5 0 0 1 8.5 2H12v7H8.5A3.5 3.5 0 0 1 5 5.5z");
    			attr(path1, "d", "M12 2h3.5a3.5 3.5 0 1 1 0 7H12V2z");
    			attr(path2, "d", "M12 12.5a3.5 3.5 0 1 1 7 0 3.5 3.5 0 1 1-7 0z");
    			attr(path3, "d", "M5 19.5A3.5 3.5 0 0 1 8.5 16H12v3.5a3.5 3.5 0 1 1-7 0z");
    			attr(path4, "d", "M5 12.5A3.5 3.5 0 0 1 8.5 9H12v7H8.5A3.5 3.5 0 0 1 5 12.5z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path0);
    			append(svg, path1);
    			append(svg, path2);
    			append(svg, path3);
    			append(svg, path4);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1E($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Figma extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1E, create_fragment$1E, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/FileMinus.svelte generated by Svelte v3.31.0 */

    function create_fragment$1F(ctx) {
    	let svg;
    	let path;
    	let polyline;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			polyline = svg_element("polyline");
    			line = svg_element("line");
    			attr(path, "d", "M14 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V8z");
    			attr(polyline, "points", "14 2 14 8 20 8");
    			attr(line, "x1", "9");
    			attr(line, "y1", "15");
    			attr(line, "x2", "15");
    			attr(line, "y2", "15");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, polyline);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1F($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class FileMinus extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1F, create_fragment$1F, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/FilePlus.svelte generated by Svelte v3.31.0 */

    function create_fragment$1G(ctx) {
    	let svg;
    	let path;
    	let polyline;
    	let line0;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			polyline = svg_element("polyline");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			attr(path, "d", "M14 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V8z");
    			attr(polyline, "points", "14 2 14 8 20 8");
    			attr(line0, "x1", "12");
    			attr(line0, "y1", "18");
    			attr(line0, "x2", "12");
    			attr(line0, "y2", "12");
    			attr(line1, "x1", "9");
    			attr(line1, "y1", "15");
    			attr(line1, "x2", "15");
    			attr(line1, "y2", "15");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, polyline);
    			append(svg, line0);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1G($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class FilePlus extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1G, create_fragment$1G, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/FileText.svelte generated by Svelte v3.31.0 */

    function create_fragment$1H(ctx) {
    	let svg;
    	let path;
    	let polyline0;
    	let line0;
    	let line1;
    	let polyline1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			polyline0 = svg_element("polyline");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			polyline1 = svg_element("polyline");
    			attr(path, "d", "M14 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V8z");
    			attr(polyline0, "points", "14 2 14 8 20 8");
    			attr(line0, "x1", "16");
    			attr(line0, "y1", "13");
    			attr(line0, "x2", "8");
    			attr(line0, "y2", "13");
    			attr(line1, "x1", "16");
    			attr(line1, "y1", "17");
    			attr(line1, "x2", "8");
    			attr(line1, "y2", "17");
    			attr(polyline1, "points", "10 9 9 9 8 9");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, polyline0);
    			append(svg, line0);
    			append(svg, line1);
    			append(svg, polyline1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1H($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class FileText extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1H, create_fragment$1H, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/File.svelte generated by Svelte v3.31.0 */

    function create_fragment$1I(ctx) {
    	let svg;
    	let path;
    	let polyline;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			polyline = svg_element("polyline");
    			attr(path, "d", "M13 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V9z");
    			attr(polyline, "points", "13 2 13 9 20 9");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, polyline);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1I($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class File extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1I, create_fragment$1I, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Film.svelte generated by Svelte v3.31.0 */

    function create_fragment$1J(ctx) {
    	let svg;
    	let rect;
    	let line0;
    	let line1;
    	let line2;
    	let line3;
    	let line4;
    	let line5;
    	let line6;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			rect = svg_element("rect");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			line2 = svg_element("line");
    			line3 = svg_element("line");
    			line4 = svg_element("line");
    			line5 = svg_element("line");
    			line6 = svg_element("line");
    			attr(rect, "x", "2");
    			attr(rect, "y", "2");
    			attr(rect, "width", "20");
    			attr(rect, "height", "20");
    			attr(rect, "rx", "2.18");
    			attr(rect, "ry", "2.18");
    			attr(line0, "x1", "7");
    			attr(line0, "y1", "2");
    			attr(line0, "x2", "7");
    			attr(line0, "y2", "22");
    			attr(line1, "x1", "17");
    			attr(line1, "y1", "2");
    			attr(line1, "x2", "17");
    			attr(line1, "y2", "22");
    			attr(line2, "x1", "2");
    			attr(line2, "y1", "12");
    			attr(line2, "x2", "22");
    			attr(line2, "y2", "12");
    			attr(line3, "x1", "2");
    			attr(line3, "y1", "7");
    			attr(line3, "x2", "7");
    			attr(line3, "y2", "7");
    			attr(line4, "x1", "2");
    			attr(line4, "y1", "17");
    			attr(line4, "x2", "7");
    			attr(line4, "y2", "17");
    			attr(line5, "x1", "17");
    			attr(line5, "y1", "17");
    			attr(line5, "x2", "22");
    			attr(line5, "y2", "17");
    			attr(line6, "x1", "17");
    			attr(line6, "y1", "7");
    			attr(line6, "x2", "22");
    			attr(line6, "y2", "7");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, rect);
    			append(svg, line0);
    			append(svg, line1);
    			append(svg, line2);
    			append(svg, line3);
    			append(svg, line4);
    			append(svg, line5);
    			append(svg, line6);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1J($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Film extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1J, create_fragment$1J, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Filter.svelte generated by Svelte v3.31.0 */

    function create_fragment$1K(ctx) {
    	let svg;
    	let polygon;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polygon = svg_element("polygon");
    			attr(polygon, "points", "22 3 2 3 10 12.46 10 19 14 21 14 12.46 22 3");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polygon);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1K($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Filter extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1K, create_fragment$1K, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Flag.svelte generated by Svelte v3.31.0 */

    function create_fragment$1L(ctx) {
    	let svg;
    	let path;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			line = svg_element("line");
    			attr(path, "d", "M4 15s1-1 4-1 5 2 8 2 4-1 4-1V3s-1 1-4 1-5-2-8-2-4 1-4 1z");
    			attr(line, "x1", "4");
    			attr(line, "y1", "22");
    			attr(line, "x2", "4");
    			attr(line, "y2", "15");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1L($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Flag extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1L, create_fragment$1L, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/FolderMinus.svelte generated by Svelte v3.31.0 */

    function create_fragment$1M(ctx) {
    	let svg;
    	let path;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			line = svg_element("line");
    			attr(path, "d", "M22 19a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h5l2 3h9a2 2 0 0 1 2 2z");
    			attr(line, "x1", "9");
    			attr(line, "y1", "14");
    			attr(line, "x2", "15");
    			attr(line, "y2", "14");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1M($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class FolderMinus extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1M, create_fragment$1M, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/FolderPlus.svelte generated by Svelte v3.31.0 */

    function create_fragment$1N(ctx) {
    	let svg;
    	let path;
    	let line0;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			attr(path, "d", "M22 19a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h5l2 3h9a2 2 0 0 1 2 2z");
    			attr(line0, "x1", "12");
    			attr(line0, "y1", "11");
    			attr(line0, "x2", "12");
    			attr(line0, "y2", "17");
    			attr(line1, "x1", "9");
    			attr(line1, "y1", "14");
    			attr(line1, "x2", "15");
    			attr(line1, "y2", "14");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, line0);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1N($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class FolderPlus extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1N, create_fragment$1N, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Folder.svelte generated by Svelte v3.31.0 */

    function create_fragment$1O(ctx) {
    	let svg;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			attr(path, "d", "M22 19a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h5l2 3h9a2 2 0 0 1 2 2z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1O($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Folder extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1O, create_fragment$1O, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Framer.svelte generated by Svelte v3.31.0 */

    function create_fragment$1P(ctx) {
    	let svg;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			attr(path, "d", "M5 16V9h14V2H5l14 14h-7m-7 0l7 7v-7m-7 0h7");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1P($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Framer extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1P, create_fragment$1P, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Frown.svelte generated by Svelte v3.31.0 */

    function create_fragment$1Q(ctx) {
    	let svg;
    	let circle;
    	let path;
    	let line0;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle = svg_element("circle");
    			path = svg_element("path");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "12");
    			attr(circle, "r", "10");
    			attr(path, "d", "M16 16s-1.5-2-4-2-4 2-4 2");
    			attr(line0, "x1", "9");
    			attr(line0, "y1", "9");
    			attr(line0, "x2", "9.01");
    			attr(line0, "y2", "9");
    			attr(line1, "x1", "15");
    			attr(line1, "y1", "9");
    			attr(line1, "x2", "15.01");
    			attr(line1, "y2", "9");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle);
    			append(svg, path);
    			append(svg, line0);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1Q($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Frown extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1Q, create_fragment$1Q, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Gift.svelte generated by Svelte v3.31.0 */

    function create_fragment$1R(ctx) {
    	let svg;
    	let polyline;
    	let rect;
    	let line;
    	let path0;
    	let path1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline = svg_element("polyline");
    			rect = svg_element("rect");
    			line = svg_element("line");
    			path0 = svg_element("path");
    			path1 = svg_element("path");
    			attr(polyline, "points", "20 12 20 22 4 22 4 12");
    			attr(rect, "x", "2");
    			attr(rect, "y", "7");
    			attr(rect, "width", "20");
    			attr(rect, "height", "5");
    			attr(line, "x1", "12");
    			attr(line, "y1", "22");
    			attr(line, "x2", "12");
    			attr(line, "y2", "7");
    			attr(path0, "d", "M12 7H7.5a2.5 2.5 0 0 1 0-5C11 2 12 7 12 7z");
    			attr(path1, "d", "M12 7h4.5a2.5 2.5 0 0 0 0-5C13 2 12 7 12 7z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline);
    			append(svg, rect);
    			append(svg, line);
    			append(svg, path0);
    			append(svg, path1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1R($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Gift extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1R, create_fragment$1R, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/GitBranch.svelte generated by Svelte v3.31.0 */

    function create_fragment$1S(ctx) {
    	let svg;
    	let line;
    	let circle0;
    	let circle1;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			line = svg_element("line");
    			circle0 = svg_element("circle");
    			circle1 = svg_element("circle");
    			path = svg_element("path");
    			attr(line, "x1", "6");
    			attr(line, "y1", "3");
    			attr(line, "x2", "6");
    			attr(line, "y2", "15");
    			attr(circle0, "cx", "18");
    			attr(circle0, "cy", "6");
    			attr(circle0, "r", "3");
    			attr(circle1, "cx", "6");
    			attr(circle1, "cy", "18");
    			attr(circle1, "r", "3");
    			attr(path, "d", "M18 9a9 9 0 0 1-9 9");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, line);
    			append(svg, circle0);
    			append(svg, circle1);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1S($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class GitBranch extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1S, create_fragment$1S, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/GitCommit.svelte generated by Svelte v3.31.0 */

    function create_fragment$1T(ctx) {
    	let svg;
    	let circle;
    	let line0;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle = svg_element("circle");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "12");
    			attr(circle, "r", "4");
    			attr(line0, "x1", "1.05");
    			attr(line0, "y1", "12");
    			attr(line0, "x2", "7");
    			attr(line0, "y2", "12");
    			attr(line1, "x1", "17.01");
    			attr(line1, "y1", "12");
    			attr(line1, "x2", "22.96");
    			attr(line1, "y2", "12");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle);
    			append(svg, line0);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1T($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class GitCommit extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1T, create_fragment$1T, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/GitMerge.svelte generated by Svelte v3.31.0 */

    function create_fragment$1U(ctx) {
    	let svg;
    	let circle0;
    	let circle1;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle0 = svg_element("circle");
    			circle1 = svg_element("circle");
    			path = svg_element("path");
    			attr(circle0, "cx", "18");
    			attr(circle0, "cy", "18");
    			attr(circle0, "r", "3");
    			attr(circle1, "cx", "6");
    			attr(circle1, "cy", "6");
    			attr(circle1, "r", "3");
    			attr(path, "d", "M6 21V9a9 9 0 0 0 9 9");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle0);
    			append(svg, circle1);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1U($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class GitMerge extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1U, create_fragment$1U, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/GitPullRequest.svelte generated by Svelte v3.31.0 */

    function create_fragment$1V(ctx) {
    	let svg;
    	let circle0;
    	let circle1;
    	let path;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle0 = svg_element("circle");
    			circle1 = svg_element("circle");
    			path = svg_element("path");
    			line = svg_element("line");
    			attr(circle0, "cx", "18");
    			attr(circle0, "cy", "18");
    			attr(circle0, "r", "3");
    			attr(circle1, "cx", "6");
    			attr(circle1, "cy", "6");
    			attr(circle1, "r", "3");
    			attr(path, "d", "M13 6h3a2 2 0 0 1 2 2v7");
    			attr(line, "x1", "6");
    			attr(line, "y1", "9");
    			attr(line, "x2", "6");
    			attr(line, "y2", "21");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle0);
    			append(svg, circle1);
    			append(svg, path);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1V($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class GitPullRequest extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1V, create_fragment$1V, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/GitHub.svelte generated by Svelte v3.31.0 */

    function create_fragment$1W(ctx) {
    	let svg;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			attr(path, "d", "M9 19c-5 1.5-5-2.5-7-3m14 6v-3.87a3.37 3.37 0 0 0-.94-2.61c3.14-.35 6.44-1.54 6.44-7A5.44 5.44 0 0 0 20 4.77 5.07 5.07 0 0 0 19.91 1S18.73.65 16 2.48a13.38 13.38 0 0 0-7 0C6.27.65 5.09 1 5.09 1A5.07 5.07 0 0 0 5 4.77a5.44 5.44 0 0 0-1.5 3.78c0 5.42 3.3 6.61 6.44 7A3.37 3.37 0 0 0 9 18.13V22");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1W($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class GitHub extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1W, create_fragment$1W, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/GitLab.svelte generated by Svelte v3.31.0 */

    function create_fragment$1X(ctx) {
    	let svg;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			attr(path, "d", "M22.65 14.39L12 22.13 1.35 14.39a.84.84 0 0 1-.3-.94l1.22-3.78 2.44-7.51A.42.42 0 0 1 4.82 2a.43.43 0 0 1 .58 0 .42.42 0 0 1 .11.18l2.44 7.49h8.1l2.44-7.51A.42.42 0 0 1 18.6 2a.43.43 0 0 1 .58 0 .42.42 0 0 1 .11.18l2.44 7.51L23 13.45a.84.84 0 0 1-.35.94z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1X($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class GitLab extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1X, create_fragment$1X, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Globe.svelte generated by Svelte v3.31.0 */

    function create_fragment$1Y(ctx) {
    	let svg;
    	let circle;
    	let line;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle = svg_element("circle");
    			line = svg_element("line");
    			path = svg_element("path");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "12");
    			attr(circle, "r", "10");
    			attr(line, "x1", "2");
    			attr(line, "y1", "12");
    			attr(line, "x2", "22");
    			attr(line, "y2", "12");
    			attr(path, "d", "M12 2a15.3 15.3 0 0 1 4 10 15.3 15.3 0 0 1-4 10 15.3 15.3 0 0 1-4-10 15.3 15.3 0 0 1 4-10z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle);
    			append(svg, line);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1Y($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Globe extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1Y, create_fragment$1Y, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Grid.svelte generated by Svelte v3.31.0 */

    function create_fragment$1Z(ctx) {
    	let svg;
    	let rect0;
    	let rect1;
    	let rect2;
    	let rect3;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			rect0 = svg_element("rect");
    			rect1 = svg_element("rect");
    			rect2 = svg_element("rect");
    			rect3 = svg_element("rect");
    			attr(rect0, "x", "3");
    			attr(rect0, "y", "3");
    			attr(rect0, "width", "7");
    			attr(rect0, "height", "7");
    			attr(rect1, "x", "14");
    			attr(rect1, "y", "3");
    			attr(rect1, "width", "7");
    			attr(rect1, "height", "7");
    			attr(rect2, "x", "14");
    			attr(rect2, "y", "14");
    			attr(rect2, "width", "7");
    			attr(rect2, "height", "7");
    			attr(rect3, "x", "3");
    			attr(rect3, "y", "14");
    			attr(rect3, "width", "7");
    			attr(rect3, "height", "7");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, rect0);
    			append(svg, rect1);
    			append(svg, rect2);
    			append(svg, rect3);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1Z($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Grid extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1Z, create_fragment$1Z, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/HardDrive.svelte generated by Svelte v3.31.0 */

    function create_fragment$1_(ctx) {
    	let svg;
    	let line0;
    	let path;
    	let line1;
    	let line2;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			line0 = svg_element("line");
    			path = svg_element("path");
    			line1 = svg_element("line");
    			line2 = svg_element("line");
    			attr(line0, "x1", "22");
    			attr(line0, "y1", "12");
    			attr(line0, "x2", "2");
    			attr(line0, "y2", "12");
    			attr(path, "d", "M5.45 5.11L2 12v6a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2v-6l-3.45-6.89A2 2 0 0 0 16.76 4H7.24a2 2 0 0 0-1.79 1.11z");
    			attr(line1, "x1", "6");
    			attr(line1, "y1", "16");
    			attr(line1, "x2", "6.01");
    			attr(line1, "y2", "16");
    			attr(line2, "x1", "10");
    			attr(line2, "y1", "16");
    			attr(line2, "x2", "10.01");
    			attr(line2, "y2", "16");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, line0);
    			append(svg, path);
    			append(svg, line1);
    			append(svg, line2);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1_($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class HardDrive extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1_, create_fragment$1_, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Hash.svelte generated by Svelte v3.31.0 */

    function create_fragment$1$(ctx) {
    	let svg;
    	let line0;
    	let line1;
    	let line2;
    	let line3;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			line2 = svg_element("line");
    			line3 = svg_element("line");
    			attr(line0, "x1", "4");
    			attr(line0, "y1", "9");
    			attr(line0, "x2", "20");
    			attr(line0, "y2", "9");
    			attr(line1, "x1", "4");
    			attr(line1, "y1", "15");
    			attr(line1, "x2", "20");
    			attr(line1, "y2", "15");
    			attr(line2, "x1", "10");
    			attr(line2, "y1", "3");
    			attr(line2, "x2", "8");
    			attr(line2, "y2", "21");
    			attr(line3, "x1", "16");
    			attr(line3, "y1", "3");
    			attr(line3, "x2", "14");
    			attr(line3, "y2", "21");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, line0);
    			append(svg, line1);
    			append(svg, line2);
    			append(svg, line3);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$1$($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Hash extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$1$, create_fragment$1$, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Headphones.svelte generated by Svelte v3.31.0 */

    function create_fragment$20(ctx) {
    	let svg;
    	let path0;
    	let path1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path0 = svg_element("path");
    			path1 = svg_element("path");
    			attr(path0, "d", "M3 18v-6a9 9 0 0 1 18 0v6");
    			attr(path1, "d", "M21 19a2 2 0 0 1-2 2h-1a2 2 0 0 1-2-2v-3a2 2 0 0 1 2-2h3zM3 19a2 2 0 0 0 2 2h1a2 2 0 0 0 2-2v-3a2 2 0 0 0-2-2H3z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path0);
    			append(svg, path1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$20($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Headphones extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$20, create_fragment$20, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Heart.svelte generated by Svelte v3.31.0 */

    function create_fragment$21(ctx) {
    	let svg;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			attr(path, "d", "M20.84 4.61a5.5 5.5 0 0 0-7.78 0L12 5.67l-1.06-1.06a5.5 5.5 0 0 0-7.78 7.78l1.06 1.06L12 21.23l7.78-7.78 1.06-1.06a5.5 5.5 0 0 0 0-7.78z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$21($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Heart extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$21, create_fragment$21, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/HelpCircle.svelte generated by Svelte v3.31.0 */

    function create_fragment$22(ctx) {
    	let svg;
    	let circle;
    	let path;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle = svg_element("circle");
    			path = svg_element("path");
    			line = svg_element("line");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "12");
    			attr(circle, "r", "10");
    			attr(path, "d", "M9.09 9a3 3 0 0 1 5.83 1c0 2-3 3-3 3");
    			attr(line, "x1", "12");
    			attr(line, "y1", "17");
    			attr(line, "x2", "12.01");
    			attr(line, "y2", "17");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle);
    			append(svg, path);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$22($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class HelpCircle extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$22, create_fragment$22, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Hexagon.svelte generated by Svelte v3.31.0 */

    function create_fragment$23(ctx) {
    	let svg;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			attr(path, "d", "M21 16V8a2 2 0 0 0-1-1.73l-7-4a2 2 0 0 0-2 0l-7 4A2 2 0 0 0 3 8v8a2 2 0 0 0 1 1.73l7 4a2 2 0 0 0 2 0l7-4A2 2 0 0 0 21 16z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$23($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Hexagon extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$23, create_fragment$23, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Home.svelte generated by Svelte v3.31.0 */

    function create_fragment$24(ctx) {
    	let svg;
    	let path;
    	let polyline;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			polyline = svg_element("polyline");
    			attr(path, "d", "M3 9l9-7 9 7v11a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2z");
    			attr(polyline, "points", "9 22 9 12 15 12 15 22");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, polyline);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$24($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Home extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$24, create_fragment$24, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Image.svelte generated by Svelte v3.31.0 */

    function create_fragment$25(ctx) {
    	let svg;
    	let rect;
    	let circle;
    	let polyline;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			rect = svg_element("rect");
    			circle = svg_element("circle");
    			polyline = svg_element("polyline");
    			attr(rect, "x", "3");
    			attr(rect, "y", "3");
    			attr(rect, "width", "18");
    			attr(rect, "height", "18");
    			attr(rect, "rx", "2");
    			attr(rect, "ry", "2");
    			attr(circle, "cx", "8.5");
    			attr(circle, "cy", "8.5");
    			attr(circle, "r", "1.5");
    			attr(polyline, "points", "21 15 16 10 5 21");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, rect);
    			append(svg, circle);
    			append(svg, polyline);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$25($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Image extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$25, create_fragment$25, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Inbox.svelte generated by Svelte v3.31.0 */

    function create_fragment$26(ctx) {
    	let svg;
    	let polyline;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline = svg_element("polyline");
    			path = svg_element("path");
    			attr(polyline, "points", "22 12 16 12 14 15 10 15 8 12 2 12");
    			attr(path, "d", "M5.45 5.11L2 12v6a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2v-6l-3.45-6.89A2 2 0 0 0 16.76 4H7.24a2 2 0 0 0-1.79 1.11z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$26($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Inbox extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$26, create_fragment$26, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Info.svelte generated by Svelte v3.31.0 */

    function create_fragment$27(ctx) {
    	let svg;
    	let circle;
    	let line0;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle = svg_element("circle");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "12");
    			attr(circle, "r", "10");
    			attr(line0, "x1", "12");
    			attr(line0, "y1", "16");
    			attr(line0, "x2", "12");
    			attr(line0, "y2", "12");
    			attr(line1, "x1", "12");
    			attr(line1, "y1", "8");
    			attr(line1, "x2", "12.01");
    			attr(line1, "y2", "8");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle);
    			append(svg, line0);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$27($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Info extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$27, create_fragment$27, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Instagram.svelte generated by Svelte v3.31.0 */

    function create_fragment$28(ctx) {
    	let svg;
    	let rect;
    	let path;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			rect = svg_element("rect");
    			path = svg_element("path");
    			line = svg_element("line");
    			attr(rect, "x", "2");
    			attr(rect, "y", "2");
    			attr(rect, "width", "20");
    			attr(rect, "height", "20");
    			attr(rect, "rx", "5");
    			attr(rect, "ry", "5");
    			attr(path, "d", "M16 11.37A4 4 0 1 1 12.63 8 4 4 0 0 1 16 11.37z");
    			attr(line, "x1", "17.5");
    			attr(line, "y1", "6.5");
    			attr(line, "x2", "17.51");
    			attr(line, "y2", "6.5");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, rect);
    			append(svg, path);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$28($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Instagram extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$28, create_fragment$28, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Italic.svelte generated by Svelte v3.31.0 */

    function create_fragment$29(ctx) {
    	let svg;
    	let line0;
    	let line1;
    	let line2;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			line2 = svg_element("line");
    			attr(line0, "x1", "19");
    			attr(line0, "y1", "4");
    			attr(line0, "x2", "10");
    			attr(line0, "y2", "4");
    			attr(line1, "x1", "14");
    			attr(line1, "y1", "20");
    			attr(line1, "x2", "5");
    			attr(line1, "y2", "20");
    			attr(line2, "x1", "15");
    			attr(line2, "y1", "4");
    			attr(line2, "x2", "9");
    			attr(line2, "y2", "20");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, line0);
    			append(svg, line1);
    			append(svg, line2);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$29($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Italic extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$29, create_fragment$29, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Key.svelte generated by Svelte v3.31.0 */

    function create_fragment$2a(ctx) {
    	let svg;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			attr(path, "d", "M21 2l-2 2m-7.61 7.61a5.5 5.5 0 1 1-7.778 7.778 5.5 5.5 0 0 1 7.777-7.777zm0 0L15.5 7.5m0 0l3 3L22 7l-3-3m-3.5 3.5L19 4");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2a($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Key extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2a, create_fragment$2a, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Layers.svelte generated by Svelte v3.31.0 */

    function create_fragment$2b(ctx) {
    	let svg;
    	let polygon;
    	let polyline0;
    	let polyline1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polygon = svg_element("polygon");
    			polyline0 = svg_element("polyline");
    			polyline1 = svg_element("polyline");
    			attr(polygon, "points", "12 2 2 7 12 12 22 7 12 2");
    			attr(polyline0, "points", "2 17 12 22 22 17");
    			attr(polyline1, "points", "2 12 12 17 22 12");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polygon);
    			append(svg, polyline0);
    			append(svg, polyline1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2b($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Layers extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2b, create_fragment$2b, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Layout.svelte generated by Svelte v3.31.0 */

    function create_fragment$2c(ctx) {
    	let svg;
    	let rect;
    	let line0;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			rect = svg_element("rect");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			attr(rect, "x", "3");
    			attr(rect, "y", "3");
    			attr(rect, "width", "18");
    			attr(rect, "height", "18");
    			attr(rect, "rx", "2");
    			attr(rect, "ry", "2");
    			attr(line0, "x1", "3");
    			attr(line0, "y1", "9");
    			attr(line0, "x2", "21");
    			attr(line0, "y2", "9");
    			attr(line1, "x1", "9");
    			attr(line1, "y1", "21");
    			attr(line1, "x2", "9");
    			attr(line1, "y2", "9");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, rect);
    			append(svg, line0);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2c($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Layout extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2c, create_fragment$2c, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/LifeBuoy.svelte generated by Svelte v3.31.0 */

    function create_fragment$2d(ctx) {
    	let svg;
    	let circle0;
    	let circle1;
    	let line0;
    	let line1;
    	let line2;
    	let line3;
    	let line4;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle0 = svg_element("circle");
    			circle1 = svg_element("circle");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			line2 = svg_element("line");
    			line3 = svg_element("line");
    			line4 = svg_element("line");
    			attr(circle0, "cx", "12");
    			attr(circle0, "cy", "12");
    			attr(circle0, "r", "10");
    			attr(circle1, "cx", "12");
    			attr(circle1, "cy", "12");
    			attr(circle1, "r", "4");
    			attr(line0, "x1", "4.93");
    			attr(line0, "y1", "4.93");
    			attr(line0, "x2", "9.17");
    			attr(line0, "y2", "9.17");
    			attr(line1, "x1", "14.83");
    			attr(line1, "y1", "14.83");
    			attr(line1, "x2", "19.07");
    			attr(line1, "y2", "19.07");
    			attr(line2, "x1", "14.83");
    			attr(line2, "y1", "9.17");
    			attr(line2, "x2", "19.07");
    			attr(line2, "y2", "4.93");
    			attr(line3, "x1", "14.83");
    			attr(line3, "y1", "9.17");
    			attr(line3, "x2", "18.36");
    			attr(line3, "y2", "5.64");
    			attr(line4, "x1", "4.93");
    			attr(line4, "y1", "19.07");
    			attr(line4, "x2", "9.17");
    			attr(line4, "y2", "14.83");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle0);
    			append(svg, circle1);
    			append(svg, line0);
    			append(svg, line1);
    			append(svg, line2);
    			append(svg, line3);
    			append(svg, line4);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2d($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class LifeBuoy extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2d, create_fragment$2d, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Link2.svelte generated by Svelte v3.31.0 */

    function create_fragment$2e(ctx) {
    	let svg;
    	let path;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			line = svg_element("line");
    			attr(path, "d", "M15 7h3a5 5 0 0 1 5 5 5 5 0 0 1-5 5h-3m-6 0H6a5 5 0 0 1-5-5 5 5 0 0 1 5-5h3");
    			attr(line, "x1", "8");
    			attr(line, "y1", "12");
    			attr(line, "x2", "16");
    			attr(line, "y2", "12");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2e($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Link2 extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2e, create_fragment$2e, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Link.svelte generated by Svelte v3.31.0 */

    function create_fragment$2f(ctx) {
    	let svg;
    	let path0;
    	let path1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path0 = svg_element("path");
    			path1 = svg_element("path");
    			attr(path0, "d", "M10 13a5 5 0 0 0 7.54.54l3-3a5 5 0 0 0-7.07-7.07l-1.72 1.71");
    			attr(path1, "d", "M14 11a5 5 0 0 0-7.54-.54l-3 3a5 5 0 0 0 7.07 7.07l1.71-1.71");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path0);
    			append(svg, path1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2f($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Link extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2f, create_fragment$2f, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Linkedin.svelte generated by Svelte v3.31.0 */

    function create_fragment$2g(ctx) {
    	let svg;
    	let path;
    	let rect;
    	let circle;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			rect = svg_element("rect");
    			circle = svg_element("circle");
    			attr(path, "d", "M16 8a6 6 0 0 1 6 6v7h-4v-7a2 2 0 0 0-2-2 2 2 0 0 0-2 2v7h-4v-7a6 6 0 0 1 6-6z");
    			attr(rect, "x", "2");
    			attr(rect, "y", "9");
    			attr(rect, "width", "4");
    			attr(rect, "height", "12");
    			attr(circle, "cx", "4");
    			attr(circle, "cy", "4");
    			attr(circle, "r", "2");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, rect);
    			append(svg, circle);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2g($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Linkedin extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2g, create_fragment$2g, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/List.svelte generated by Svelte v3.31.0 */

    function create_fragment$2h(ctx) {
    	let svg;
    	let line0;
    	let line1;
    	let line2;
    	let line3;
    	let line4;
    	let line5;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			line2 = svg_element("line");
    			line3 = svg_element("line");
    			line4 = svg_element("line");
    			line5 = svg_element("line");
    			attr(line0, "x1", "8");
    			attr(line0, "y1", "6");
    			attr(line0, "x2", "21");
    			attr(line0, "y2", "6");
    			attr(line1, "x1", "8");
    			attr(line1, "y1", "12");
    			attr(line1, "x2", "21");
    			attr(line1, "y2", "12");
    			attr(line2, "x1", "8");
    			attr(line2, "y1", "18");
    			attr(line2, "x2", "21");
    			attr(line2, "y2", "18");
    			attr(line3, "x1", "3");
    			attr(line3, "y1", "6");
    			attr(line3, "x2", "3.01");
    			attr(line3, "y2", "6");
    			attr(line4, "x1", "3");
    			attr(line4, "y1", "12");
    			attr(line4, "x2", "3.01");
    			attr(line4, "y2", "12");
    			attr(line5, "x1", "3");
    			attr(line5, "y1", "18");
    			attr(line5, "x2", "3.01");
    			attr(line5, "y2", "18");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, line0);
    			append(svg, line1);
    			append(svg, line2);
    			append(svg, line3);
    			append(svg, line4);
    			append(svg, line5);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2h($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class List extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2h, create_fragment$2h, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Loader.svelte generated by Svelte v3.31.0 */

    function create_fragment$2i(ctx) {
    	let svg;
    	let line0;
    	let line1;
    	let line2;
    	let line3;
    	let line4;
    	let line5;
    	let line6;
    	let line7;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			line2 = svg_element("line");
    			line3 = svg_element("line");
    			line4 = svg_element("line");
    			line5 = svg_element("line");
    			line6 = svg_element("line");
    			line7 = svg_element("line");
    			attr(line0, "x1", "12");
    			attr(line0, "y1", "2");
    			attr(line0, "x2", "12");
    			attr(line0, "y2", "6");
    			attr(line1, "x1", "12");
    			attr(line1, "y1", "18");
    			attr(line1, "x2", "12");
    			attr(line1, "y2", "22");
    			attr(line2, "x1", "4.93");
    			attr(line2, "y1", "4.93");
    			attr(line2, "x2", "7.76");
    			attr(line2, "y2", "7.76");
    			attr(line3, "x1", "16.24");
    			attr(line3, "y1", "16.24");
    			attr(line3, "x2", "19.07");
    			attr(line3, "y2", "19.07");
    			attr(line4, "x1", "2");
    			attr(line4, "y1", "12");
    			attr(line4, "x2", "6");
    			attr(line4, "y2", "12");
    			attr(line5, "x1", "18");
    			attr(line5, "y1", "12");
    			attr(line5, "x2", "22");
    			attr(line5, "y2", "12");
    			attr(line6, "x1", "4.93");
    			attr(line6, "y1", "19.07");
    			attr(line6, "x2", "7.76");
    			attr(line6, "y2", "16.24");
    			attr(line7, "x1", "16.24");
    			attr(line7, "y1", "7.76");
    			attr(line7, "x2", "19.07");
    			attr(line7, "y2", "4.93");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, line0);
    			append(svg, line1);
    			append(svg, line2);
    			append(svg, line3);
    			append(svg, line4);
    			append(svg, line5);
    			append(svg, line6);
    			append(svg, line7);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2i($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Loader extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2i, create_fragment$2i, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Lock.svelte generated by Svelte v3.31.0 */

    function create_fragment$2j(ctx) {
    	let svg;
    	let rect;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			rect = svg_element("rect");
    			path = svg_element("path");
    			attr(rect, "x", "3");
    			attr(rect, "y", "11");
    			attr(rect, "width", "18");
    			attr(rect, "height", "11");
    			attr(rect, "rx", "2");
    			attr(rect, "ry", "2");
    			attr(path, "d", "M7 11V7a5 5 0 0 1 10 0v4");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, rect);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2j($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Lock extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2j, create_fragment$2j, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/LogIn.svelte generated by Svelte v3.31.0 */

    function create_fragment$2k(ctx) {
    	let svg;
    	let path;
    	let polyline;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			polyline = svg_element("polyline");
    			line = svg_element("line");
    			attr(path, "d", "M15 3h4a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2h-4");
    			attr(polyline, "points", "10 17 15 12 10 7");
    			attr(line, "x1", "15");
    			attr(line, "y1", "12");
    			attr(line, "x2", "3");
    			attr(line, "y2", "12");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, polyline);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2k($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class LogIn extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2k, create_fragment$2k, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/LogOut.svelte generated by Svelte v3.31.0 */

    function create_fragment$2l(ctx) {
    	let svg;
    	let path;
    	let polyline;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			polyline = svg_element("polyline");
    			line = svg_element("line");
    			attr(path, "d", "M9 21H5a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h4");
    			attr(polyline, "points", "16 17 21 12 16 7");
    			attr(line, "x1", "21");
    			attr(line, "y1", "12");
    			attr(line, "x2", "9");
    			attr(line, "y2", "12");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, polyline);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2l($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class LogOut extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2l, create_fragment$2l, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Mail.svelte generated by Svelte v3.31.0 */

    function create_fragment$2m(ctx) {
    	let svg;
    	let path;
    	let polyline;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			polyline = svg_element("polyline");
    			attr(path, "d", "M4 4h16c1.1 0 2 .9 2 2v12c0 1.1-.9 2-2 2H4c-1.1 0-2-.9-2-2V6c0-1.1.9-2 2-2z");
    			attr(polyline, "points", "22,6 12,13 2,6");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, polyline);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2m($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Mail extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2m, create_fragment$2m, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/MapPin.svelte generated by Svelte v3.31.0 */

    function create_fragment$2n(ctx) {
    	let svg;
    	let path;
    	let circle;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			circle = svg_element("circle");
    			attr(path, "d", "M21 10c0 7-9 13-9 13s-9-6-9-13a9 9 0 0 1 18 0z");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "10");
    			attr(circle, "r", "3");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, circle);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2n($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class MapPin extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2n, create_fragment$2n, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Map.svelte generated by Svelte v3.31.0 */

    function create_fragment$2o(ctx) {
    	let svg;
    	let polygon;
    	let line0;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polygon = svg_element("polygon");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			attr(polygon, "points", "1 6 1 22 8 18 16 22 23 18 23 2 16 6 8 2 1 6");
    			attr(line0, "x1", "8");
    			attr(line0, "y1", "2");
    			attr(line0, "x2", "8");
    			attr(line0, "y2", "18");
    			attr(line1, "x1", "16");
    			attr(line1, "y1", "6");
    			attr(line1, "x2", "16");
    			attr(line1, "y2", "22");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polygon);
    			append(svg, line0);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2o($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Map$1 extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2o, create_fragment$2o, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Maximize2.svelte generated by Svelte v3.31.0 */

    function create_fragment$2p(ctx) {
    	let svg;
    	let polyline0;
    	let polyline1;
    	let line0;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline0 = svg_element("polyline");
    			polyline1 = svg_element("polyline");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			attr(polyline0, "points", "15 3 21 3 21 9");
    			attr(polyline1, "points", "9 21 3 21 3 15");
    			attr(line0, "x1", "21");
    			attr(line0, "y1", "3");
    			attr(line0, "x2", "14");
    			attr(line0, "y2", "10");
    			attr(line1, "x1", "3");
    			attr(line1, "y1", "21");
    			attr(line1, "x2", "10");
    			attr(line1, "y2", "14");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline0);
    			append(svg, polyline1);
    			append(svg, line0);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2p($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Maximize2 extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2p, create_fragment$2p, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Maximize.svelte generated by Svelte v3.31.0 */

    function create_fragment$2q(ctx) {
    	let svg;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			attr(path, "d", "M8 3H5a2 2 0 0 0-2 2v3m18 0V5a2 2 0 0 0-2-2h-3m0 18h3a2 2 0 0 0 2-2v-3M3 16v3a2 2 0 0 0 2 2h3");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2q($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Maximize extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2q, create_fragment$2q, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Meh.svelte generated by Svelte v3.31.0 */

    function create_fragment$2r(ctx) {
    	let svg;
    	let circle;
    	let line0;
    	let line1;
    	let line2;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle = svg_element("circle");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			line2 = svg_element("line");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "12");
    			attr(circle, "r", "10");
    			attr(line0, "x1", "8");
    			attr(line0, "y1", "15");
    			attr(line0, "x2", "16");
    			attr(line0, "y2", "15");
    			attr(line1, "x1", "9");
    			attr(line1, "y1", "9");
    			attr(line1, "x2", "9.01");
    			attr(line1, "y2", "9");
    			attr(line2, "x1", "15");
    			attr(line2, "y1", "9");
    			attr(line2, "x2", "15.01");
    			attr(line2, "y2", "9");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle);
    			append(svg, line0);
    			append(svg, line1);
    			append(svg, line2);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2r($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Meh extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2r, create_fragment$2r, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Menu.svelte generated by Svelte v3.31.0 */

    function create_fragment$2s(ctx) {
    	let svg;
    	let line0;
    	let line1;
    	let line2;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			line2 = svg_element("line");
    			attr(line0, "x1", "3");
    			attr(line0, "y1", "12");
    			attr(line0, "x2", "21");
    			attr(line0, "y2", "12");
    			attr(line1, "x1", "3");
    			attr(line1, "y1", "6");
    			attr(line1, "x2", "21");
    			attr(line1, "y2", "6");
    			attr(line2, "x1", "3");
    			attr(line2, "y1", "18");
    			attr(line2, "x2", "21");
    			attr(line2, "y2", "18");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, line0);
    			append(svg, line1);
    			append(svg, line2);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2s($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Menu extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2s, create_fragment$2s, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/MessageCircle.svelte generated by Svelte v3.31.0 */

    function create_fragment$2t(ctx) {
    	let svg;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			attr(path, "d", "M21 11.5a8.38 8.38 0 0 1-.9 3.8 8.5 8.5 0 0 1-7.6 4.7 8.38 8.38 0 0 1-3.8-.9L3 21l1.9-5.7a8.38 8.38 0 0 1-.9-3.8 8.5 8.5 0 0 1 4.7-7.6 8.38 8.38 0 0 1 3.8-.9h.5a8.48 8.48 0 0 1 8 8v.5z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2t($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class MessageCircle extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2t, create_fragment$2t, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/MessageSquare.svelte generated by Svelte v3.31.0 */

    function create_fragment$2u(ctx) {
    	let svg;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			attr(path, "d", "M21 15a2 2 0 0 1-2 2H7l-4 4V5a2 2 0 0 1 2-2h14a2 2 0 0 1 2 2z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2u($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class MessageSquare extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2u, create_fragment$2u, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/MicOff.svelte generated by Svelte v3.31.0 */

    function create_fragment$2v(ctx) {
    	let svg;
    	let line0;
    	let path0;
    	let path1;
    	let line1;
    	let line2;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			line0 = svg_element("line");
    			path0 = svg_element("path");
    			path1 = svg_element("path");
    			line1 = svg_element("line");
    			line2 = svg_element("line");
    			attr(line0, "x1", "1");
    			attr(line0, "y1", "1");
    			attr(line0, "x2", "23");
    			attr(line0, "y2", "23");
    			attr(path0, "d", "M9 9v3a3 3 0 0 0 5.12 2.12M15 9.34V4a3 3 0 0 0-5.94-.6");
    			attr(path1, "d", "M17 16.95A7 7 0 0 1 5 12v-2m14 0v2a7 7 0 0 1-.11 1.23");
    			attr(line1, "x1", "12");
    			attr(line1, "y1", "19");
    			attr(line1, "x2", "12");
    			attr(line1, "y2", "23");
    			attr(line2, "x1", "8");
    			attr(line2, "y1", "23");
    			attr(line2, "x2", "16");
    			attr(line2, "y2", "23");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, line0);
    			append(svg, path0);
    			append(svg, path1);
    			append(svg, line1);
    			append(svg, line2);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2v($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class MicOff extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2v, create_fragment$2v, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Mic.svelte generated by Svelte v3.31.0 */

    function create_fragment$2w(ctx) {
    	let svg;
    	let path0;
    	let path1;
    	let line0;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path0 = svg_element("path");
    			path1 = svg_element("path");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			attr(path0, "d", "M12 1a3 3 0 0 0-3 3v8a3 3 0 0 0 6 0V4a3 3 0 0 0-3-3z");
    			attr(path1, "d", "M19 10v2a7 7 0 0 1-14 0v-2");
    			attr(line0, "x1", "12");
    			attr(line0, "y1", "19");
    			attr(line0, "x2", "12");
    			attr(line0, "y2", "23");
    			attr(line1, "x1", "8");
    			attr(line1, "y1", "23");
    			attr(line1, "x2", "16");
    			attr(line1, "y2", "23");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path0);
    			append(svg, path1);
    			append(svg, line0);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2w($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Mic extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2w, create_fragment$2w, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Minimize2.svelte generated by Svelte v3.31.0 */

    function create_fragment$2x(ctx) {
    	let svg;
    	let polyline0;
    	let polyline1;
    	let line0;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline0 = svg_element("polyline");
    			polyline1 = svg_element("polyline");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			attr(polyline0, "points", "4 14 10 14 10 20");
    			attr(polyline1, "points", "20 10 14 10 14 4");
    			attr(line0, "x1", "14");
    			attr(line0, "y1", "10");
    			attr(line0, "x2", "21");
    			attr(line0, "y2", "3");
    			attr(line1, "x1", "3");
    			attr(line1, "y1", "21");
    			attr(line1, "x2", "10");
    			attr(line1, "y2", "14");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline0);
    			append(svg, polyline1);
    			append(svg, line0);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2x($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Minimize2 extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2x, create_fragment$2x, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Minimize.svelte generated by Svelte v3.31.0 */

    function create_fragment$2y(ctx) {
    	let svg;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			attr(path, "d", "M8 3v3a2 2 0 0 1-2 2H3m18 0h-3a2 2 0 0 1-2-2V3m0 18v-3a2 2 0 0 1 2-2h3M3 16h3a2 2 0 0 1 2 2v3");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2y($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Minimize extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2y, create_fragment$2y, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/MinusCircle.svelte generated by Svelte v3.31.0 */

    function create_fragment$2z(ctx) {
    	let svg;
    	let circle;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle = svg_element("circle");
    			line = svg_element("line");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "12");
    			attr(circle, "r", "10");
    			attr(line, "x1", "8");
    			attr(line, "y1", "12");
    			attr(line, "x2", "16");
    			attr(line, "y2", "12");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2z($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class MinusCircle extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2z, create_fragment$2z, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/MinusSquare.svelte generated by Svelte v3.31.0 */

    function create_fragment$2A(ctx) {
    	let svg;
    	let rect;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			rect = svg_element("rect");
    			line = svg_element("line");
    			attr(rect, "x", "3");
    			attr(rect, "y", "3");
    			attr(rect, "width", "18");
    			attr(rect, "height", "18");
    			attr(rect, "rx", "2");
    			attr(rect, "ry", "2");
    			attr(line, "x1", "8");
    			attr(line, "y1", "12");
    			attr(line, "x2", "16");
    			attr(line, "y2", "12");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, rect);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2A($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class MinusSquare extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2A, create_fragment$2A, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Minus.svelte generated by Svelte v3.31.0 */

    function create_fragment$2B(ctx) {
    	let svg;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			line = svg_element("line");
    			attr(line, "x1", "5");
    			attr(line, "y1", "12");
    			attr(line, "x2", "19");
    			attr(line, "y2", "12");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2B($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Minus extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2B, create_fragment$2B, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Monitor.svelte generated by Svelte v3.31.0 */

    function create_fragment$2C(ctx) {
    	let svg;
    	let rect;
    	let line0;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			rect = svg_element("rect");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			attr(rect, "x", "2");
    			attr(rect, "y", "3");
    			attr(rect, "width", "20");
    			attr(rect, "height", "14");
    			attr(rect, "rx", "2");
    			attr(rect, "ry", "2");
    			attr(line0, "x1", "8");
    			attr(line0, "y1", "21");
    			attr(line0, "x2", "16");
    			attr(line0, "y2", "21");
    			attr(line1, "x1", "12");
    			attr(line1, "y1", "17");
    			attr(line1, "x2", "12");
    			attr(line1, "y2", "21");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, rect);
    			append(svg, line0);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2C($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Monitor extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2C, create_fragment$2C, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Moon.svelte generated by Svelte v3.31.0 */

    function create_fragment$2D(ctx) {
    	let svg;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			attr(path, "d", "M21 12.79A9 9 0 1 1 11.21 3 7 7 0 0 0 21 12.79z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2D($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Moon extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2D, create_fragment$2D, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/MoreHorizontal.svelte generated by Svelte v3.31.0 */

    function create_fragment$2E(ctx) {
    	let svg;
    	let circle0;
    	let circle1;
    	let circle2;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle0 = svg_element("circle");
    			circle1 = svg_element("circle");
    			circle2 = svg_element("circle");
    			attr(circle0, "cx", "12");
    			attr(circle0, "cy", "12");
    			attr(circle0, "r", "1");
    			attr(circle1, "cx", "19");
    			attr(circle1, "cy", "12");
    			attr(circle1, "r", "1");
    			attr(circle2, "cx", "5");
    			attr(circle2, "cy", "12");
    			attr(circle2, "r", "1");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle0);
    			append(svg, circle1);
    			append(svg, circle2);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2E($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class MoreHorizontal extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2E, create_fragment$2E, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/MoreVertical.svelte generated by Svelte v3.31.0 */

    function create_fragment$2F(ctx) {
    	let svg;
    	let circle0;
    	let circle1;
    	let circle2;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle0 = svg_element("circle");
    			circle1 = svg_element("circle");
    			circle2 = svg_element("circle");
    			attr(circle0, "cx", "12");
    			attr(circle0, "cy", "12");
    			attr(circle0, "r", "1");
    			attr(circle1, "cx", "12");
    			attr(circle1, "cy", "5");
    			attr(circle1, "r", "1");
    			attr(circle2, "cx", "12");
    			attr(circle2, "cy", "19");
    			attr(circle2, "r", "1");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle0);
    			append(svg, circle1);
    			append(svg, circle2);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2F($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class MoreVertical extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2F, create_fragment$2F, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/MousePointer.svelte generated by Svelte v3.31.0 */

    function create_fragment$2G(ctx) {
    	let svg;
    	let path0;
    	let path1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path0 = svg_element("path");
    			path1 = svg_element("path");
    			attr(path0, "d", "M3 3l7.07 16.97 2.51-7.39 7.39-2.51L3 3z");
    			attr(path1, "d", "M13 13l6 6");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path0);
    			append(svg, path1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2G($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class MousePointer extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2G, create_fragment$2G, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Move.svelte generated by Svelte v3.31.0 */

    function create_fragment$2H(ctx) {
    	let svg;
    	let polyline0;
    	let polyline1;
    	let polyline2;
    	let polyline3;
    	let line0;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline0 = svg_element("polyline");
    			polyline1 = svg_element("polyline");
    			polyline2 = svg_element("polyline");
    			polyline3 = svg_element("polyline");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			attr(polyline0, "points", "5 9 2 12 5 15");
    			attr(polyline1, "points", "9 5 12 2 15 5");
    			attr(polyline2, "points", "15 19 12 22 9 19");
    			attr(polyline3, "points", "19 9 22 12 19 15");
    			attr(line0, "x1", "2");
    			attr(line0, "y1", "12");
    			attr(line0, "x2", "22");
    			attr(line0, "y2", "12");
    			attr(line1, "x1", "12");
    			attr(line1, "y1", "2");
    			attr(line1, "x2", "12");
    			attr(line1, "y2", "22");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline0);
    			append(svg, polyline1);
    			append(svg, polyline2);
    			append(svg, polyline3);
    			append(svg, line0);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2H($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Move extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2H, create_fragment$2H, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Music.svelte generated by Svelte v3.31.0 */

    function create_fragment$2I(ctx) {
    	let svg;
    	let path;
    	let circle0;
    	let circle1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			circle0 = svg_element("circle");
    			circle1 = svg_element("circle");
    			attr(path, "d", "M9 18V5l12-2v13");
    			attr(circle0, "cx", "6");
    			attr(circle0, "cy", "18");
    			attr(circle0, "r", "3");
    			attr(circle1, "cx", "18");
    			attr(circle1, "cy", "16");
    			attr(circle1, "r", "3");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, circle0);
    			append(svg, circle1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2I($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Music extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2I, create_fragment$2I, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Navigation2.svelte generated by Svelte v3.31.0 */

    function create_fragment$2J(ctx) {
    	let svg;
    	let polygon;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polygon = svg_element("polygon");
    			attr(polygon, "points", "12 2 19 21 12 17 5 21 12 2");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polygon);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2J($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Navigation2 extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2J, create_fragment$2J, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Navigation.svelte generated by Svelte v3.31.0 */

    function create_fragment$2K(ctx) {
    	let svg;
    	let polygon;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polygon = svg_element("polygon");
    			attr(polygon, "points", "3 11 22 2 13 21 11 13 3 11");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polygon);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2K($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Navigation extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2K, create_fragment$2K, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Octagon.svelte generated by Svelte v3.31.0 */

    function create_fragment$2L(ctx) {
    	let svg;
    	let polygon;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polygon = svg_element("polygon");
    			attr(polygon, "points", "7.86 2 16.14 2 22 7.86 22 16.14 16.14 22 7.86 22 2 16.14 2 7.86 7.86 2");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polygon);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2L($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Octagon extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2L, create_fragment$2L, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Package.svelte generated by Svelte v3.31.0 */

    function create_fragment$2M(ctx) {
    	let svg;
    	let line0;
    	let path;
    	let polyline;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			line0 = svg_element("line");
    			path = svg_element("path");
    			polyline = svg_element("polyline");
    			line1 = svg_element("line");
    			attr(line0, "x1", "16.5");
    			attr(line0, "y1", "9.4");
    			attr(line0, "x2", "7.5");
    			attr(line0, "y2", "4.21");
    			attr(path, "d", "M21 16V8a2 2 0 0 0-1-1.73l-7-4a2 2 0 0 0-2 0l-7 4A2 2 0 0 0 3 8v8a2 2 0 0 0 1 1.73l7 4a2 2 0 0 0 2 0l7-4A2 2 0 0 0 21 16z");
    			attr(polyline, "points", "3.27 6.96 12 12.01 20.73 6.96");
    			attr(line1, "x1", "12");
    			attr(line1, "y1", "22.08");
    			attr(line1, "x2", "12");
    			attr(line1, "y2", "12");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, line0);
    			append(svg, path);
    			append(svg, polyline);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2M($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Package extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2M, create_fragment$2M, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Paperclip.svelte generated by Svelte v3.31.0 */

    function create_fragment$2N(ctx) {
    	let svg;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			attr(path, "d", "M21.44 11.05l-9.19 9.19a6 6 0 0 1-8.49-8.49l9.19-9.19a4 4 0 0 1 5.66 5.66l-9.2 9.19a2 2 0 0 1-2.83-2.83l8.49-8.48");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2N($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Paperclip extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2N, create_fragment$2N, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/PauseCircle.svelte generated by Svelte v3.31.0 */

    function create_fragment$2O(ctx) {
    	let svg;
    	let circle;
    	let line0;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle = svg_element("circle");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "12");
    			attr(circle, "r", "10");
    			attr(line0, "x1", "10");
    			attr(line0, "y1", "15");
    			attr(line0, "x2", "10");
    			attr(line0, "y2", "9");
    			attr(line1, "x1", "14");
    			attr(line1, "y1", "15");
    			attr(line1, "x2", "14");
    			attr(line1, "y2", "9");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle);
    			append(svg, line0);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2O($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class PauseCircle extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2O, create_fragment$2O, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Pause.svelte generated by Svelte v3.31.0 */

    function create_fragment$2P(ctx) {
    	let svg;
    	let rect0;
    	let rect1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			rect0 = svg_element("rect");
    			rect1 = svg_element("rect");
    			attr(rect0, "x", "6");
    			attr(rect0, "y", "4");
    			attr(rect0, "width", "4");
    			attr(rect0, "height", "16");
    			attr(rect1, "x", "14");
    			attr(rect1, "y", "4");
    			attr(rect1, "width", "4");
    			attr(rect1, "height", "16");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, rect0);
    			append(svg, rect1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2P($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Pause extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2P, create_fragment$2P, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/PenTool.svelte generated by Svelte v3.31.0 */

    function create_fragment$2Q(ctx) {
    	let svg;
    	let path0;
    	let path1;
    	let path2;
    	let circle;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path0 = svg_element("path");
    			path1 = svg_element("path");
    			path2 = svg_element("path");
    			circle = svg_element("circle");
    			attr(path0, "d", "M12 19l7-7 3 3-7 7-3-3z");
    			attr(path1, "d", "M18 13l-1.5-7.5L2 2l3.5 14.5L13 18l5-5z");
    			attr(path2, "d", "M2 2l7.586 7.586");
    			attr(circle, "cx", "11");
    			attr(circle, "cy", "11");
    			attr(circle, "r", "2");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path0);
    			append(svg, path1);
    			append(svg, path2);
    			append(svg, circle);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2Q($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class PenTool extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2Q, create_fragment$2Q, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Percent.svelte generated by Svelte v3.31.0 */

    function create_fragment$2R(ctx) {
    	let svg;
    	let line;
    	let circle0;
    	let circle1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			line = svg_element("line");
    			circle0 = svg_element("circle");
    			circle1 = svg_element("circle");
    			attr(line, "x1", "19");
    			attr(line, "y1", "5");
    			attr(line, "x2", "5");
    			attr(line, "y2", "19");
    			attr(circle0, "cx", "6.5");
    			attr(circle0, "cy", "6.5");
    			attr(circle0, "r", "2.5");
    			attr(circle1, "cx", "17.5");
    			attr(circle1, "cy", "17.5");
    			attr(circle1, "r", "2.5");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, line);
    			append(svg, circle0);
    			append(svg, circle1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2R($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Percent extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2R, create_fragment$2R, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/PhoneCall.svelte generated by Svelte v3.31.0 */

    function create_fragment$2S(ctx) {
    	let svg;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			attr(path, "d", "M15.05 5A5 5 0 0 1 19 8.95M15.05 1A9 9 0 0 1 23 8.94m-1 7.98v3a2 2 0 0 1-2.18 2 19.79 19.79 0 0 1-8.63-3.07 19.5 19.5 0 0 1-6-6 19.79 19.79 0 0 1-3.07-8.67A2 2 0 0 1 4.11 2h3a2 2 0 0 1 2 1.72 12.84 12.84 0 0 0 .7 2.81 2 2 0 0 1-.45 2.11L8.09 9.91a16 16 0 0 0 6 6l1.27-1.27a2 2 0 0 1 2.11-.45 12.84 12.84 0 0 0 2.81.7A2 2 0 0 1 22 16.92z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2S($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class PhoneCall extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2S, create_fragment$2S, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/PhoneForwarded.svelte generated by Svelte v3.31.0 */

    function create_fragment$2T(ctx) {
    	let svg;
    	let polyline;
    	let line;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline = svg_element("polyline");
    			line = svg_element("line");
    			path = svg_element("path");
    			attr(polyline, "points", "19 1 23 5 19 9");
    			attr(line, "x1", "15");
    			attr(line, "y1", "5");
    			attr(line, "x2", "23");
    			attr(line, "y2", "5");
    			attr(path, "d", "M22 16.92v3a2 2 0 0 1-2.18 2 19.79 19.79 0 0 1-8.63-3.07 19.5 19.5 0 0 1-6-6 19.79 19.79 0 0 1-3.07-8.67A2 2 0 0 1 4.11 2h3a2 2 0 0 1 2 1.72 12.84 12.84 0 0 0 .7 2.81 2 2 0 0 1-.45 2.11L8.09 9.91a16 16 0 0 0 6 6l1.27-1.27a2 2 0 0 1 2.11-.45 12.84 12.84 0 0 0 2.81.7A2 2 0 0 1 22 16.92z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline);
    			append(svg, line);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2T($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class PhoneForwarded extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2T, create_fragment$2T, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/PhoneIncoming.svelte generated by Svelte v3.31.0 */

    function create_fragment$2U(ctx) {
    	let svg;
    	let polyline;
    	let line;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline = svg_element("polyline");
    			line = svg_element("line");
    			path = svg_element("path");
    			attr(polyline, "points", "16 2 16 8 22 8");
    			attr(line, "x1", "23");
    			attr(line, "y1", "1");
    			attr(line, "x2", "16");
    			attr(line, "y2", "8");
    			attr(path, "d", "M22 16.92v3a2 2 0 0 1-2.18 2 19.79 19.79 0 0 1-8.63-3.07 19.5 19.5 0 0 1-6-6 19.79 19.79 0 0 1-3.07-8.67A2 2 0 0 1 4.11 2h3a2 2 0 0 1 2 1.72 12.84 12.84 0 0 0 .7 2.81 2 2 0 0 1-.45 2.11L8.09 9.91a16 16 0 0 0 6 6l1.27-1.27a2 2 0 0 1 2.11-.45 12.84 12.84 0 0 0 2.81.7A2 2 0 0 1 22 16.92z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline);
    			append(svg, line);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2U($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class PhoneIncoming extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2U, create_fragment$2U, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/PhoneMissed.svelte generated by Svelte v3.31.0 */

    function create_fragment$2V(ctx) {
    	let svg;
    	let line0;
    	let line1;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			path = svg_element("path");
    			attr(line0, "x1", "23");
    			attr(line0, "y1", "1");
    			attr(line0, "x2", "17");
    			attr(line0, "y2", "7");
    			attr(line1, "x1", "17");
    			attr(line1, "y1", "1");
    			attr(line1, "x2", "23");
    			attr(line1, "y2", "7");
    			attr(path, "d", "M22 16.92v3a2 2 0 0 1-2.18 2 19.79 19.79 0 0 1-8.63-3.07 19.5 19.5 0 0 1-6-6 19.79 19.79 0 0 1-3.07-8.67A2 2 0 0 1 4.11 2h3a2 2 0 0 1 2 1.72 12.84 12.84 0 0 0 .7 2.81 2 2 0 0 1-.45 2.11L8.09 9.91a16 16 0 0 0 6 6l1.27-1.27a2 2 0 0 1 2.11-.45 12.84 12.84 0 0 0 2.81.7A2 2 0 0 1 22 16.92z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, line0);
    			append(svg, line1);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2V($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class PhoneMissed extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2V, create_fragment$2V, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/PhoneOff.svelte generated by Svelte v3.31.0 */

    function create_fragment$2W(ctx) {
    	let svg;
    	let path;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			line = svg_element("line");
    			attr(path, "d", "M10.68 13.31a16 16 0 0 0 3.41 2.6l1.27-1.27a2 2 0 0 1 2.11-.45 12.84 12.84 0 0 0 2.81.7 2 2 0 0 1 1.72 2v3a2 2 0 0 1-2.18 2 19.79 19.79 0 0 1-8.63-3.07 19.42 19.42 0 0 1-3.33-2.67m-2.67-3.34a19.79 19.79 0 0 1-3.07-8.63A2 2 0 0 1 4.11 2h3a2 2 0 0 1 2 1.72 12.84 12.84 0 0 0 .7 2.81 2 2 0 0 1-.45 2.11L8.09 9.91");
    			attr(line, "x1", "23");
    			attr(line, "y1", "1");
    			attr(line, "x2", "1");
    			attr(line, "y2", "23");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2W($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class PhoneOff extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2W, create_fragment$2W, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/PhoneOutgoing.svelte generated by Svelte v3.31.0 */

    function create_fragment$2X(ctx) {
    	let svg;
    	let polyline;
    	let line;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline = svg_element("polyline");
    			line = svg_element("line");
    			path = svg_element("path");
    			attr(polyline, "points", "23 7 23 1 17 1");
    			attr(line, "x1", "16");
    			attr(line, "y1", "8");
    			attr(line, "x2", "23");
    			attr(line, "y2", "1");
    			attr(path, "d", "M22 16.92v3a2 2 0 0 1-2.18 2 19.79 19.79 0 0 1-8.63-3.07 19.5 19.5 0 0 1-6-6 19.79 19.79 0 0 1-3.07-8.67A2 2 0 0 1 4.11 2h3a2 2 0 0 1 2 1.72 12.84 12.84 0 0 0 .7 2.81 2 2 0 0 1-.45 2.11L8.09 9.91a16 16 0 0 0 6 6l1.27-1.27a2 2 0 0 1 2.11-.45 12.84 12.84 0 0 0 2.81.7A2 2 0 0 1 22 16.92z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline);
    			append(svg, line);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2X($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class PhoneOutgoing extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2X, create_fragment$2X, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Phone.svelte generated by Svelte v3.31.0 */

    function create_fragment$2Y(ctx) {
    	let svg;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			attr(path, "d", "M22 16.92v3a2 2 0 0 1-2.18 2 19.79 19.79 0 0 1-8.63-3.07 19.5 19.5 0 0 1-6-6 19.79 19.79 0 0 1-3.07-8.67A2 2 0 0 1 4.11 2h3a2 2 0 0 1 2 1.72 12.84 12.84 0 0 0 .7 2.81 2 2 0 0 1-.45 2.11L8.09 9.91a16 16 0 0 0 6 6l1.27-1.27a2 2 0 0 1 2.11-.45 12.84 12.84 0 0 0 2.81.7A2 2 0 0 1 22 16.92z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2Y($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Phone extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2Y, create_fragment$2Y, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/PieChart.svelte generated by Svelte v3.31.0 */

    function create_fragment$2Z(ctx) {
    	let svg;
    	let path0;
    	let path1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path0 = svg_element("path");
    			path1 = svg_element("path");
    			attr(path0, "d", "M21.21 15.89A10 10 0 1 1 8 2.83");
    			attr(path1, "d", "M22 12A10 10 0 0 0 12 2v10z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path0);
    			append(svg, path1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2Z($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class PieChart extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2Z, create_fragment$2Z, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/PlayCircle.svelte generated by Svelte v3.31.0 */

    function create_fragment$2_(ctx) {
    	let svg;
    	let circle;
    	let polygon;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle = svg_element("circle");
    			polygon = svg_element("polygon");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "12");
    			attr(circle, "r", "10");
    			attr(polygon, "points", "10 8 16 12 10 16 10 8");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle);
    			append(svg, polygon);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2_($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class PlayCircle extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2_, create_fragment$2_, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Play.svelte generated by Svelte v3.31.0 */

    function create_fragment$2$(ctx) {
    	let svg;
    	let polygon;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polygon = svg_element("polygon");
    			attr(polygon, "points", "5 3 19 12 5 21 5 3");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polygon);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$2$($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Play extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$2$, create_fragment$2$, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/PlusCircle.svelte generated by Svelte v3.31.0 */

    function create_fragment$30(ctx) {
    	let svg;
    	let circle;
    	let line0;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle = svg_element("circle");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "12");
    			attr(circle, "r", "10");
    			attr(line0, "x1", "12");
    			attr(line0, "y1", "8");
    			attr(line0, "x2", "12");
    			attr(line0, "y2", "16");
    			attr(line1, "x1", "8");
    			attr(line1, "y1", "12");
    			attr(line1, "x2", "16");
    			attr(line1, "y2", "12");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle);
    			append(svg, line0);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$30($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class PlusCircle extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$30, create_fragment$30, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/PlusSquare.svelte generated by Svelte v3.31.0 */

    function create_fragment$31(ctx) {
    	let svg;
    	let rect;
    	let line0;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			rect = svg_element("rect");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			attr(rect, "x", "3");
    			attr(rect, "y", "3");
    			attr(rect, "width", "18");
    			attr(rect, "height", "18");
    			attr(rect, "rx", "2");
    			attr(rect, "ry", "2");
    			attr(line0, "x1", "12");
    			attr(line0, "y1", "8");
    			attr(line0, "x2", "12");
    			attr(line0, "y2", "16");
    			attr(line1, "x1", "8");
    			attr(line1, "y1", "12");
    			attr(line1, "x2", "16");
    			attr(line1, "y2", "12");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, rect);
    			append(svg, line0);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$31($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class PlusSquare extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$31, create_fragment$31, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Plus.svelte generated by Svelte v3.31.0 */

    function create_fragment$32(ctx) {
    	let svg;
    	let line0;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			attr(line0, "x1", "12");
    			attr(line0, "y1", "5");
    			attr(line0, "x2", "12");
    			attr(line0, "y2", "19");
    			attr(line1, "x1", "5");
    			attr(line1, "y1", "12");
    			attr(line1, "x2", "19");
    			attr(line1, "y2", "12");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, line0);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$32($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Plus extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$32, create_fragment$32, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Pocket.svelte generated by Svelte v3.31.0 */

    function create_fragment$33(ctx) {
    	let svg;
    	let path;
    	let polyline;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			polyline = svg_element("polyline");
    			attr(path, "d", "M4 3h16a2 2 0 0 1 2 2v6a10 10 0 0 1-10 10A10 10 0 0 1 2 11V5a2 2 0 0 1 2-2z");
    			attr(polyline, "points", "8 10 12 14 16 10");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, polyline);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$33($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Pocket extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$33, create_fragment$33, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Power.svelte generated by Svelte v3.31.0 */

    function create_fragment$34(ctx) {
    	let svg;
    	let path;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			line = svg_element("line");
    			attr(path, "d", "M18.36 6.64a9 9 0 1 1-12.73 0");
    			attr(line, "x1", "12");
    			attr(line, "y1", "2");
    			attr(line, "x2", "12");
    			attr(line, "y2", "12");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$34($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Power extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$34, create_fragment$34, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Printer.svelte generated by Svelte v3.31.0 */

    function create_fragment$35(ctx) {
    	let svg;
    	let polyline;
    	let path;
    	let rect;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline = svg_element("polyline");
    			path = svg_element("path");
    			rect = svg_element("rect");
    			attr(polyline, "points", "6 9 6 2 18 2 18 9");
    			attr(path, "d", "M6 18H4a2 2 0 0 1-2-2v-5a2 2 0 0 1 2-2h16a2 2 0 0 1 2 2v5a2 2 0 0 1-2 2h-2");
    			attr(rect, "x", "6");
    			attr(rect, "y", "14");
    			attr(rect, "width", "12");
    			attr(rect, "height", "8");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline);
    			append(svg, path);
    			append(svg, rect);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$35($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Printer extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$35, create_fragment$35, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Radio.svelte generated by Svelte v3.31.0 */

    function create_fragment$36(ctx) {
    	let svg;
    	let circle;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle = svg_element("circle");
    			path = svg_element("path");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "12");
    			attr(circle, "r", "2");
    			attr(path, "d", "M16.24 7.76a6 6 0 0 1 0 8.49m-8.48-.01a6 6 0 0 1 0-8.49m11.31-2.82a10 10 0 0 1 0 14.14m-14.14 0a10 10 0 0 1 0-14.14");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$36($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Radio extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$36, create_fragment$36, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/RefreshCcw.svelte generated by Svelte v3.31.0 */

    function create_fragment$37(ctx) {
    	let svg;
    	let polyline0;
    	let polyline1;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline0 = svg_element("polyline");
    			polyline1 = svg_element("polyline");
    			path = svg_element("path");
    			attr(polyline0, "points", "1 4 1 10 7 10");
    			attr(polyline1, "points", "23 20 23 14 17 14");
    			attr(path, "d", "M20.49 9A9 9 0 0 0 5.64 5.64L1 10m22 4l-4.64 4.36A9 9 0 0 1 3.51 15");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline0);
    			append(svg, polyline1);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$37($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class RefreshCcw extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$37, create_fragment$37, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/RefreshCw.svelte generated by Svelte v3.31.0 */

    function create_fragment$38(ctx) {
    	let svg;
    	let polyline0;
    	let polyline1;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline0 = svg_element("polyline");
    			polyline1 = svg_element("polyline");
    			path = svg_element("path");
    			attr(polyline0, "points", "23 4 23 10 17 10");
    			attr(polyline1, "points", "1 20 1 14 7 14");
    			attr(path, "d", "M3.51 9a9 9 0 0 1 14.85-3.36L23 10M1 14l4.64 4.36A9 9 0 0 0 20.49 15");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline0);
    			append(svg, polyline1);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$38($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class RefreshCw extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$38, create_fragment$38, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Repeat.svelte generated by Svelte v3.31.0 */

    function create_fragment$39(ctx) {
    	let svg;
    	let polyline0;
    	let path0;
    	let polyline1;
    	let path1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline0 = svg_element("polyline");
    			path0 = svg_element("path");
    			polyline1 = svg_element("polyline");
    			path1 = svg_element("path");
    			attr(polyline0, "points", "17 1 21 5 17 9");
    			attr(path0, "d", "M3 11V9a4 4 0 0 1 4-4h14");
    			attr(polyline1, "points", "7 23 3 19 7 15");
    			attr(path1, "d", "M21 13v2a4 4 0 0 1-4 4H3");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline0);
    			append(svg, path0);
    			append(svg, polyline1);
    			append(svg, path1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$39($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Repeat extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$39, create_fragment$39, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Rewind.svelte generated by Svelte v3.31.0 */

    function create_fragment$3a(ctx) {
    	let svg;
    	let polygon0;
    	let polygon1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polygon0 = svg_element("polygon");
    			polygon1 = svg_element("polygon");
    			attr(polygon0, "points", "11 19 2 12 11 5 11 19");
    			attr(polygon1, "points", "22 19 13 12 22 5 22 19");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polygon0);
    			append(svg, polygon1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3a($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Rewind extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3a, create_fragment$3a, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/RotateCcw.svelte generated by Svelte v3.31.0 */

    function create_fragment$3b(ctx) {
    	let svg;
    	let polyline;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline = svg_element("polyline");
    			path = svg_element("path");
    			attr(polyline, "points", "1 4 1 10 7 10");
    			attr(path, "d", "M3.51 15a9 9 0 1 0 2.13-9.36L1 10");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3b($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class RotateCcw extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3b, create_fragment$3b, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/RotateCw.svelte generated by Svelte v3.31.0 */

    function create_fragment$3c(ctx) {
    	let svg;
    	let polyline;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline = svg_element("polyline");
    			path = svg_element("path");
    			attr(polyline, "points", "23 4 23 10 17 10");
    			attr(path, "d", "M20.49 15a9 9 0 1 1-2.12-9.36L23 10");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3c($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class RotateCw extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3c, create_fragment$3c, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Rss.svelte generated by Svelte v3.31.0 */

    function create_fragment$3d(ctx) {
    	let svg;
    	let path0;
    	let path1;
    	let circle;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path0 = svg_element("path");
    			path1 = svg_element("path");
    			circle = svg_element("circle");
    			attr(path0, "d", "M4 11a9 9 0 0 1 9 9");
    			attr(path1, "d", "M4 4a16 16 0 0 1 16 16");
    			attr(circle, "cx", "5");
    			attr(circle, "cy", "19");
    			attr(circle, "r", "1");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path0);
    			append(svg, path1);
    			append(svg, circle);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3d($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Rss extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3d, create_fragment$3d, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Save.svelte generated by Svelte v3.31.0 */

    function create_fragment$3e(ctx) {
    	let svg;
    	let path;
    	let polyline0;
    	let polyline1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			polyline0 = svg_element("polyline");
    			polyline1 = svg_element("polyline");
    			attr(path, "d", "M19 21H5a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h11l5 5v11a2 2 0 0 1-2 2z");
    			attr(polyline0, "points", "17 21 17 13 7 13 7 21");
    			attr(polyline1, "points", "7 3 7 8 15 8");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, polyline0);
    			append(svg, polyline1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3e($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Save extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3e, create_fragment$3e, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Scissors.svelte generated by Svelte v3.31.0 */

    function create_fragment$3f(ctx) {
    	let svg;
    	let circle0;
    	let circle1;
    	let line0;
    	let line1;
    	let line2;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle0 = svg_element("circle");
    			circle1 = svg_element("circle");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			line2 = svg_element("line");
    			attr(circle0, "cx", "6");
    			attr(circle0, "cy", "6");
    			attr(circle0, "r", "3");
    			attr(circle1, "cx", "6");
    			attr(circle1, "cy", "18");
    			attr(circle1, "r", "3");
    			attr(line0, "x1", "20");
    			attr(line0, "y1", "4");
    			attr(line0, "x2", "8.12");
    			attr(line0, "y2", "15.88");
    			attr(line1, "x1", "14.47");
    			attr(line1, "y1", "14.48");
    			attr(line1, "x2", "20");
    			attr(line1, "y2", "20");
    			attr(line2, "x1", "8.12");
    			attr(line2, "y1", "8.12");
    			attr(line2, "x2", "12");
    			attr(line2, "y2", "12");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle0);
    			append(svg, circle1);
    			append(svg, line0);
    			append(svg, line1);
    			append(svg, line2);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3f($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Scissors extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3f, create_fragment$3f, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Search.svelte generated by Svelte v3.31.0 */

    function create_fragment$3g(ctx) {
    	let svg;
    	let circle;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle = svg_element("circle");
    			line = svg_element("line");
    			attr(circle, "cx", "11");
    			attr(circle, "cy", "11");
    			attr(circle, "r", "8");
    			attr(line, "x1", "21");
    			attr(line, "y1", "21");
    			attr(line, "x2", "16.65");
    			attr(line, "y2", "16.65");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3g($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Search extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3g, create_fragment$3g, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Send.svelte generated by Svelte v3.31.0 */

    function create_fragment$3h(ctx) {
    	let svg;
    	let line;
    	let polygon;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			line = svg_element("line");
    			polygon = svg_element("polygon");
    			attr(line, "x1", "22");
    			attr(line, "y1", "2");
    			attr(line, "x2", "11");
    			attr(line, "y2", "13");
    			attr(polygon, "points", "22 2 15 22 11 13 2 9 22 2");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, line);
    			append(svg, polygon);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3h($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Send extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3h, create_fragment$3h, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Server.svelte generated by Svelte v3.31.0 */

    function create_fragment$3i(ctx) {
    	let svg;
    	let rect0;
    	let rect1;
    	let line0;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			rect0 = svg_element("rect");
    			rect1 = svg_element("rect");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			attr(rect0, "x", "2");
    			attr(rect0, "y", "2");
    			attr(rect0, "width", "20");
    			attr(rect0, "height", "8");
    			attr(rect0, "rx", "2");
    			attr(rect0, "ry", "2");
    			attr(rect1, "x", "2");
    			attr(rect1, "y", "14");
    			attr(rect1, "width", "20");
    			attr(rect1, "height", "8");
    			attr(rect1, "rx", "2");
    			attr(rect1, "ry", "2");
    			attr(line0, "x1", "6");
    			attr(line0, "y1", "6");
    			attr(line0, "x2", "6.01");
    			attr(line0, "y2", "6");
    			attr(line1, "x1", "6");
    			attr(line1, "y1", "18");
    			attr(line1, "x2", "6.01");
    			attr(line1, "y2", "18");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, rect0);
    			append(svg, rect1);
    			append(svg, line0);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3i($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Server extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3i, create_fragment$3i, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Settings.svelte generated by Svelte v3.31.0 */

    function create_fragment$3j(ctx) {
    	let svg;
    	let circle;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle = svg_element("circle");
    			path = svg_element("path");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "12");
    			attr(circle, "r", "3");
    			attr(path, "d", "M19.4 15a1.65 1.65 0 0 0 .33 1.82l.06.06a2 2 0 0 1 0 2.83 2 2 0 0 1-2.83 0l-.06-.06a1.65 1.65 0 0 0-1.82-.33 1.65 1.65 0 0 0-1 1.51V21a2 2 0 0 1-2 2 2 2 0 0 1-2-2v-.09A1.65 1.65 0 0 0 9 19.4a1.65 1.65 0 0 0-1.82.33l-.06.06a2 2 0 0 1-2.83 0 2 2 0 0 1 0-2.83l.06-.06a1.65 1.65 0 0 0 .33-1.82 1.65 1.65 0 0 0-1.51-1H3a2 2 0 0 1-2-2 2 2 0 0 1 2-2h.09A1.65 1.65 0 0 0 4.6 9a1.65 1.65 0 0 0-.33-1.82l-.06-.06a2 2 0 0 1 0-2.83 2 2 0 0 1 2.83 0l.06.06a1.65 1.65 0 0 0 1.82.33H9a1.65 1.65 0 0 0 1-1.51V3a2 2 0 0 1 2-2 2 2 0 0 1 2 2v.09a1.65 1.65 0 0 0 1 1.51 1.65 1.65 0 0 0 1.82-.33l.06-.06a2 2 0 0 1 2.83 0 2 2 0 0 1 0 2.83l-.06.06a1.65 1.65 0 0 0-.33 1.82V9a1.65 1.65 0 0 0 1.51 1H21a2 2 0 0 1 2 2 2 2 0 0 1-2 2h-.09a1.65 1.65 0 0 0-1.51 1z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3j($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Settings extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3j, create_fragment$3j, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Share2.svelte generated by Svelte v3.31.0 */

    function create_fragment$3k(ctx) {
    	let svg;
    	let circle0;
    	let circle1;
    	let circle2;
    	let line0;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle0 = svg_element("circle");
    			circle1 = svg_element("circle");
    			circle2 = svg_element("circle");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			attr(circle0, "cx", "18");
    			attr(circle0, "cy", "5");
    			attr(circle0, "r", "3");
    			attr(circle1, "cx", "6");
    			attr(circle1, "cy", "12");
    			attr(circle1, "r", "3");
    			attr(circle2, "cx", "18");
    			attr(circle2, "cy", "19");
    			attr(circle2, "r", "3");
    			attr(line0, "x1", "8.59");
    			attr(line0, "y1", "13.51");
    			attr(line0, "x2", "15.42");
    			attr(line0, "y2", "17.49");
    			attr(line1, "x1", "15.41");
    			attr(line1, "y1", "6.51");
    			attr(line1, "x2", "8.59");
    			attr(line1, "y2", "10.49");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle0);
    			append(svg, circle1);
    			append(svg, circle2);
    			append(svg, line0);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3k($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Share2 extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3k, create_fragment$3k, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Share.svelte generated by Svelte v3.31.0 */

    function create_fragment$3l(ctx) {
    	let svg;
    	let path;
    	let polyline;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			polyline = svg_element("polyline");
    			line = svg_element("line");
    			attr(path, "d", "M4 12v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2v-8");
    			attr(polyline, "points", "16 6 12 2 8 6");
    			attr(line, "x1", "12");
    			attr(line, "y1", "2");
    			attr(line, "x2", "12");
    			attr(line, "y2", "15");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, polyline);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3l($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Share extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3l, create_fragment$3l, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/ShieldOff.svelte generated by Svelte v3.31.0 */

    function create_fragment$3m(ctx) {
    	let svg;
    	let path0;
    	let path1;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path0 = svg_element("path");
    			path1 = svg_element("path");
    			line = svg_element("line");
    			attr(path0, "d", "M19.69 14a6.9 6.9 0 0 0 .31-2V5l-8-3-3.16 1.18");
    			attr(path1, "d", "M4.73 4.73L4 5v7c0 6 8 10 8 10a20.29 20.29 0 0 0 5.62-4.38");
    			attr(line, "x1", "1");
    			attr(line, "y1", "1");
    			attr(line, "x2", "23");
    			attr(line, "y2", "23");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path0);
    			append(svg, path1);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3m($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class ShieldOff extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3m, create_fragment$3m, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Shield.svelte generated by Svelte v3.31.0 */

    function create_fragment$3n(ctx) {
    	let svg;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			attr(path, "d", "M12 22s8-4 8-10V5l-8-3-8 3v7c0 6 8 10 8 10z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3n($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Shield extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3n, create_fragment$3n, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/ShoppingBag.svelte generated by Svelte v3.31.0 */

    function create_fragment$3o(ctx) {
    	let svg;
    	let path0;
    	let line;
    	let path1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path0 = svg_element("path");
    			line = svg_element("line");
    			path1 = svg_element("path");
    			attr(path0, "d", "M6 2L3 6v14a2 2 0 0 0 2 2h14a2 2 0 0 0 2-2V6l-3-4z");
    			attr(line, "x1", "3");
    			attr(line, "y1", "6");
    			attr(line, "x2", "21");
    			attr(line, "y2", "6");
    			attr(path1, "d", "M16 10a4 4 0 0 1-8 0");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path0);
    			append(svg, line);
    			append(svg, path1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3o($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class ShoppingBag extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3o, create_fragment$3o, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/ShoppingCart.svelte generated by Svelte v3.31.0 */

    function create_fragment$3p(ctx) {
    	let svg;
    	let circle0;
    	let circle1;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle0 = svg_element("circle");
    			circle1 = svg_element("circle");
    			path = svg_element("path");
    			attr(circle0, "cx", "9");
    			attr(circle0, "cy", "21");
    			attr(circle0, "r", "1");
    			attr(circle1, "cx", "20");
    			attr(circle1, "cy", "21");
    			attr(circle1, "r", "1");
    			attr(path, "d", "M1 1h4l2.68 13.39a2 2 0 0 0 2 1.61h9.72a2 2 0 0 0 2-1.61L23 6H6");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle0);
    			append(svg, circle1);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3p($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class ShoppingCart extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3p, create_fragment$3p, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Shuffle.svelte generated by Svelte v3.31.0 */

    function create_fragment$3q(ctx) {
    	let svg;
    	let polyline0;
    	let line0;
    	let polyline1;
    	let line1;
    	let line2;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline0 = svg_element("polyline");
    			line0 = svg_element("line");
    			polyline1 = svg_element("polyline");
    			line1 = svg_element("line");
    			line2 = svg_element("line");
    			attr(polyline0, "points", "16 3 21 3 21 8");
    			attr(line0, "x1", "4");
    			attr(line0, "y1", "20");
    			attr(line0, "x2", "21");
    			attr(line0, "y2", "3");
    			attr(polyline1, "points", "21 16 21 21 16 21");
    			attr(line1, "x1", "15");
    			attr(line1, "y1", "15");
    			attr(line1, "x2", "21");
    			attr(line1, "y2", "21");
    			attr(line2, "x1", "4");
    			attr(line2, "y1", "4");
    			attr(line2, "x2", "9");
    			attr(line2, "y2", "9");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline0);
    			append(svg, line0);
    			append(svg, polyline1);
    			append(svg, line1);
    			append(svg, line2);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3q($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Shuffle extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3q, create_fragment$3q, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Sidebar.svelte generated by Svelte v3.31.0 */

    function create_fragment$3r(ctx) {
    	let svg;
    	let rect;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			rect = svg_element("rect");
    			line = svg_element("line");
    			attr(rect, "x", "3");
    			attr(rect, "y", "3");
    			attr(rect, "width", "18");
    			attr(rect, "height", "18");
    			attr(rect, "rx", "2");
    			attr(rect, "ry", "2");
    			attr(line, "x1", "9");
    			attr(line, "y1", "3");
    			attr(line, "x2", "9");
    			attr(line, "y2", "21");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, rect);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3r($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Sidebar extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3r, create_fragment$3r, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/SkipBack.svelte generated by Svelte v3.31.0 */

    function create_fragment$3s(ctx) {
    	let svg;
    	let polygon;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polygon = svg_element("polygon");
    			line = svg_element("line");
    			attr(polygon, "points", "19 20 9 12 19 4 19 20");
    			attr(line, "x1", "5");
    			attr(line, "y1", "19");
    			attr(line, "x2", "5");
    			attr(line, "y2", "5");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polygon);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3s($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class SkipBack extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3s, create_fragment$3s, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/SkipForward.svelte generated by Svelte v3.31.0 */

    function create_fragment$3t(ctx) {
    	let svg;
    	let polygon;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polygon = svg_element("polygon");
    			line = svg_element("line");
    			attr(polygon, "points", "5 4 15 12 5 20 5 4");
    			attr(line, "x1", "19");
    			attr(line, "y1", "5");
    			attr(line, "x2", "19");
    			attr(line, "y2", "19");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polygon);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3t($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class SkipForward extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3t, create_fragment$3t, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Slack.svelte generated by Svelte v3.31.0 */

    function create_fragment$3u(ctx) {
    	let svg;
    	let path0;
    	let path1;
    	let path2;
    	let path3;
    	let path4;
    	let path5;
    	let path6;
    	let path7;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path0 = svg_element("path");
    			path1 = svg_element("path");
    			path2 = svg_element("path");
    			path3 = svg_element("path");
    			path4 = svg_element("path");
    			path5 = svg_element("path");
    			path6 = svg_element("path");
    			path7 = svg_element("path");
    			attr(path0, "d", "M14.5 10c-.83 0-1.5-.67-1.5-1.5v-5c0-.83.67-1.5 1.5-1.5s1.5.67 1.5 1.5v5c0 .83-.67 1.5-1.5 1.5z");
    			attr(path1, "d", "M20.5 10H19V8.5c0-.83.67-1.5 1.5-1.5s1.5.67 1.5 1.5-.67 1.5-1.5 1.5z");
    			attr(path2, "d", "M9.5 14c.83 0 1.5.67 1.5 1.5v5c0 .83-.67 1.5-1.5 1.5S8 21.33 8 20.5v-5c0-.83.67-1.5 1.5-1.5z");
    			attr(path3, "d", "M3.5 14H5v1.5c0 .83-.67 1.5-1.5 1.5S2 16.33 2 15.5 2.67 14 3.5 14z");
    			attr(path4, "d", "M14 14.5c0-.83.67-1.5 1.5-1.5h5c.83 0 1.5.67 1.5 1.5s-.67 1.5-1.5 1.5h-5c-.83 0-1.5-.67-1.5-1.5z");
    			attr(path5, "d", "M15.5 19H14v1.5c0 .83.67 1.5 1.5 1.5s1.5-.67 1.5-1.5-.67-1.5-1.5-1.5z");
    			attr(path6, "d", "M10 9.5C10 8.67 9.33 8 8.5 8h-5C2.67 8 2 8.67 2 9.5S2.67 11 3.5 11h5c.83 0 1.5-.67 1.5-1.5z");
    			attr(path7, "d", "M8.5 5H10V3.5C10 2.67 9.33 2 8.5 2S7 2.67 7 3.5 7.67 5 8.5 5z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path0);
    			append(svg, path1);
    			append(svg, path2);
    			append(svg, path3);
    			append(svg, path4);
    			append(svg, path5);
    			append(svg, path6);
    			append(svg, path7);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3u($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Slack extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3u, create_fragment$3u, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Slash.svelte generated by Svelte v3.31.0 */

    function create_fragment$3v(ctx) {
    	let svg;
    	let circle;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle = svg_element("circle");
    			line = svg_element("line");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "12");
    			attr(circle, "r", "10");
    			attr(line, "x1", "4.93");
    			attr(line, "y1", "4.93");
    			attr(line, "x2", "19.07");
    			attr(line, "y2", "19.07");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3v($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Slash extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3v, create_fragment$3v, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Sliders.svelte generated by Svelte v3.31.0 */

    function create_fragment$3w(ctx) {
    	let svg;
    	let line0;
    	let line1;
    	let line2;
    	let line3;
    	let line4;
    	let line5;
    	let line6;
    	let line7;
    	let line8;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			line2 = svg_element("line");
    			line3 = svg_element("line");
    			line4 = svg_element("line");
    			line5 = svg_element("line");
    			line6 = svg_element("line");
    			line7 = svg_element("line");
    			line8 = svg_element("line");
    			attr(line0, "x1", "4");
    			attr(line0, "y1", "21");
    			attr(line0, "x2", "4");
    			attr(line0, "y2", "14");
    			attr(line1, "x1", "4");
    			attr(line1, "y1", "10");
    			attr(line1, "x2", "4");
    			attr(line1, "y2", "3");
    			attr(line2, "x1", "12");
    			attr(line2, "y1", "21");
    			attr(line2, "x2", "12");
    			attr(line2, "y2", "12");
    			attr(line3, "x1", "12");
    			attr(line3, "y1", "8");
    			attr(line3, "x2", "12");
    			attr(line3, "y2", "3");
    			attr(line4, "x1", "20");
    			attr(line4, "y1", "21");
    			attr(line4, "x2", "20");
    			attr(line4, "y2", "16");
    			attr(line5, "x1", "20");
    			attr(line5, "y1", "12");
    			attr(line5, "x2", "20");
    			attr(line5, "y2", "3");
    			attr(line6, "x1", "1");
    			attr(line6, "y1", "14");
    			attr(line6, "x2", "7");
    			attr(line6, "y2", "14");
    			attr(line7, "x1", "9");
    			attr(line7, "y1", "8");
    			attr(line7, "x2", "15");
    			attr(line7, "y2", "8");
    			attr(line8, "x1", "17");
    			attr(line8, "y1", "16");
    			attr(line8, "x2", "23");
    			attr(line8, "y2", "16");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, line0);
    			append(svg, line1);
    			append(svg, line2);
    			append(svg, line3);
    			append(svg, line4);
    			append(svg, line5);
    			append(svg, line6);
    			append(svg, line7);
    			append(svg, line8);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3w($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Sliders extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3w, create_fragment$3w, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Smartphone.svelte generated by Svelte v3.31.0 */

    function create_fragment$3x(ctx) {
    	let svg;
    	let rect;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			rect = svg_element("rect");
    			line = svg_element("line");
    			attr(rect, "x", "5");
    			attr(rect, "y", "2");
    			attr(rect, "width", "14");
    			attr(rect, "height", "20");
    			attr(rect, "rx", "2");
    			attr(rect, "ry", "2");
    			attr(line, "x1", "12");
    			attr(line, "y1", "18");
    			attr(line, "x2", "12.01");
    			attr(line, "y2", "18");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, rect);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3x($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Smartphone extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3x, create_fragment$3x, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Smile.svelte generated by Svelte v3.31.0 */

    function create_fragment$3y(ctx) {
    	let svg;
    	let circle;
    	let path;
    	let line0;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle = svg_element("circle");
    			path = svg_element("path");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "12");
    			attr(circle, "r", "10");
    			attr(path, "d", "M8 14s1.5 2 4 2 4-2 4-2");
    			attr(line0, "x1", "9");
    			attr(line0, "y1", "9");
    			attr(line0, "x2", "9.01");
    			attr(line0, "y2", "9");
    			attr(line1, "x1", "15");
    			attr(line1, "y1", "9");
    			attr(line1, "x2", "15.01");
    			attr(line1, "y2", "9");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle);
    			append(svg, path);
    			append(svg, line0);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3y($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Smile extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3y, create_fragment$3y, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Speaker.svelte generated by Svelte v3.31.0 */

    function create_fragment$3z(ctx) {
    	let svg;
    	let rect;
    	let circle;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			rect = svg_element("rect");
    			circle = svg_element("circle");
    			line = svg_element("line");
    			attr(rect, "x", "4");
    			attr(rect, "y", "2");
    			attr(rect, "width", "16");
    			attr(rect, "height", "20");
    			attr(rect, "rx", "2");
    			attr(rect, "ry", "2");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "14");
    			attr(circle, "r", "4");
    			attr(line, "x1", "12");
    			attr(line, "y1", "6");
    			attr(line, "x2", "12.01");
    			attr(line, "y2", "6");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, rect);
    			append(svg, circle);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3z($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Speaker extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3z, create_fragment$3z, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Square.svelte generated by Svelte v3.31.0 */

    function create_fragment$3A(ctx) {
    	let svg;
    	let rect;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			rect = svg_element("rect");
    			attr(rect, "x", "3");
    			attr(rect, "y", "3");
    			attr(rect, "width", "18");
    			attr(rect, "height", "18");
    			attr(rect, "rx", "2");
    			attr(rect, "ry", "2");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, rect);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3A($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Square extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3A, create_fragment$3A, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Star.svelte generated by Svelte v3.31.0 */

    function create_fragment$3B(ctx) {
    	let svg;
    	let polygon;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polygon = svg_element("polygon");
    			attr(polygon, "points", "12 2 15.09 8.26 22 9.27 17 14.14 18.18 21.02 12 17.77 5.82 21.02 7 14.14 2 9.27 8.91 8.26 12 2");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polygon);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3B($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Star extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3B, create_fragment$3B, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/StopCircle.svelte generated by Svelte v3.31.0 */

    function create_fragment$3C(ctx) {
    	let svg;
    	let circle;
    	let rect;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle = svg_element("circle");
    			rect = svg_element("rect");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "12");
    			attr(circle, "r", "10");
    			attr(rect, "x", "9");
    			attr(rect, "y", "9");
    			attr(rect, "width", "6");
    			attr(rect, "height", "6");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle);
    			append(svg, rect);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3C($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class StopCircle extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3C, create_fragment$3C, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Sun.svelte generated by Svelte v3.31.0 */

    function create_fragment$3D(ctx) {
    	let svg;
    	let circle;
    	let line0;
    	let line1;
    	let line2;
    	let line3;
    	let line4;
    	let line5;
    	let line6;
    	let line7;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle = svg_element("circle");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			line2 = svg_element("line");
    			line3 = svg_element("line");
    			line4 = svg_element("line");
    			line5 = svg_element("line");
    			line6 = svg_element("line");
    			line7 = svg_element("line");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "12");
    			attr(circle, "r", "5");
    			attr(line0, "x1", "12");
    			attr(line0, "y1", "1");
    			attr(line0, "x2", "12");
    			attr(line0, "y2", "3");
    			attr(line1, "x1", "12");
    			attr(line1, "y1", "21");
    			attr(line1, "x2", "12");
    			attr(line1, "y2", "23");
    			attr(line2, "x1", "4.22");
    			attr(line2, "y1", "4.22");
    			attr(line2, "x2", "5.64");
    			attr(line2, "y2", "5.64");
    			attr(line3, "x1", "18.36");
    			attr(line3, "y1", "18.36");
    			attr(line3, "x2", "19.78");
    			attr(line3, "y2", "19.78");
    			attr(line4, "x1", "1");
    			attr(line4, "y1", "12");
    			attr(line4, "x2", "3");
    			attr(line4, "y2", "12");
    			attr(line5, "x1", "21");
    			attr(line5, "y1", "12");
    			attr(line5, "x2", "23");
    			attr(line5, "y2", "12");
    			attr(line6, "x1", "4.22");
    			attr(line6, "y1", "19.78");
    			attr(line6, "x2", "5.64");
    			attr(line6, "y2", "18.36");
    			attr(line7, "x1", "18.36");
    			attr(line7, "y1", "5.64");
    			attr(line7, "x2", "19.78");
    			attr(line7, "y2", "4.22");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle);
    			append(svg, line0);
    			append(svg, line1);
    			append(svg, line2);
    			append(svg, line3);
    			append(svg, line4);
    			append(svg, line5);
    			append(svg, line6);
    			append(svg, line7);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3D($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Sun extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3D, create_fragment$3D, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Sunrise.svelte generated by Svelte v3.31.0 */

    function create_fragment$3E(ctx) {
    	let svg;
    	let path;
    	let line0;
    	let line1;
    	let line2;
    	let line3;
    	let line4;
    	let line5;
    	let polyline;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			line2 = svg_element("line");
    			line3 = svg_element("line");
    			line4 = svg_element("line");
    			line5 = svg_element("line");
    			polyline = svg_element("polyline");
    			attr(path, "d", "M17 18a5 5 0 0 0-10 0");
    			attr(line0, "x1", "12");
    			attr(line0, "y1", "2");
    			attr(line0, "x2", "12");
    			attr(line0, "y2", "9");
    			attr(line1, "x1", "4.22");
    			attr(line1, "y1", "10.22");
    			attr(line1, "x2", "5.64");
    			attr(line1, "y2", "11.64");
    			attr(line2, "x1", "1");
    			attr(line2, "y1", "18");
    			attr(line2, "x2", "3");
    			attr(line2, "y2", "18");
    			attr(line3, "x1", "21");
    			attr(line3, "y1", "18");
    			attr(line3, "x2", "23");
    			attr(line3, "y2", "18");
    			attr(line4, "x1", "18.36");
    			attr(line4, "y1", "11.64");
    			attr(line4, "x2", "19.78");
    			attr(line4, "y2", "10.22");
    			attr(line5, "x1", "23");
    			attr(line5, "y1", "22");
    			attr(line5, "x2", "1");
    			attr(line5, "y2", "22");
    			attr(polyline, "points", "8 6 12 2 16 6");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, line0);
    			append(svg, line1);
    			append(svg, line2);
    			append(svg, line3);
    			append(svg, line4);
    			append(svg, line5);
    			append(svg, polyline);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3E($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Sunrise extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3E, create_fragment$3E, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Sunset.svelte generated by Svelte v3.31.0 */

    function create_fragment$3F(ctx) {
    	let svg;
    	let path;
    	let line0;
    	let line1;
    	let line2;
    	let line3;
    	let line4;
    	let line5;
    	let polyline;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			line2 = svg_element("line");
    			line3 = svg_element("line");
    			line4 = svg_element("line");
    			line5 = svg_element("line");
    			polyline = svg_element("polyline");
    			attr(path, "d", "M17 18a5 5 0 0 0-10 0");
    			attr(line0, "x1", "12");
    			attr(line0, "y1", "9");
    			attr(line0, "x2", "12");
    			attr(line0, "y2", "2");
    			attr(line1, "x1", "4.22");
    			attr(line1, "y1", "10.22");
    			attr(line1, "x2", "5.64");
    			attr(line1, "y2", "11.64");
    			attr(line2, "x1", "1");
    			attr(line2, "y1", "18");
    			attr(line2, "x2", "3");
    			attr(line2, "y2", "18");
    			attr(line3, "x1", "21");
    			attr(line3, "y1", "18");
    			attr(line3, "x2", "23");
    			attr(line3, "y2", "18");
    			attr(line4, "x1", "18.36");
    			attr(line4, "y1", "11.64");
    			attr(line4, "x2", "19.78");
    			attr(line4, "y2", "10.22");
    			attr(line5, "x1", "23");
    			attr(line5, "y1", "22");
    			attr(line5, "x2", "1");
    			attr(line5, "y2", "22");
    			attr(polyline, "points", "16 5 12 9 8 5");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, line0);
    			append(svg, line1);
    			append(svg, line2);
    			append(svg, line3);
    			append(svg, line4);
    			append(svg, line5);
    			append(svg, polyline);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3F($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Sunset extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3F, create_fragment$3F, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Tablet.svelte generated by Svelte v3.31.0 */

    function create_fragment$3G(ctx) {
    	let svg;
    	let rect;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			rect = svg_element("rect");
    			line = svg_element("line");
    			attr(rect, "x", "4");
    			attr(rect, "y", "2");
    			attr(rect, "width", "16");
    			attr(rect, "height", "20");
    			attr(rect, "rx", "2");
    			attr(rect, "ry", "2");
    			attr(line, "x1", "12");
    			attr(line, "y1", "18");
    			attr(line, "x2", "12.01");
    			attr(line, "y2", "18");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, rect);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3G($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Tablet extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3G, create_fragment$3G, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Tag.svelte generated by Svelte v3.31.0 */

    function create_fragment$3H(ctx) {
    	let svg;
    	let path;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			line = svg_element("line");
    			attr(path, "d", "M20.59 13.41l-7.17 7.17a2 2 0 0 1-2.83 0L2 12V2h10l8.59 8.59a2 2 0 0 1 0 2.82z");
    			attr(line, "x1", "7");
    			attr(line, "y1", "7");
    			attr(line, "x2", "7.01");
    			attr(line, "y2", "7");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3H($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Tag extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3H, create_fragment$3H, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Target.svelte generated by Svelte v3.31.0 */

    function create_fragment$3I(ctx) {
    	let svg;
    	let circle0;
    	let circle1;
    	let circle2;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle0 = svg_element("circle");
    			circle1 = svg_element("circle");
    			circle2 = svg_element("circle");
    			attr(circle0, "cx", "12");
    			attr(circle0, "cy", "12");
    			attr(circle0, "r", "10");
    			attr(circle1, "cx", "12");
    			attr(circle1, "cy", "12");
    			attr(circle1, "r", "6");
    			attr(circle2, "cx", "12");
    			attr(circle2, "cy", "12");
    			attr(circle2, "r", "2");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle0);
    			append(svg, circle1);
    			append(svg, circle2);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3I($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Target extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3I, create_fragment$3I, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Terminal.svelte generated by Svelte v3.31.0 */

    function create_fragment$3J(ctx) {
    	let svg;
    	let polyline;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline = svg_element("polyline");
    			line = svg_element("line");
    			attr(polyline, "points", "4 17 10 11 4 5");
    			attr(line, "x1", "12");
    			attr(line, "y1", "19");
    			attr(line, "x2", "20");
    			attr(line, "y2", "19");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3J($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Terminal extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3J, create_fragment$3J, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Thermometer.svelte generated by Svelte v3.31.0 */

    function create_fragment$3K(ctx) {
    	let svg;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			attr(path, "d", "M14 14.76V3.5a2.5 2.5 0 0 0-5 0v11.26a4.5 4.5 0 1 0 5 0z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3K($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Thermometer extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3K, create_fragment$3K, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/ThumbsDown.svelte generated by Svelte v3.31.0 */

    function create_fragment$3L(ctx) {
    	let svg;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			attr(path, "d", "M10 15v4a3 3 0 0 0 3 3l4-9V2H5.72a2 2 0 0 0-2 1.7l-1.38 9a2 2 0 0 0 2 2.3zm7-13h2.67A2.31 2.31 0 0 1 22 4v7a2.31 2.31 0 0 1-2.33 2H17");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3L($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class ThumbsDown extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3L, create_fragment$3L, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/ThumbsUp.svelte generated by Svelte v3.31.0 */

    function create_fragment$3M(ctx) {
    	let svg;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			attr(path, "d", "M14 9V5a3 3 0 0 0-3-3l-4 9v11h11.28a2 2 0 0 0 2-1.7l1.38-9a2 2 0 0 0-2-2.3zM7 22H4a2 2 0 0 1-2-2v-7a2 2 0 0 1 2-2h3");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3M($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class ThumbsUp extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3M, create_fragment$3M, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/ToggleLeft.svelte generated by Svelte v3.31.0 */

    function create_fragment$3N(ctx) {
    	let svg;
    	let rect;
    	let circle;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			rect = svg_element("rect");
    			circle = svg_element("circle");
    			attr(rect, "x", "1");
    			attr(rect, "y", "5");
    			attr(rect, "width", "22");
    			attr(rect, "height", "14");
    			attr(rect, "rx", "7");
    			attr(rect, "ry", "7");
    			attr(circle, "cx", "8");
    			attr(circle, "cy", "12");
    			attr(circle, "r", "3");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, rect);
    			append(svg, circle);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3N($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class ToggleLeft extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3N, create_fragment$3N, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/ToggleRight.svelte generated by Svelte v3.31.0 */

    function create_fragment$3O(ctx) {
    	let svg;
    	let rect;
    	let circle;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			rect = svg_element("rect");
    			circle = svg_element("circle");
    			attr(rect, "x", "1");
    			attr(rect, "y", "5");
    			attr(rect, "width", "22");
    			attr(rect, "height", "14");
    			attr(rect, "rx", "7");
    			attr(rect, "ry", "7");
    			attr(circle, "cx", "16");
    			attr(circle, "cy", "12");
    			attr(circle, "r", "3");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, rect);
    			append(svg, circle);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3O($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class ToggleRight extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3O, create_fragment$3O, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Tool.svelte generated by Svelte v3.31.0 */

    function create_fragment$3P(ctx) {
    	let svg;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			attr(path, "d", "M14.7 6.3a1 1 0 0 0 0 1.4l1.6 1.6a1 1 0 0 0 1.4 0l3.77-3.77a6 6 0 0 1-7.94 7.94l-6.91 6.91a2.12 2.12 0 0 1-3-3l6.91-6.91a6 6 0 0 1 7.94-7.94l-3.76 3.76z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3P($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Tool extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3P, create_fragment$3P, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Trash2.svelte generated by Svelte v3.31.0 */

    function create_fragment$3Q(ctx) {
    	let svg;
    	let polyline;
    	let path;
    	let line0;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline = svg_element("polyline");
    			path = svg_element("path");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			attr(polyline, "points", "3 6 5 6 21 6");
    			attr(path, "d", "M19 6v14a2 2 0 0 1-2 2H7a2 2 0 0 1-2-2V6m3 0V4a2 2 0 0 1 2-2h4a2 2 0 0 1 2 2v2");
    			attr(line0, "x1", "10");
    			attr(line0, "y1", "11");
    			attr(line0, "x2", "10");
    			attr(line0, "y2", "17");
    			attr(line1, "x1", "14");
    			attr(line1, "y1", "11");
    			attr(line1, "x2", "14");
    			attr(line1, "y2", "17");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline);
    			append(svg, path);
    			append(svg, line0);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3Q($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Trash2 extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3Q, create_fragment$3Q, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Trash.svelte generated by Svelte v3.31.0 */

    function create_fragment$3R(ctx) {
    	let svg;
    	let polyline;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline = svg_element("polyline");
    			path = svg_element("path");
    			attr(polyline, "points", "3 6 5 6 21 6");
    			attr(path, "d", "M19 6v14a2 2 0 0 1-2 2H7a2 2 0 0 1-2-2V6m3 0V4a2 2 0 0 1 2-2h4a2 2 0 0 1 2 2v2");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3R($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Trash extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3R, create_fragment$3R, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Trello.svelte generated by Svelte v3.31.0 */

    function create_fragment$3S(ctx) {
    	let svg;
    	let rect0;
    	let rect1;
    	let rect2;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			rect0 = svg_element("rect");
    			rect1 = svg_element("rect");
    			rect2 = svg_element("rect");
    			attr(rect0, "x", "3");
    			attr(rect0, "y", "3");
    			attr(rect0, "width", "18");
    			attr(rect0, "height", "18");
    			attr(rect0, "rx", "2");
    			attr(rect0, "ry", "2");
    			attr(rect1, "x", "7");
    			attr(rect1, "y", "7");
    			attr(rect1, "width", "3");
    			attr(rect1, "height", "9");
    			attr(rect2, "x", "14");
    			attr(rect2, "y", "7");
    			attr(rect2, "width", "3");
    			attr(rect2, "height", "5");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, rect0);
    			append(svg, rect1);
    			append(svg, rect2);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3S($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Trello extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3S, create_fragment$3S, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/TrendingDown.svelte generated by Svelte v3.31.0 */

    function create_fragment$3T(ctx) {
    	let svg;
    	let polyline0;
    	let polyline1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline0 = svg_element("polyline");
    			polyline1 = svg_element("polyline");
    			attr(polyline0, "points", "23 18 13.5 8.5 8.5 13.5 1 6");
    			attr(polyline1, "points", "17 18 23 18 23 12");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline0);
    			append(svg, polyline1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3T($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class TrendingDown extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3T, create_fragment$3T, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/TrendingUp.svelte generated by Svelte v3.31.0 */

    function create_fragment$3U(ctx) {
    	let svg;
    	let polyline0;
    	let polyline1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline0 = svg_element("polyline");
    			polyline1 = svg_element("polyline");
    			attr(polyline0, "points", "23 6 13.5 15.5 8.5 10.5 1 18");
    			attr(polyline1, "points", "17 6 23 6 23 12");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline0);
    			append(svg, polyline1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3U($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class TrendingUp extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3U, create_fragment$3U, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Triangle.svelte generated by Svelte v3.31.0 */

    function create_fragment$3V(ctx) {
    	let svg;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			attr(path, "d", "M10.29 3.86L1.82 18a2 2 0 0 0 1.71 3h16.94a2 2 0 0 0 1.71-3L13.71 3.86a2 2 0 0 0-3.42 0z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3V($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Triangle extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3V, create_fragment$3V, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Truck.svelte generated by Svelte v3.31.0 */

    function create_fragment$3W(ctx) {
    	let svg;
    	let rect;
    	let polygon;
    	let circle0;
    	let circle1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			rect = svg_element("rect");
    			polygon = svg_element("polygon");
    			circle0 = svg_element("circle");
    			circle1 = svg_element("circle");
    			attr(rect, "x", "1");
    			attr(rect, "y", "3");
    			attr(rect, "width", "15");
    			attr(rect, "height", "13");
    			attr(polygon, "points", "16 8 20 8 23 11 23 16 16 16 16 8");
    			attr(circle0, "cx", "5.5");
    			attr(circle0, "cy", "18.5");
    			attr(circle0, "r", "2.5");
    			attr(circle1, "cx", "18.5");
    			attr(circle1, "cy", "18.5");
    			attr(circle1, "r", "2.5");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, rect);
    			append(svg, polygon);
    			append(svg, circle0);
    			append(svg, circle1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3W($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Truck extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3W, create_fragment$3W, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Tv.svelte generated by Svelte v3.31.0 */

    function create_fragment$3X(ctx) {
    	let svg;
    	let rect;
    	let polyline;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			rect = svg_element("rect");
    			polyline = svg_element("polyline");
    			attr(rect, "x", "2");
    			attr(rect, "y", "7");
    			attr(rect, "width", "20");
    			attr(rect, "height", "15");
    			attr(rect, "rx", "2");
    			attr(rect, "ry", "2");
    			attr(polyline, "points", "17 2 12 7 7 2");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, rect);
    			append(svg, polyline);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3X($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Tv extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3X, create_fragment$3X, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Twitch.svelte generated by Svelte v3.31.0 */

    function create_fragment$3Y(ctx) {
    	let svg;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			attr(path, "d", "M21 2H3v16h5v4l4-4h5l4-4V2zm-10 9V7m5 4V7");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3Y($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Twitch extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3Y, create_fragment$3Y, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Twitter.svelte generated by Svelte v3.31.0 */

    function create_fragment$3Z(ctx) {
    	let svg;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			attr(path, "d", "M23 3a10.9 10.9 0 0 1-3.14 1.53 4.48 4.48 0 0 0-7.86 3v1A10.66 10.66 0 0 1 3 4s-4 9 5 13a11.64 11.64 0 0 1-7 2c9 5 20 0 20-11.5a4.5 4.5 0 0 0-.08-.83A7.72 7.72 0 0 0 23 3z");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3Z($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Twitter extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3Z, create_fragment$3Z, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Type.svelte generated by Svelte v3.31.0 */

    function create_fragment$3_(ctx) {
    	let svg;
    	let polyline;
    	let line0;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline = svg_element("polyline");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			attr(polyline, "points", "4 7 4 4 20 4 20 7");
    			attr(line0, "x1", "9");
    			attr(line0, "y1", "20");
    			attr(line0, "x2", "15");
    			attr(line0, "y2", "20");
    			attr(line1, "x1", "12");
    			attr(line1, "y1", "4");
    			attr(line1, "x2", "12");
    			attr(line1, "y2", "20");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline);
    			append(svg, line0);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3_($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Type extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3_, create_fragment$3_, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Umbrella.svelte generated by Svelte v3.31.0 */

    function create_fragment$3$(ctx) {
    	let svg;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			attr(path, "d", "M23 12a11.05 11.05 0 0 0-22 0zm-5 7a3 3 0 0 1-6 0v-7");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$3$($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Umbrella extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$3$, create_fragment$3$, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Underline.svelte generated by Svelte v3.31.0 */

    function create_fragment$40(ctx) {
    	let svg;
    	let path;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			line = svg_element("line");
    			attr(path, "d", "M6 3v7a6 6 0 0 0 6 6 6 6 0 0 0 6-6V3");
    			attr(line, "x1", "4");
    			attr(line, "y1", "21");
    			attr(line, "x2", "20");
    			attr(line, "y2", "21");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$40($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Underline extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$40, create_fragment$40, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Unlock.svelte generated by Svelte v3.31.0 */

    function create_fragment$41(ctx) {
    	let svg;
    	let rect;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			rect = svg_element("rect");
    			path = svg_element("path");
    			attr(rect, "x", "3");
    			attr(rect, "y", "11");
    			attr(rect, "width", "18");
    			attr(rect, "height", "11");
    			attr(rect, "rx", "2");
    			attr(rect, "ry", "2");
    			attr(path, "d", "M7 11V7a5 5 0 0 1 9.9-1");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, rect);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$41($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Unlock extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$41, create_fragment$41, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/UploadCloud.svelte generated by Svelte v3.31.0 */

    function create_fragment$42(ctx) {
    	let svg;
    	let polyline0;
    	let line;
    	let path;
    	let polyline1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline0 = svg_element("polyline");
    			line = svg_element("line");
    			path = svg_element("path");
    			polyline1 = svg_element("polyline");
    			attr(polyline0, "points", "16 16 12 12 8 16");
    			attr(line, "x1", "12");
    			attr(line, "y1", "12");
    			attr(line, "x2", "12");
    			attr(line, "y2", "21");
    			attr(path, "d", "M20.39 18.39A5 5 0 0 0 18 9h-1.26A8 8 0 1 0 3 16.3");
    			attr(polyline1, "points", "16 16 12 12 8 16");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline0);
    			append(svg, line);
    			append(svg, path);
    			append(svg, polyline1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$42($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class UploadCloud extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$42, create_fragment$42, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Upload.svelte generated by Svelte v3.31.0 */

    function create_fragment$43(ctx) {
    	let svg;
    	let path;
    	let polyline;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			polyline = svg_element("polyline");
    			line = svg_element("line");
    			attr(path, "d", "M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-4");
    			attr(polyline, "points", "17 8 12 3 7 8");
    			attr(line, "x1", "12");
    			attr(line, "y1", "3");
    			attr(line, "x2", "12");
    			attr(line, "y2", "15");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, polyline);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$43($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Upload extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$43, create_fragment$43, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/UserCheck.svelte generated by Svelte v3.31.0 */

    function create_fragment$44(ctx) {
    	let svg;
    	let path;
    	let circle;
    	let polyline;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			circle = svg_element("circle");
    			polyline = svg_element("polyline");
    			attr(path, "d", "M16 21v-2a4 4 0 0 0-4-4H5a4 4 0 0 0-4 4v2");
    			attr(circle, "cx", "8.5");
    			attr(circle, "cy", "7");
    			attr(circle, "r", "4");
    			attr(polyline, "points", "17 11 19 13 23 9");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, circle);
    			append(svg, polyline);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$44($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class UserCheck extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$44, create_fragment$44, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/UserMinus.svelte generated by Svelte v3.31.0 */

    function create_fragment$45(ctx) {
    	let svg;
    	let path;
    	let circle;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			circle = svg_element("circle");
    			line = svg_element("line");
    			attr(path, "d", "M16 21v-2a4 4 0 0 0-4-4H5a4 4 0 0 0-4 4v2");
    			attr(circle, "cx", "8.5");
    			attr(circle, "cy", "7");
    			attr(circle, "r", "4");
    			attr(line, "x1", "23");
    			attr(line, "y1", "11");
    			attr(line, "x2", "17");
    			attr(line, "y2", "11");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, circle);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$45($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class UserMinus extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$45, create_fragment$45, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/UserPlus.svelte generated by Svelte v3.31.0 */

    function create_fragment$46(ctx) {
    	let svg;
    	let path;
    	let circle;
    	let line0;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			circle = svg_element("circle");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			attr(path, "d", "M16 21v-2a4 4 0 0 0-4-4H5a4 4 0 0 0-4 4v2");
    			attr(circle, "cx", "8.5");
    			attr(circle, "cy", "7");
    			attr(circle, "r", "4");
    			attr(line0, "x1", "20");
    			attr(line0, "y1", "8");
    			attr(line0, "x2", "20");
    			attr(line0, "y2", "14");
    			attr(line1, "x1", "23");
    			attr(line1, "y1", "11");
    			attr(line1, "x2", "17");
    			attr(line1, "y2", "11");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, circle);
    			append(svg, line0);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$46($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class UserPlus extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$46, create_fragment$46, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/UserX.svelte generated by Svelte v3.31.0 */

    function create_fragment$47(ctx) {
    	let svg;
    	let path;
    	let circle;
    	let line0;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			circle = svg_element("circle");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			attr(path, "d", "M16 21v-2a4 4 0 0 0-4-4H5a4 4 0 0 0-4 4v2");
    			attr(circle, "cx", "8.5");
    			attr(circle, "cy", "7");
    			attr(circle, "r", "4");
    			attr(line0, "x1", "18");
    			attr(line0, "y1", "8");
    			attr(line0, "x2", "23");
    			attr(line0, "y2", "13");
    			attr(line1, "x1", "23");
    			attr(line1, "y1", "8");
    			attr(line1, "x2", "18");
    			attr(line1, "y2", "13");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, circle);
    			append(svg, line0);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$47($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class UserX extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$47, create_fragment$47, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/User.svelte generated by Svelte v3.31.0 */

    function create_fragment$48(ctx) {
    	let svg;
    	let path;
    	let circle;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			circle = svg_element("circle");
    			attr(path, "d", "M20 21v-2a4 4 0 0 0-4-4H8a4 4 0 0 0-4 4v2");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "7");
    			attr(circle, "r", "4");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, circle);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$48($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class User extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$48, create_fragment$48, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Users.svelte generated by Svelte v3.31.0 */

    function create_fragment$49(ctx) {
    	let svg;
    	let path0;
    	let circle;
    	let path1;
    	let path2;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path0 = svg_element("path");
    			circle = svg_element("circle");
    			path1 = svg_element("path");
    			path2 = svg_element("path");
    			attr(path0, "d", "M17 21v-2a4 4 0 0 0-4-4H5a4 4 0 0 0-4 4v2");
    			attr(circle, "cx", "9");
    			attr(circle, "cy", "7");
    			attr(circle, "r", "4");
    			attr(path1, "d", "M23 21v-2a4 4 0 0 0-3-3.87");
    			attr(path2, "d", "M16 3.13a4 4 0 0 1 0 7.75");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path0);
    			append(svg, circle);
    			append(svg, path1);
    			append(svg, path2);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$49($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Users extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$49, create_fragment$49, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/VideoOff.svelte generated by Svelte v3.31.0 */

    function create_fragment$4a(ctx) {
    	let svg;
    	let path;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			line = svg_element("line");
    			attr(path, "d", "M16 16v1a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V7a2 2 0 0 1 2-2h2m5.66 0H14a2 2 0 0 1 2 2v3.34l1 1L23 7v10");
    			attr(line, "x1", "1");
    			attr(line, "y1", "1");
    			attr(line, "x2", "23");
    			attr(line, "y2", "23");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$4a($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class VideoOff extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$4a, create_fragment$4a, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Video.svelte generated by Svelte v3.31.0 */

    function create_fragment$4b(ctx) {
    	let svg;
    	let polygon;
    	let rect;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polygon = svg_element("polygon");
    			rect = svg_element("rect");
    			attr(polygon, "points", "23 7 16 12 23 17 23 7");
    			attr(rect, "x", "1");
    			attr(rect, "y", "5");
    			attr(rect, "width", "15");
    			attr(rect, "height", "14");
    			attr(rect, "rx", "2");
    			attr(rect, "ry", "2");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polygon);
    			append(svg, rect);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$4b($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Video extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$4b, create_fragment$4b, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Voicemail.svelte generated by Svelte v3.31.0 */

    function create_fragment$4c(ctx) {
    	let svg;
    	let circle0;
    	let circle1;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle0 = svg_element("circle");
    			circle1 = svg_element("circle");
    			line = svg_element("line");
    			attr(circle0, "cx", "5.5");
    			attr(circle0, "cy", "11.5");
    			attr(circle0, "r", "4.5");
    			attr(circle1, "cx", "18.5");
    			attr(circle1, "cy", "11.5");
    			attr(circle1, "r", "4.5");
    			attr(line, "x1", "5.5");
    			attr(line, "y1", "16");
    			attr(line, "x2", "18.5");
    			attr(line, "y2", "16");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle0);
    			append(svg, circle1);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$4c($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Voicemail extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$4c, create_fragment$4c, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Volume1.svelte generated by Svelte v3.31.0 */

    function create_fragment$4d(ctx) {
    	let svg;
    	let polygon;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polygon = svg_element("polygon");
    			path = svg_element("path");
    			attr(polygon, "points", "11 5 6 9 2 9 2 15 6 15 11 19 11 5");
    			attr(path, "d", "M15.54 8.46a5 5 0 0 1 0 7.07");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polygon);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$4d($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Volume1 extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$4d, create_fragment$4d, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Volume2.svelte generated by Svelte v3.31.0 */

    function create_fragment$4e(ctx) {
    	let svg;
    	let polygon;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polygon = svg_element("polygon");
    			path = svg_element("path");
    			attr(polygon, "points", "11 5 6 9 2 9 2 15 6 15 11 19 11 5");
    			attr(path, "d", "M19.07 4.93a10 10 0 0 1 0 14.14M15.54 8.46a5 5 0 0 1 0 7.07");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polygon);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$4e($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Volume2 extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$4e, create_fragment$4e, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/VolumeX.svelte generated by Svelte v3.31.0 */

    function create_fragment$4f(ctx) {
    	let svg;
    	let polygon;
    	let line0;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polygon = svg_element("polygon");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			attr(polygon, "points", "11 5 6 9 2 9 2 15 6 15 11 19 11 5");
    			attr(line0, "x1", "23");
    			attr(line0, "y1", "9");
    			attr(line0, "x2", "17");
    			attr(line0, "y2", "15");
    			attr(line1, "x1", "17");
    			attr(line1, "y1", "9");
    			attr(line1, "x2", "23");
    			attr(line1, "y2", "15");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polygon);
    			append(svg, line0);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$4f($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class VolumeX extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$4f, create_fragment$4f, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Volume.svelte generated by Svelte v3.31.0 */

    function create_fragment$4g(ctx) {
    	let svg;
    	let polygon;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polygon = svg_element("polygon");
    			attr(polygon, "points", "11 5 6 9 2 9 2 15 6 15 11 19 11 5");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polygon);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$4g($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Volume extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$4g, create_fragment$4g, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Watch.svelte generated by Svelte v3.31.0 */

    function create_fragment$4h(ctx) {
    	let svg;
    	let circle;
    	let polyline;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle = svg_element("circle");
    			polyline = svg_element("polyline");
    			path = svg_element("path");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "12");
    			attr(circle, "r", "7");
    			attr(polyline, "points", "12 9 12 12 13.5 13.5");
    			attr(path, "d", "M16.51 17.35l-.35 3.83a2 2 0 0 1-2 1.82H9.83a2 2 0 0 1-2-1.82l-.35-3.83m.01-10.7l.35-3.83A2 2 0 0 1 9.83 1h4.35a2 2 0 0 1 2 1.82l.35 3.83");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle);
    			append(svg, polyline);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$4h($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Watch extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$4h, create_fragment$4h, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/WifiOff.svelte generated by Svelte v3.31.0 */

    function create_fragment$4i(ctx) {
    	let svg;
    	let line0;
    	let path0;
    	let path1;
    	let path2;
    	let path3;
    	let path4;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			line0 = svg_element("line");
    			path0 = svg_element("path");
    			path1 = svg_element("path");
    			path2 = svg_element("path");
    			path3 = svg_element("path");
    			path4 = svg_element("path");
    			line1 = svg_element("line");
    			attr(line0, "x1", "1");
    			attr(line0, "y1", "1");
    			attr(line0, "x2", "23");
    			attr(line0, "y2", "23");
    			attr(path0, "d", "M16.72 11.06A10.94 10.94 0 0 1 19 12.55");
    			attr(path1, "d", "M5 12.55a10.94 10.94 0 0 1 5.17-2.39");
    			attr(path2, "d", "M10.71 5.05A16 16 0 0 1 22.58 9");
    			attr(path3, "d", "M1.42 9a15.91 15.91 0 0 1 4.7-2.88");
    			attr(path4, "d", "M8.53 16.11a6 6 0 0 1 6.95 0");
    			attr(line1, "x1", "12");
    			attr(line1, "y1", "20");
    			attr(line1, "x2", "12.01");
    			attr(line1, "y2", "20");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, line0);
    			append(svg, path0);
    			append(svg, path1);
    			append(svg, path2);
    			append(svg, path3);
    			append(svg, path4);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$4i($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class WifiOff extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$4i, create_fragment$4i, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Wifi.svelte generated by Svelte v3.31.0 */

    function create_fragment$4j(ctx) {
    	let svg;
    	let path0;
    	let path1;
    	let path2;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path0 = svg_element("path");
    			path1 = svg_element("path");
    			path2 = svg_element("path");
    			line = svg_element("line");
    			attr(path0, "d", "M5 12.55a11 11 0 0 1 14.08 0");
    			attr(path1, "d", "M1.42 9a16 16 0 0 1 21.16 0");
    			attr(path2, "d", "M8.53 16.11a6 6 0 0 1 6.95 0");
    			attr(line, "x1", "12");
    			attr(line, "y1", "20");
    			attr(line, "x2", "12.01");
    			attr(line, "y2", "20");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path0);
    			append(svg, path1);
    			append(svg, path2);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$4j($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Wifi extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$4j, create_fragment$4j, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Wind.svelte generated by Svelte v3.31.0 */

    function create_fragment$4k(ctx) {
    	let svg;
    	let path;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			attr(path, "d", "M9.59 4.59A2 2 0 1 1 11 8H2m10.59 11.41A2 2 0 1 0 14 16H2m15.73-8.27A2.5 2.5 0 1 1 19.5 12H2");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$4k($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Wind extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$4k, create_fragment$4k, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/XCircle.svelte generated by Svelte v3.31.0 */

    function create_fragment$4l(ctx) {
    	let svg;
    	let circle;
    	let line0;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle = svg_element("circle");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			attr(circle, "cx", "12");
    			attr(circle, "cy", "12");
    			attr(circle, "r", "10");
    			attr(line0, "x1", "15");
    			attr(line0, "y1", "9");
    			attr(line0, "x2", "9");
    			attr(line0, "y2", "15");
    			attr(line1, "x1", "9");
    			attr(line1, "y1", "9");
    			attr(line1, "x2", "15");
    			attr(line1, "y2", "15");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle);
    			append(svg, line0);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$4l($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class XCircle extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$4l, create_fragment$4l, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/XOctagon.svelte generated by Svelte v3.31.0 */

    function create_fragment$4m(ctx) {
    	let svg;
    	let polygon;
    	let line0;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polygon = svg_element("polygon");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			attr(polygon, "points", "7.86 2 16.14 2 22 7.86 22 16.14 16.14 22 7.86 22 2 16.14 2 7.86 7.86 2");
    			attr(line0, "x1", "15");
    			attr(line0, "y1", "9");
    			attr(line0, "x2", "9");
    			attr(line0, "y2", "15");
    			attr(line1, "x1", "9");
    			attr(line1, "y1", "9");
    			attr(line1, "x2", "15");
    			attr(line1, "y2", "15");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polygon);
    			append(svg, line0);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$4m($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class XOctagon extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$4m, create_fragment$4m, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/XSquare.svelte generated by Svelte v3.31.0 */

    function create_fragment$4n(ctx) {
    	let svg;
    	let rect;
    	let line0;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			rect = svg_element("rect");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			attr(rect, "x", "3");
    			attr(rect, "y", "3");
    			attr(rect, "width", "18");
    			attr(rect, "height", "18");
    			attr(rect, "rx", "2");
    			attr(rect, "ry", "2");
    			attr(line0, "x1", "9");
    			attr(line0, "y1", "9");
    			attr(line0, "x2", "15");
    			attr(line0, "y2", "15");
    			attr(line1, "x1", "15");
    			attr(line1, "y1", "9");
    			attr(line1, "x2", "9");
    			attr(line1, "y2", "15");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, rect);
    			append(svg, line0);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$4n($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class XSquare extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$4n, create_fragment$4n, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/X.svelte generated by Svelte v3.31.0 */

    function create_fragment$4o(ctx) {
    	let svg;
    	let line0;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			attr(line0, "x1", "18");
    			attr(line0, "y1", "6");
    			attr(line0, "x2", "6");
    			attr(line0, "y2", "18");
    			attr(line1, "x1", "6");
    			attr(line1, "y1", "6");
    			attr(line1, "x2", "18");
    			attr(line1, "y2", "18");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, line0);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$4o($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class X extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$4o, create_fragment$4o, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Youtube.svelte generated by Svelte v3.31.0 */

    function create_fragment$4p(ctx) {
    	let svg;
    	let path;
    	let polygon;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			path = svg_element("path");
    			polygon = svg_element("polygon");
    			attr(path, "d", "M22.54 6.42a2.78 2.78 0 0 0-1.94-2C18.88 4 12 4 12 4s-6.88 0-8.6.46a2.78 2.78 0 0 0-1.94 2A29 29 0 0 0 1 11.75a29 29 0 0 0 .46 5.33A2.78 2.78 0 0 0 3.4 19c1.72.46 8.6.46 8.6.46s6.88 0 8.6-.46a2.78 2.78 0 0 0 1.94-2 29 29 0 0 0 .46-5.25 29 29 0 0 0-.46-5.33z");
    			attr(polygon, "points", "9.75 15.02 15.5 11.75 9.75 8.48 9.75 15.02");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, path);
    			append(svg, polygon);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$4p($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Youtube extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$4p, create_fragment$4p, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/ZapOff.svelte generated by Svelte v3.31.0 */

    function create_fragment$4q(ctx) {
    	let svg;
    	let polyline0;
    	let polyline1;
    	let polyline2;
    	let line;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polyline0 = svg_element("polyline");
    			polyline1 = svg_element("polyline");
    			polyline2 = svg_element("polyline");
    			line = svg_element("line");
    			attr(polyline0, "points", "12.41 6.75 13 2 10.57 4.92");
    			attr(polyline1, "points", "18.57 12.91 21 10 15.66 10");
    			attr(polyline2, "points", "8 8 3 14 12 14 11 22 16 16");
    			attr(line, "x1", "1");
    			attr(line, "y1", "1");
    			attr(line, "x2", "23");
    			attr(line, "y2", "23");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polyline0);
    			append(svg, polyline1);
    			append(svg, polyline2);
    			append(svg, line);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$4q($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class ZapOff extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$4q, create_fragment$4q, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/Zap.svelte generated by Svelte v3.31.0 */

    function create_fragment$4r(ctx) {
    	let svg;
    	let polygon;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			polygon = svg_element("polygon");
    			attr(polygon, "points", "13 2 3 14 12 14 11 22 21 10 12 10 13 2");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, polygon);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$4r($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class Zap extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$4r, create_fragment$4r, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/ZoomIn.svelte generated by Svelte v3.31.0 */

    function create_fragment$4s(ctx) {
    	let svg;
    	let circle;
    	let line0;
    	let line1;
    	let line2;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle = svg_element("circle");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			line2 = svg_element("line");
    			attr(circle, "cx", "11");
    			attr(circle, "cy", "11");
    			attr(circle, "r", "8");
    			attr(line0, "x1", "21");
    			attr(line0, "y1", "21");
    			attr(line0, "x2", "16.65");
    			attr(line0, "y2", "16.65");
    			attr(line1, "x1", "11");
    			attr(line1, "y1", "8");
    			attr(line1, "x2", "11");
    			attr(line1, "y2", "14");
    			attr(line2, "x1", "8");
    			attr(line2, "y1", "11");
    			attr(line2, "x2", "14");
    			attr(line2, "y2", "11");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle);
    			append(svg, line0);
    			append(svg, line1);
    			append(svg, line2);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$4s($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class ZoomIn extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$4s, create_fragment$4s, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    /* src/icons/ZoomOut.svelte generated by Svelte v3.31.0 */

    function create_fragment$4t(ctx) {
    	let svg;
    	let circle;
    	let line0;
    	let line1;

    	let svg_levels = [
    		{ xmlns: "http://www.w3.org/2000/svg" },
    		{ width: /*size*/ ctx[1] },
    		{ height: /*size*/ ctx[1] },
    		{ viewBox: "0 0 24 24" },
    		{ fill: "none" },
    		{ stroke: /*color*/ ctx[0] },
    		{ "stroke-width": "2" },
    		{ "stroke-linecap": "round" },
    		{ "stroke-linejoin": "round" },
    		/*$$restProps*/ ctx[2]
    	];

    	let svg_data = {};

    	for (let i = 0; i < svg_levels.length; i += 1) {
    		svg_data = assign(svg_data, svg_levels[i]);
    	}

    	return {
    		c() {
    			svg = svg_element("svg");
    			circle = svg_element("circle");
    			line0 = svg_element("line");
    			line1 = svg_element("line");
    			attr(circle, "cx", "11");
    			attr(circle, "cy", "11");
    			attr(circle, "r", "8");
    			attr(line0, "x1", "21");
    			attr(line0, "y1", "21");
    			attr(line0, "x2", "16.65");
    			attr(line0, "y2", "16.65");
    			attr(line1, "x1", "8");
    			attr(line1, "y1", "11");
    			attr(line1, "x2", "14");
    			attr(line1, "y2", "11");
    			set_svg_attributes(svg, svg_data);
    		},
    		m(target, anchor) {
    			insert(target, svg, anchor);
    			append(svg, circle);
    			append(svg, line0);
    			append(svg, line1);
    		},
    		p(ctx, [dirty]) {
    			set_svg_attributes(svg, svg_data = get_spread_update(svg_levels, [
    				{ xmlns: "http://www.w3.org/2000/svg" },
    				dirty & /*size*/ 2 && { width: /*size*/ ctx[1] },
    				dirty & /*size*/ 2 && { height: /*size*/ ctx[1] },
    				{ viewBox: "0 0 24 24" },
    				{ fill: "none" },
    				dirty & /*color*/ 1 && { stroke: /*color*/ ctx[0] },
    				{ "stroke-width": "2" },
    				{ "stroke-linecap": "round" },
    				{ "stroke-linejoin": "round" },
    				dirty & /*$$restProps*/ 4 && /*$$restProps*/ ctx[2]
    			]));
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(svg);
    		}
    	};
    }

    function instance$4t($$self, $$props, $$invalidate) {
    	const omit_props_names = ["color","size"];
    	let $$restProps = compute_rest_props($$props, omit_props_names);
    	let { color = "currentColor" } = $$props;
    	let { size = 24 } = $$props;

    	$$self.$$set = $$new_props => {
    		$$props = assign(assign({}, $$props), exclude_internal_props($$new_props));
    		$$invalidate(2, $$restProps = compute_rest_props($$props, omit_props_names));
    		if ("color" in $$new_props) $$invalidate(0, color = $$new_props.color);
    		if ("size" in $$new_props) $$invalidate(1, size = $$new_props.size);
    	};

    	return [color, size, $$restProps];
    }

    class ZoomOut extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance$4t, create_fragment$4t, safe_not_equal, { color: 0, size: 1 });
    	}
    }

    exports.Activity = Activity;
    exports.Airplay = Airplay;
    exports.AlertCircle = AlertCircle;
    exports.AlertOctagon = AlertOctagon;
    exports.AlertTriangle = AlertTriangle;
    exports.AlignCenter = AlignCenter;
    exports.AlignJustify = AlignJustify;
    exports.AlignLeft = AlignLeft;
    exports.AlignRight = AlignRight;
    exports.Anchor = Anchor;
    exports.Aperture = Aperture;
    exports.Archive = Archive;
    exports.ArrowDown = ArrowDown;
    exports.ArrowDownCircle = ArrowDownCircle;
    exports.ArrowDownLeft = ArrowDownLeft;
    exports.ArrowDownRight = ArrowDownRight;
    exports.ArrowLeft = ArrowLeft;
    exports.ArrowLeftCircle = ArrowLeftCircle;
    exports.ArrowRight = ArrowRight;
    exports.ArrowRightCircle = ArrowRightCircle;
    exports.ArrowUp = ArrowUp;
    exports.ArrowUpCircle = ArrowUpCircle;
    exports.ArrowUpLeft = ArrowUpLeft;
    exports.ArrowUpRight = ArrowUpRight;
    exports.AtSign = AtSign;
    exports.Award = Award;
    exports.BarChart = BarChart;
    exports.BarChart2 = BarChart2;
    exports.Battery = Battery;
    exports.BatteryCharging = BatteryCharging;
    exports.Bell = Bell;
    exports.BellOff = BellOff;
    exports.Bluetooth = Bluetooth;
    exports.Bold = Bold;
    exports.Book = Book;
    exports.BookOpen = BookOpen;
    exports.Bookmark = Bookmark;
    exports.Box = Box;
    exports.Briefcase = Briefcase;
    exports.Calendar = Calendar;
    exports.Camera = Camera;
    exports.CameraOff = CameraOff;
    exports.Cast = Cast;
    exports.Check = Check;
    exports.CheckCircle = CheckCircle;
    exports.CheckSquare = CheckSquare;
    exports.ChevronDown = ChevronDown;
    exports.ChevronLeft = ChevronLeft;
    exports.ChevronRight = ChevronRight;
    exports.ChevronUp = ChevronUp;
    exports.ChevronsDown = ChevronsDown;
    exports.ChevronsLeft = ChevronsLeft;
    exports.ChevronsRight = ChevronsRight;
    exports.ChevronsUp = ChevronsUp;
    exports.Chrome = Chrome;
    exports.Circle = Circle;
    exports.Clipboard = Clipboard;
    exports.Clock = Clock;
    exports.Cloud = Cloud;
    exports.CloudDrizzle = CloudDrizzle;
    exports.CloudLightning = CloudLightning;
    exports.CloudOff = CloudOff;
    exports.CloudRain = CloudRain;
    exports.CloudSnow = CloudSnow;
    exports.Code = Code;
    exports.Codepen = Codepen;
    exports.Codesandbox = Codesandbox;
    exports.Coffee = Coffee;
    exports.Columns = Columns;
    exports.Command = Command;
    exports.Compass = Compass;
    exports.Copy = Copy;
    exports.CornerDownLeft = CornerDownLeft;
    exports.CornerDownRight = CornerDownRight;
    exports.CornerLeftDown = CornerLeftDown;
    exports.CornerLeftUp = CornerLeftUp;
    exports.CornerRightDown = CornerRightDown;
    exports.CornerRightUp = CornerRightUp;
    exports.CornerUpLeft = CornerUpLeft;
    exports.CornerUpRight = CornerUpRight;
    exports.Cpu = Cpu;
    exports.CreditCard = CreditCard;
    exports.Crop = Crop;
    exports.Crosshair = Crosshair;
    exports.Database = Database;
    exports.Delete = Delete;
    exports.Disc = Disc;
    exports.Divide = Divide;
    exports.DivideCircle = DivideCircle;
    exports.DivideSquare = DivideSquare;
    exports.DollarSign = DollarSign;
    exports.Download = Download;
    exports.DownloadCloud = DownloadCloud;
    exports.Dribbble = Dribbble;
    exports.Droplet = Droplet;
    exports.Edit = Edit;
    exports.Edit2 = Edit2;
    exports.Edit3 = Edit3;
    exports.ExternalLink = ExternalLink;
    exports.Eye = Eye;
    exports.EyeOff = EyeOff;
    exports.Facebook = Facebook;
    exports.FastForward = FastForward;
    exports.Feather = Feather;
    exports.Figma = Figma;
    exports.File = File;
    exports.FileMinus = FileMinus;
    exports.FilePlus = FilePlus;
    exports.FileText = FileText;
    exports.Film = Film;
    exports.Filter = Filter;
    exports.Flag = Flag;
    exports.Folder = Folder;
    exports.FolderMinus = FolderMinus;
    exports.FolderPlus = FolderPlus;
    exports.Framer = Framer;
    exports.Frown = Frown;
    exports.Gift = Gift;
    exports.GitBranch = GitBranch;
    exports.GitCommit = GitCommit;
    exports.GitHub = GitHub;
    exports.GitLab = GitLab;
    exports.GitMerge = GitMerge;
    exports.GitPullRequest = GitPullRequest;
    exports.Globe = Globe;
    exports.Grid = Grid;
    exports.HardDrive = HardDrive;
    exports.Hash = Hash;
    exports.Headphones = Headphones;
    exports.Heart = Heart;
    exports.HelpCircle = HelpCircle;
    exports.Hexagon = Hexagon;
    exports.Home = Home;
    exports.Image = Image;
    exports.Inbox = Inbox;
    exports.Info = Info;
    exports.Instagram = Instagram;
    exports.Italic = Italic;
    exports.Key = Key;
    exports.Layers = Layers;
    exports.Layout = Layout;
    exports.LifeBuoy = LifeBuoy;
    exports.Link = Link;
    exports.Link2 = Link2;
    exports.Linkedin = Linkedin;
    exports.List = List;
    exports.Loader = Loader;
    exports.Lock = Lock;
    exports.LogIn = LogIn;
    exports.LogOut = LogOut;
    exports.Mail = Mail;
    exports.Map = Map$1;
    exports.MapPin = MapPin;
    exports.Maximize = Maximize;
    exports.Maximize2 = Maximize2;
    exports.Meh = Meh;
    exports.Menu = Menu;
    exports.MessageCircle = MessageCircle;
    exports.MessageSquare = MessageSquare;
    exports.Mic = Mic;
    exports.MicOff = MicOff;
    exports.Minimize = Minimize;
    exports.Minimize2 = Minimize2;
    exports.Minus = Minus;
    exports.MinusCircle = MinusCircle;
    exports.MinusSquare = MinusSquare;
    exports.Monitor = Monitor;
    exports.Moon = Moon;
    exports.MoreHorizontal = MoreHorizontal;
    exports.MoreVertical = MoreVertical;
    exports.MousePointer = MousePointer;
    exports.Move = Move;
    exports.Music = Music;
    exports.Navigation = Navigation;
    exports.Navigation2 = Navigation2;
    exports.Octagon = Octagon;
    exports.Package = Package;
    exports.Paperclip = Paperclip;
    exports.Pause = Pause;
    exports.PauseCircle = PauseCircle;
    exports.PenTool = PenTool;
    exports.Percent = Percent;
    exports.Phone = Phone;
    exports.PhoneCall = PhoneCall;
    exports.PhoneForwarded = PhoneForwarded;
    exports.PhoneIncoming = PhoneIncoming;
    exports.PhoneMissed = PhoneMissed;
    exports.PhoneOff = PhoneOff;
    exports.PhoneOutgoing = PhoneOutgoing;
    exports.PieChart = PieChart;
    exports.Play = Play;
    exports.PlayCircle = PlayCircle;
    exports.Plus = Plus;
    exports.PlusCircle = PlusCircle;
    exports.PlusSquare = PlusSquare;
    exports.Pocket = Pocket;
    exports.Power = Power;
    exports.Printer = Printer;
    exports.Radio = Radio;
    exports.RefreshCcw = RefreshCcw;
    exports.RefreshCw = RefreshCw;
    exports.Repeat = Repeat;
    exports.Rewind = Rewind;
    exports.RotateCcw = RotateCcw;
    exports.RotateCw = RotateCw;
    exports.Rss = Rss;
    exports.Save = Save;
    exports.Scissors = Scissors;
    exports.Search = Search;
    exports.Send = Send;
    exports.Server = Server;
    exports.Settings = Settings;
    exports.Share = Share;
    exports.Share2 = Share2;
    exports.Shield = Shield;
    exports.ShieldOff = ShieldOff;
    exports.ShoppingBag = ShoppingBag;
    exports.ShoppingCart = ShoppingCart;
    exports.Shuffle = Shuffle;
    exports.Sidebar = Sidebar;
    exports.SkipBack = SkipBack;
    exports.SkipForward = SkipForward;
    exports.Slack = Slack;
    exports.Slash = Slash;
    exports.Sliders = Sliders;
    exports.Smartphone = Smartphone;
    exports.Smile = Smile;
    exports.Speaker = Speaker;
    exports.Square = Square;
    exports.Star = Star;
    exports.StopCircle = StopCircle;
    exports.Sun = Sun;
    exports.Sunrise = Sunrise;
    exports.Sunset = Sunset;
    exports.Tablet = Tablet;
    exports.Tag = Tag;
    exports.Target = Target;
    exports.Terminal = Terminal;
    exports.Thermometer = Thermometer;
    exports.ThumbsDown = ThumbsDown;
    exports.ThumbsUp = ThumbsUp;
    exports.ToggleLeft = ToggleLeft;
    exports.ToggleRight = ToggleRight;
    exports.Tool = Tool;
    exports.Trash = Trash;
    exports.Trash2 = Trash2;
    exports.Trello = Trello;
    exports.TrendingDown = TrendingDown;
    exports.TrendingUp = TrendingUp;
    exports.Triangle = Triangle;
    exports.Truck = Truck;
    exports.Tv = Tv;
    exports.Twitch = Twitch;
    exports.Twitter = Twitter;
    exports.Type = Type;
    exports.Umbrella = Umbrella;
    exports.Underline = Underline;
    exports.Unlock = Unlock;
    exports.Upload = Upload;
    exports.UploadCloud = UploadCloud;
    exports.User = User;
    exports.UserCheck = UserCheck;
    exports.UserMinus = UserMinus;
    exports.UserPlus = UserPlus;
    exports.UserX = UserX;
    exports.Users = Users;
    exports.Video = Video;
    exports.VideoOff = VideoOff;
    exports.Voicemail = Voicemail;
    exports.Volume = Volume;
    exports.Volume1 = Volume1;
    exports.Volume2 = Volume2;
    exports.VolumeX = VolumeX;
    exports.Watch = Watch;
    exports.Wifi = Wifi;
    exports.WifiOff = WifiOff;
    exports.Wind = Wind;
    exports.X = X;
    exports.XCircle = XCircle;
    exports.XOctagon = XOctagon;
    exports.XSquare = XSquare;
    exports.Youtube = Youtube;
    exports.Zap = Zap;
    exports.ZapOff = ZapOff;
    exports.ZoomIn = ZoomIn;
    exports.ZoomOut = ZoomOut;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
